@@ -1,5 +1,13 @@
-def subgradient_svm ():
-	print 'SubGradientSVM'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+train=lm.load_numbers('../data/fm_train_real.dat')
+test=lm.load_numbers('../data/fm_test_real.dat')
+labels=lm.load_labels('../data/label_train_twoclass.dat')
+
+parameter_list=[[train,test,labels,5,1e-3,3.0], [train,test,labels,0.9,1e-2,1.0]]
+
+def classifier_subgradientsvm_modular(fm_train_real, fm_test_real,
+		label_train_twoclass, C, epsilon, max_train_time):
 
 	from shogun.Features import RealFeatures, SparseRealFeatures, Labels
 	from shogun.Classifier import SubGradientSVM
@@ -11,26 +19,18 @@ def subgradient_svm ():
 	feats_test=SparseRealFeatures()
 	feats_test.obtain_from_simple(realfeat)
 
-	C=0.9
-	epsilon=1e-3
-	num_threads=1
-	max_train_time=1.
 	labels=Labels(label_train_twoclass)
 
 	svm=SubGradientSVM(C, feats_train, labels)
 	svm.set_epsilon(epsilon)
-	svm.parallel.set_num_threads(num_threads)
-	svm.set_bias_enabled(False)
 	svm.set_max_train_time(max_train_time)
 	svm.train()
 
 	svm.set_features(feats_test)
-	svm.classify().get_labels()
+	labels=svm.classify().get_labels()
+
+	return labels, svm
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_real=lm.load_numbers('../data/fm_train_real.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	label_train_twoclass=lm.load_labels('../data/label_train_twoclass.dat')
-	subgradient_svm()
+	print 'SubGradientSVM'
+	classifier_subgradientsvm_modular(*parameter_list[0])
