@@ -1,5 +1,13 @@
-def bray_curtis_distance ():
-	print 'BrayCurtisDistance'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat = lm.load_numbers('../data/fm_train_real.dat')
+testdat = lm.load_numbers('../data/fm_test_real.dat')
+
+parameter_list = [[traindat,testdat],[traindat,testdat]]
+
+def distance_braycurtis_modular (fm_train_real=traindat,fm_test_real=testdat):
+
 
 	from shogun.Features import RealFeatures
 	from shogun.Distance import BrayCurtisDistance
@@ -13,10 +21,9 @@ def bray_curtis_distance ():
 	distance.init(feats_train, feats_test)
 	dm_test=distance.get_distance_matrix()
 
+	return distance,dm_train,dm_test
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_real=lm.load_numbers('../data/fm_train_real.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	bray_curtis_distance()
+	print 'BrayCurtisDistance'
+	distance_braycurtis_modular(*parameter_list[0])
+
