@@ -1,14 +1,18 @@
-def manhattan_word_distance ():
-	print 'ManhattanWordDistance'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindna = lm.load_dna('../data/fm_train_dna.dat')
+testdna = lm.load_dna('../data/fm_test_dna.dat')
+testdat = lm.load_numbers('../data/fm_test_real.dat')
+
+parameter_list = [[traindna,testdna,testdat,3,0,False],[traindna,testdna,testdat,4,0,False]]
+
+def distance_manhattenword_modular (fm_train_dna=traindna ,fm_test_dna=testdna,fm_test_real=testdat,order=3,gap=0,reverse=False):
 
 	from shogun.Features import StringCharFeatures, StringWordFeatures, DNA
 	from shogun.PreProc import SortWordString
 	from shogun.Distance import ManhattanWordDistance
 
-	order=3
-	gap=0
-	reverse=False
-
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_train_dna)
 	feats_train=StringWordFeatures(charfeat.get_alphabet())
@@ -30,12 +34,8 @@ def manhattan_word_distance ():
 	dm_train=distance.get_distance_matrix()
 	distance.init(feats_train, feats_test)
 	dm_test=distance.get_distance_matrix()
-
+	return dm_train,dm_test
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	manhattan_word_distance()
+	print 'ManhattanWordDistance'
+	distance_manhattenword_modular(*parameter_list[0])
