@@ -1,11 +1,15 @@
-def comm_ulong_string ():
-	print 'CommUlongString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat =lm.load_dna('../data/fm_train_dna.dat')
+testdat =  lm.load_dna('../data/fm_test_dna.dat')
+parameter_list = [[traindat,testdat,3,0,False ],[traindat,testdat,4,0,False]]
+
+def kernel_comm_ulong_string_modular (fm_train_dna=traindat,fm_test_dna=testdat, order=3, gap=0, reverse = False):
+
 	from shogun.Kernel import CommUlongStringKernel
 	from shogun.Features import StringUlongFeatures, StringCharFeatures, DNA
 	from shogun.PreProc import SortUlongString
-	order=3
-	gap=0
-	reverse=False
 
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_train_dna)
@@ -31,10 +35,8 @@ def comm_ulong_string ():
 	km_train=kernel.get_kernel_matrix()
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	comm_ulong_string()
+	print 'CommUlongString'
+	kernel_comm_ulong_string_modular(*parameter_list[0])
