@@ -1,13 +1,16 @@
-def comm_word_string ():
-	print 'CommWordString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+parameter_list = [[traindat,testdat,4,0,False, False],[traindat,testdat,4,0,False,False]]
+
+def kernel_comm_word_string_modular (fm_train_dna=traindat, fm_test_dna=testdat, order=3, gap=0, reverse = False, use_sign = False):
+	
 	from shogun.Kernel import CommWordStringKernel
 	from shogun.Features import StringWordFeatures, StringCharFeatures, DNA
 	from shogun.PreProc import SortWordString
-
-	order=3
-	gap=0
-	reverse=False
-
+	
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_train_dna)
 	feats_train=StringWordFeatures(charfeat.get_alphabet())
@@ -24,17 +27,13 @@ def comm_word_string ():
 	feats_test.add_preproc(preproc)
 	feats_test.apply_preproc()
 
-	use_sign=False
-
 	kernel=CommWordStringKernel(feats_train, feats_train, use_sign)
 
 	km_train=kernel.get_kernel_matrix()
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	comm_word_string()
+	print 'CommWordString'
+	kernel_comm_word_string_modular(*parameter_list[0])
