@@ -1,14 +1,20 @@
-def plugin_estimate_histogram ():
-	print 'PluginEstimate w/ HistogramWord'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+label_traindat = lm.load_labels('../data/label_train_dna.dat')
+parameter_list=[[traindat,testdat,label_traindat,3,0,False],[traindat,testdat,label_traindat,3,0,False]]
+
+def kernel_histogram_word_string_modular (fm_train_dna=traindat,fm_test_dna=testdat,label_train_dna=label_traindat,order=3,gap=0,reverse=False):
+
 	from shogun.Features import StringCharFeatures, StringWordFeatures, DNA, Labels
 	from shogun.Kernel import HistogramWordStringKernel
-	from shogun.Classifier import PluginEstimate
-
-	order=3
-	gap=0
-	reverse=False
+	from shogun.Classifier import PluginEstimate#, MSG_DEBUG
 
+	reverse = reverse
 	charfeat=StringCharFeatures(DNA)
+	#charfeat.io.set_loglevel(MSG_DEBUG)
 	charfeat.set_features(fm_train_dna)
 	feats_train=StringWordFeatures(charfeat.get_alphabet())
 	feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse)
@@ -26,17 +32,12 @@ def plugin_estimate_histogram ():
 
 	kernel=HistogramWordStringKernel(feats_train, feats_train, pie)
 	km_train=kernel.get_kernel_matrix()
-
 	kernel.init(feats_train, feats_test)
 	pie.set_features(feats_test)
 	pie.classify().get_labels()
 	km_test=kernel.get_kernel_matrix()
-
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	label_train_dna=lm.load_labels('../data/label_train_dna.dat')
-	plugin_estimate_histogram()
+	print 'PluginEstimate w/ HistogramWord'
+	kernel_histogram_word_string_modular(*parameter_list[0])
