@@ -1,5 +1,11 @@
-def linear_string ():
-	print 'LinearString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+
+parameter_list=[[traindat,testdat],[traindat,testdat]]
+
+def kernel_linear_string_modular (fm_train_dna=traindat,fm_test_dna=testdat):
 	from shogun.Features import StringCharFeatures, DNA
 	from shogun.Kernel import LinearStringKernel
 
@@ -11,11 +17,9 @@ def linear_string ():
 
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
-
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
 	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	linear_string()
+	print 'LinearString'
+ 	kernel_linear_string_modular(*parameter_list[0])
