@@ -1,13 +1,16 @@
-def oligo_string ():
-	print 'OligoString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+
+parameter_list = [[traindat,testdat,3,1.2,10],[traindat,testdat,4,1.3,10]]
+
+def kernel_oligo_string_modular (fm_train_dna=traindat,fm_test_dna=testdat,k=3,width=1.2,size_cache=10):
 	from shogun.Features import StringCharFeatures, DNA
 	from shogun.Kernel import OligoStringKernel
 
 	feats_train=StringCharFeatures(fm_train_dna, DNA)
 	feats_test=StringCharFeatures(fm_test_dna, DNA)
-	k=3
-	width=1.2
-	size_cache=10
 
 	kernel=OligoStringKernel(size_cache, k, width)
 	kernel.init(feats_train, feats_train)
@@ -15,10 +18,8 @@ def oligo_string ():
 	km_train=kernel.get_kernel_matrix()
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	oligo_string()
+	print 'OligoString'
+	kernel_oligo_string_modular(*parameter_list[0])
