@@ -1,13 +1,15 @@
-def weighted_comm_word_string ():
-	print 'WeightedCommWordString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+
+parameter_list = [[traindat,testdat],[traindat,testdat]]
+
+def kernel_weighted_comm_word_string_modular (fm_train_dna=traindat,fm_test_dna=testdat,order=3,gap=0,reverse=True ):
 	from shogun.Kernel import WeightedCommWordStringKernel
 	from shogun.Features import StringWordFeatures, StringCharFeatures, DNA
 	from shogun.PreProc import SortWordString
 
-	order=3
-	gap=0
-	reverse=True
-
 	charfeat=StringCharFeatures(fm_train_dna, DNA)
 	feats_train=StringWordFeatures(charfeat.get_alphabet())
 	feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse)
@@ -28,11 +30,8 @@ def weighted_comm_word_string ():
 
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
-
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	weighted_comm_word_string()
+	print 'WeightedCommWordString'
+	kernel_weighted_comm_word_string_modular(*parameter_list[0])
