@@ -1,8 +1,8 @@
 library(shogun)
 
-fm_train_real <- as.matrix(read.table('../data/fm_train_real.dat'))
-fm_test_real <- as.matrix(read.table('../data/fm_test_real.dat'))
-label_train_twoclass <- as.real(read.table('../data/label_train_twoclass.dat'))
+fm_train_real <- t(as.matrix(read.table('../data/fm_train_real.dat')))
+fm_test_real <- t(as.matrix(read.table('../data/fm_test_real.dat')))
+label_train_twoclass <- as.real(read.table('../data/label_train_twoclass.dat')$V1)
 
 # liblinear
 print('LibLinear')
