@@ -74,7 +74,7 @@ for f in files:
 for f in deps.iterkeys():
 	if f[-1] == 'i' and not initial_deps.has_key(f):
 		if file(f).read().find('%module')>-1:
-			str1=os.path.join(os.path.dirname(f), prefix + os.path.basename(f)[:-2]) + '.' + suffix + ': ' + f[:-2]+'_wrap.cxx.o' + ' sg_print_functions.cpp.o'
+			str1=os.path.join(os.path.dirname(f), prefix + os.path.basename(f)[:-2]) + suffix + ': ' + f[:-2]+'_wrap.cxx.o' + ' sg_print_functions.cpp.o'
 			str2=os.path.join(os.path.dirname(f), os.path.basename(f)[:-2]) + '_wrap.cxx: ' + f
 
 			fdep=list();
