@@ -1,7 +1,7 @@
 #!/bin/bash
 
-VERSION=`head -n 3 NEWS | tail -n 1| awk '{ print $5 }'`
-DATE=`head -n 1 NEWS | cut -f 1 -d ' '`
+VERSION=`head -n 3 ../NEWS | tail -n 1| awk '{ print $5 }'`
+DATE=`head -n 1 ../NEWS | cut -f 1 -d ' '`
 RVERSION="`echo 'version; quit()' | R  --no-save 2>&1 | grep version\.string | cut -f 4 -d ' '`"
 PLATFORM=`echo 'R.version$platform' | R --no-save 2>/dev/null | grep '\[1\]' | cut -f 2 -d '"'`
 DATE="`date '+%Y-%m-%d %H:%M:%S'`"
@@ -15,7 +15,7 @@ Version: $VERSION
 Date: $DATE
 Title: The SHOGUN Machine Learning Toolbox
 Author: Soeren Sonnenburg, Gunnar Raetsch
-Maintainer: Soeren Sonnenburg <Soeren.Sonnenburg@first.fraunhofer.de>
+Maintainer: Soeren Sonnenburg <sonne@debian.org>
 Depends: R (>= 2.1.0)
 Suggests:
 Description: SHOGUN - is a new machine learning toolbox with focus on large
@@ -43,7 +43,7 @@ echo "x=structure(list(DESCRIPTION = c(Package='$2',\
 		Date=\"$DATE\",\
 		Title=\"The SHOGUN Machine Learning Toolbox\",\
 		Author=\"Soeren Sonnenburg, Gunnar Raetsch\",\
-		Maintainer=\"Soeren.Sonnenburg@first.fraunhofer.de\",\
+		Maintainer=\"sonne@debian.org\",\
 		Depends=\"R (>= $RVERSION)\"),\
 		Built = list(R=\"$RVERSION\", Platform=\"$PLATFORM\", Date=\"$DATE\", OStype=\"$OSTYPE\"),\
 		Rdepends = list(name='R', op='>=', version='2.1.0'),\
@@ -55,9 +55,9 @@ echo "x=structure(list(DESCRIPTION = c(Package='$2',\
 		.saveRDS(x, \"$PKGFILE\")" | R --no-save
 
 # R STATIC
-if [ "$2" = "sg" ]
+if test "$2" = "sg" || test "$2" = "elwms"
 then
-echo "Installing static sg interface for R"
+echo "Installing static sg/elwms interface for R"
 cat >"$1/$2/R/$2" <<EOF
 .packageName <- "$2"
 # The purpose of this file is to supply no functionality
@@ -138,12 +138,12 @@ cat >"$1/$2/R/$2" <<EOF
 	cat(paste("\nWelcome! This is SHOGUN version $VERSION\n"))
 EOF
 
-for f in */*.so
+for f in *.so
 do
 	echo "library.dynam(\"`basename $f`\", pkg, lib)" >> "$1/$2/R/$2"
 done
 
-for f in */*.RData
+for f in *.RData
 do
 	echo "load(paste(lib, \"/\", \"$2\", \"/R/\", \"`basename $f`\", sep=''), envir=.GlobalEnv)" >> "$1/$2/R/$2"
 	echo "cacheMetaData(1)" >> "$1/$2/R/$2"
@@ -156,7 +156,7 @@ cat >>"$1/$2/R/$2" <<EOF
 {
 EOF
 
-for f in */*.so
+for f in *.$3
 do
 	echo "library.dynam.unload(\"$f\", lib)" >> "$1/$2/R/$2"
 done
