@@ -4,7 +4,7 @@
 #include <shogun/lib/ShogunException.h>
 #include <shogun/lib/io.h>
 #include <shogun/lib/AsciiFile.h>
-#include <shogun/ui/SGInterface.h>
+#include "ui/SGInterface.h"
 
 #ifdef HAVE_READLINE
 #include <readline/readline.h>
@@ -53,8 +53,8 @@ CCmdLineInterface::CCmdLineInterface()
 
 CCmdLineInterface::~CCmdLineInterface()
 {
-	SG_UNREF(m_lhs);
-	SG_UNREF(m_rhs);
+	delete m_lhs;
+	delete m_rhs;
 }
 
 void CCmdLineInterface::reset(const char* line)
@@ -69,9 +69,9 @@ void CCmdLineInterface::reset(const char* line)
 	const char delim_lhs[]="=, \t\n";
 	const char delim_rhs[]=" \t\n";
 
-	SG_UNREF(m_lhs);
+	delete m_lhs;
 	m_lhs=NULL;
-	SG_UNREF(m_rhs);
+	delete m_rhs;
 	m_rhs=NULL;
 
 	/* split lhs from rhs
@@ -87,7 +87,7 @@ void CCmdLineInterface::reset(const char* line)
 		element=strtok((char*) line, delim_lhs);
 		if (element)
 		{
-			m_lhs=new CDynamicArray<char*>();
+			m_lhs=new DynArray<char*>();
 			m_lhs->append_element(element);
 			m_nlhs++;
 			while ((element=strtok(NULL, delim_lhs)))
@@ -105,7 +105,7 @@ void CCmdLineInterface::reset(const char* line)
 
 	if (element)
 	{
-		m_rhs=new CDynamicArray<char*>();
+		m_rhs=new DynArray<char*>();
 		m_rhs->append_element(element);
 		m_nrhs++;
 		while ((element=strtok(NULL, delim_rhs)))
@@ -370,14 +370,14 @@ void CCmdLineInterface::get_real_sparsematrix(TSparse<float64_t>*& matrix, int32
 }
 
 
-void CCmdLineInterface::get_byte_string_list(T_STRING<uint8_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CCmdLineInterface::get_byte_string_list(TString<uint8_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CCmdLineInterface::get_char_string_list(T_STRING<char>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CCmdLineInterface::get_char_string_list(TString<char>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	const char* filename=get_arg_increment();
 	if (!filename)
@@ -387,21 +387,21 @@ void CCmdLineInterface::get_char_string_list(T_STRING<char>*& strings, int32_t&
 	f.get_char_string_list(strings, num_str, max_string_len);
 }
 
-void CCmdLineInterface::get_int_string_list(T_STRING<int32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CCmdLineInterface::get_int_string_list(TString<int32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CCmdLineInterface::get_short_string_list(T_STRING<int16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CCmdLineInterface::get_short_string_list(TString<int16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CCmdLineInterface::get_word_string_list(T_STRING<uint16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CCmdLineInterface::get_word_string_list(TString<uint16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
@@ -491,7 +491,7 @@ void CCmdLineInterface::set_real_sparsematrix(const TSparse<float64_t>* matrix,
 }
 
 #define SET_STRING_LIST(fname, sg_type)	\
-void CCmdLineInterface::fname(const T_STRING<sg_type>* strings, int32_t num_str)		\
+void CCmdLineInterface::fname(const TString<sg_type>* strings, int32_t num_str)		\
 {																						\
 	const char* filename=set_arg_increment();											\
 	if (!filename)																		\
@@ -525,7 +525,7 @@ bool CCmdLineInterface::skip_line(const char* line)
 
 	//SG_PRINT("ascii(0) %d, %c\n", int(line[0]), line[0]);
 
-	char* skipped=CIO::skip_blanks((char*) line);
+	char* skipped=IO::skip_blanks((char*) line);
 	if (skipped[0]==CMDLINE_COMMENT0 || skipped[0]==CMDLINE_COMMENT1)
 		return true;
 
