@@ -1,7 +1,9 @@
 #ifndef __CMDLINEINTERFACE__H_
 #define __CMDLINEINTERFACE__H_
 
-#include <shogun/ui/SGInterface.h>
+#include <shogun/base/DynArray.h>
+
+#include "ui/SGInterface.h"
 
 namespace shogun
 {
@@ -70,19 +72,19 @@ class CCmdLineInterface : public CSGInterface
 			TSparse<float64_t>*& matrix, int32_t& num_feat, int32_t& num_vec);
 
 		virtual void get_byte_string_list(
-			T_STRING<uint8_t>*& strings, int32_t& num_str,
+			TString<uint8_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_char_string_list(
-			T_STRING<char>*& strings, int32_t& num_str,
+			TString<char>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_int_string_list(
-			T_STRING<int32_t>*& strings, int32_t& num_str,
+			TString<int32_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_short_string_list(
-			T_STRING<int16_t>*& strings, int32_t& num_str,
+			TString<int16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_word_string_list(
-			T_STRING<uint16_t>*& strings, int32_t& num_str,
+			TString<uint16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 
 		virtual void get_attribute_struct(
@@ -122,15 +124,15 @@ class CCmdLineInterface : public CSGInterface
 			int32_t num_vec, int64_t nnz);
 
 		virtual void set_byte_string_list(
-			const T_STRING<uint8_t>* strings, int32_t num_str);
+			const TString<uint8_t>* strings, int32_t num_str);
 		virtual void set_char_string_list(
-			const T_STRING<char>* strings, int32_t num_str);
+			const TString<char>* strings, int32_t num_str);
 		virtual void set_int_string_list(
-			const T_STRING<int32_t>* strings, int32_t num_str);
+			const TString<int32_t>* strings, int32_t num_str);
 		virtual void set_short_string_list(
-			const T_STRING<int16_t>* strings, int32_t num_str);
+			const TString<int16_t>* strings, int32_t num_str);
 		virtual void set_word_string_list(
-			const T_STRING<uint16_t>* strings, int32_t num_str);
+			const TString<uint16_t>* strings, int32_t num_str);
 
 		virtual void set_attribute_struct(
 			const CDynamicArray<T_ATTRIBUTE>* attrs);
@@ -172,8 +174,8 @@ class CCmdLineInterface : public CSGInterface
 		inline virtual const char* get_name() const { return "CmdLineInterface"; }
 
 	private:
-		CDynamicArray<char*>* m_lhs;
-		CDynamicArray<char*>* m_rhs;
+		DynArray<char*>* m_lhs;
+		DynArray<char*>* m_rhs;
 };
 }
 #endif // __CMDLINEINTERFACE__H_
