@@ -9,19 +9,17 @@
  */
 
 #include "classifier/Classifier.h"
-
-
-#ifdef HAVE_BOOST_SERIALIZATION
-#include <boost/serialization/export.hpp>
-BOOST_CLASS_EXPORT_GUID(shogun::CClassifier, "CClassifier");
-//BOOST_SERIALIZATION_ASSUME_ABSTRACT(shogun::CClassifier);
-#endif //HAVE_BOOST_SERIALIZATION
+#include "base/Parameter.h"
 
 using namespace shogun;
 
 CClassifier::CClassifier() : CSGObject(), max_train_time(0), labels(NULL),
 	solver_type(ST_AUTO)
 {
+	m_parameters->add(&max_train_time, "max_train_time",
+					  "Maximum training time.");
+	m_parameters->add((machine_int_t*) &solver_type, "solver_type");
+	m_parameters->add((CSGObject**) &labels, "labels");
 }
 
 CClassifier::~CClassifier()
