@@ -49,7 +49,8 @@ namespace shogun
  * \sa CLinearClassifier
  * \sa http://en.wikipedia.org/wiki/Linear_discriminant_analysis
  */
-class CLDA : public CLinearClassifier
+#define IGNORE_IN_CLASSLIST
+IGNORE_IN_CLASSLIST class CLDA : public CLinearClassifier
 {
 	public:
 		/** constructor
