@@ -9,12 +9,18 @@
  */
 
 #include "classifier/LinearClassifier.h"
+#include "base/Parameter.h"
 
 using namespace shogun;
 
 CLinearClassifier::CLinearClassifier()
 : CClassifier(), w_dim(0), w(NULL), bias(0), features(NULL)
 {
+
+	m_parameters->add_vector(&w, &w_dim, "w", "Parameter vector w.");
+	m_parameters->add(&bias, "bias", "Bias b.");
+	m_parameters->add((CSGObject**) &features, "features", "Feature object.");
+
 }
 
 CLinearClassifier::~CLinearClassifier()
@@ -25,11 +31,15 @@ CLinearClassifier::~CLinearClassifier()
 
 bool CLinearClassifier::load(FILE* srcfile)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
 bool CLinearClassifier::save(FILE* dstfile)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
