@@ -13,7 +13,7 @@
 
 
 #include "lib/common.h"
-#include "classifier/svm/SVM_light.h"
+#include "classifier/svm/SVMLight.h"
 
 #include <stdio.h>
 
@@ -22,13 +22,11 @@ namespace shogun
 /** @brief class DomainAdaptiveSVM */
 class CDomainAdaptationSVM : public CSVMLight
 {
-
 	public:
 
 		/** default constructor */
 		CDomainAdaptationSVM();
 
-
 		/** constructor
 		 *
 		 * @param C cost constant C
@@ -39,11 +37,9 @@ class CDomainAdaptationSVM : public CSVMLight
 		 */
 		CDomainAdaptationSVM(float64_t C, CKernel* k, CLabels* lab, CSVM* presvm, float64_t B);
 
-
 		/** destructor */
 		virtual ~CDomainAdaptationSVM();
 
-
 		/** init SVM
 		 *
 		 * @param presvm trained SVM to regularize against
@@ -51,7 +47,6 @@ class CDomainAdaptationSVM : public CSVMLight
 		 * */
 		void init(CSVM* presvm, float64_t B);
 
-
 		/** train SVM classifier
 		 *
 		 * @param data training data (parameter can be avoided if distance or
@@ -62,14 +57,12 @@ class CDomainAdaptationSVM : public CSVMLight
 		 */
 		virtual bool train(CFeatures* data=NULL);
 
-
 		/** get classifier type
 		 *
 		 * @return classifier type LIGHT
 		 */
 		virtual inline EClassifierType get_classifier_type() { return CT_DASVM; }
 
-
 		/** classify objects
 		 *
 		 * @param data (test)data to be classified
@@ -77,66 +70,32 @@ class CDomainAdaptationSVM : public CSVMLight
 		 */
 		virtual CLabels* classify(CFeatures* data);
 
-
 		/** returns SVM that is used as prior information
 		 *
 		 * @return presvm
 		 */
 		virtual CSVM* get_presvm();
 
-
 		/** getter for regularization parameter B
 		 *
 		 * @return regularization parameter B
 		 */
 		virtual float64_t get_B();
 
-
 		/** getter for train_factor
 		 *
 		 * @return train_factor
 		 */
 		virtual float64_t get_train_factor();
 
-
 		/** setter for train_factor
 		 *
 		 */
 		virtual void set_train_factor(float64_t factor);
 
-
 		/** @return object name */
 		inline virtual const char* get_name() const { return "DomainAdaptationSVM"; }
 
-
-	private:
-
-#ifdef HAVE_BOOST_SERIALIZATION
-		friend class ::boost::serialization::access;
-		// When the class Archive corresponds to an output archive, the
-		// & operator is defined similar to <<.  Likewise, when the class Archive
-		// is a type of input archive the & operator is defined similar to >>.
-		template<class Archive>
-		void serialize(Archive & ar, const unsigned int archive_version)
-		{
-
-			SG_DEBUG("archiving CDomainAdaptationSVM\n");
-
-			// serialize base class
-			ar & ::boost::serialization::base_object<CSVMLight>(*this);
-
-			// serialize remaining fields
-			ar & presvm;
-
-			ar & B;
-
-			ar & train_factor;
-
-			SG_DEBUG("done archiving CDomainAdaptationSVM\n");
-
-		}
-#endif //HAVE_BOOST_SERIALIZATION
-
 	protected:
 
 		/** check sanity of presvm
@@ -145,18 +104,19 @@ class CDomainAdaptationSVM : public CSVMLight
 		 */
 		virtual bool is_presvm_sane();
 
+	private:
+		void init();
+
+	protected:
 
 		/** SVM to regularize against */
 		CSVM* presvm;
 
-
 		/** regularization parameter B */
 		float64_t B;
 
-
 		/** flag to switch off regularization in training */
 		float64_t train_factor;
-
 };
 }
 #endif
