@@ -14,6 +14,7 @@
 #include "lib/io.h"
 #include "lib/Signal.h"
 #include "lib/Time.h"
+#include "base/Parameter.h"
 #include "classifier/svm/LibLinear.h"
 #include "classifier/svm/SVM_linear.h"
 #include "classifier/svm/Tron.h"
@@ -21,35 +22,62 @@
 
 using namespace shogun;
 
+CLibLinear::CLibLinear(void)
+: CLinearClassifier()
+{
+    init();
+}
+
 CLibLinear::CLibLinear(LIBLINEAR_SOLVER_TYPE l)
 : CLinearClassifier()
 {
-	liblinear_solver_type=l;
-	use_bias=false;
-	C1=1;
-	C2=1;
-	set_max_iterations();
+    init();
 }
 
 CLibLinear::CLibLinear(
 	float64_t C, CDotFeatures* traindat, CLabels* trainlab)
-: CLinearClassifier(), C1(C), C2(C), use_bias(true), epsilon(1e-5)
+: CLinearClassifier()
 {
+    init();
+	C1=C;
+	C2=C;
+	use_bias=true;
+	epsilon=1e-5;
+
 	set_features(traindat);
 	set_labels(trainlab);
-	liblinear_solver_type=L2R_L1LOSS_SVC_DUAL;
-	set_max_iterations();
+	init_linear_term();
 }
 
+void CLibLinear::init()
+{
+	liblinear_solver_type=L2R_L1LOSS_SVC_DUAL;
+	use_bias=false;
+	C1=1;
+	C2=1;
+	set_max_iterations();
+	m_linear_term=NULL;
+	m_linear_term_len=0;
+
+    m_parameters->add(&C1, "C1",  "C Cost constant 1.");
+    m_parameters->add(&C2, "C2",  "C Cost constant 2.");
+    m_parameters->add(&use_bias, "use_bias",  "Indicates if bias is used.");
+    m_parameters->add(&epsilon, "epsilon",  "Convergence precision.");
+    m_parameters->add(&max_iterations, "max_iterations",  "Max number of iterations.");
+    m_parameters->add_vector(&m_linear_term, &m_linear_term_len, "linear_term", "Linear Term");
+    m_parameters->add((machine_int_t*) &liblinear_solver_type, "liblinear_solver_type", "Type of LibLinear solver.");
+}
 
 CLibLinear::~CLibLinear()
 {
+	delete[] m_linear_term;
 }
 
 bool CLibLinear::train(CFeatures* data)
 {
 	CSignal::clear_cancel();
 	ASSERT(labels);
+
 	if (data)
 	{
 		if (!data->has_property(FP_DOT))
@@ -192,14 +220,14 @@ bool CLibLinear::train(CFeatures* data)
 	return true;
 }
 
-// A coordinate descent algorithm for 
+// A coordinate descent algorithm for
 // L1-loss and L2-loss SVM dual problems
 //
 //  min_\alpha  0.5(\alpha^T (Q + D)\alpha) - e^T \alpha,
 //    s.t.      0 <= alpha_i <= upper_bound_i,
-// 
+//
 //  where Qij = yi yj xi^T xj and
-//  D is a diagonal matrix 
+//  D is a diagonal matrix
 //
 // In L1-SVM case:
 // 		upper_bound_i = Cp if y_i = 1
@@ -210,7 +238,7 @@ bool CLibLinear::train(CFeatures* data)
 // 		D_ii = 1/(2*Cp)	if y_i = 1
 // 		D_ii = 1/(2*Cn)	if y_i = -1
 //
-// Given: 
+// Given:
 // x, y, Cp, Cn
 // eps is the stopping tolerance
 //
@@ -257,12 +285,13 @@ void CLibLinear::solve_l2r_l1l2_svc(
 
 	for(i=0; i<w_size; i++)
 		w[i] = 0;
+
 	for(i=0; i<l; i++)
 	{
 		alpha[i] = 0;
 		if(prob->y[i] > 0)
 		{
-			y[i] = +1; 
+			y[i] = +1;
 		}
 		else
 		{
@@ -270,10 +299,11 @@ void CLibLinear::solve_l2r_l1l2_svc(
 		}
 		QD[i] = diag[GETI(i)];
 
-		QD[i] += prob->x->dot(i,i);
+		QD[i] += prob->x->dot(i, prob->x,i);
 		index[i] = i;
 	}
 
+
 	CTime start_time;
 	while (iter < max_iterations && !CSignal::cancel_computations())
 	{
@@ -298,7 +328,10 @@ void CLibLinear::solve_l2r_l1l2_svc(
 			if (prob->use_bias)
 				G+=w[n];
 
-			G = G*yi-1;
+			if (m_linear_term)
+				G = G*yi + m_linear_term[i];
+			else
+				G = G*yi-1;
 
 			C = upper_bound[GETI(i)];
 			G += alpha[i]*diag[GETI(i)];
@@ -400,12 +433,12 @@ void CLibLinear::solve_l2r_l1l2_svc(
 	delete [] index;
 }
 
-// A coordinate descent algorithm for 
+// A coordinate descent algorithm for
 // L1-regularized L2-loss support vector classification
 //
 //  min_w \sum |wj| + C \sum max(0, 1-yi w^T xi)^2,
 //
-// Given: 
+// Given:
 // x, y, Cp, Cn
 // eps is the stopping tolerance
 //
@@ -477,7 +510,7 @@ void CLibLinear::solve_l1r_l2_svc(
 			x->free_feature_iterator(iterator);
 		}
 	}
-	
+
 
 	CTime start_time;
 	while (iter < max_iterations && !CSignal::cancel_computations())
@@ -745,12 +778,12 @@ void CLibLinear::solve_l1r_l2_svc(
 	delete [] xj_sq;
 }
 
-// A coordinate descent algorithm for 
+// A coordinate descent algorithm for
 // L1-regularized logistic regression problems
 //
 //  min_w \sum |wj| + C \sum log(1+exp(-yi w^T xi)),
 //
-// Given: 
+// Given:
 // x, y, Cp, Cn
 // eps is the stopping tolerance
 //
@@ -761,7 +794,7 @@ void CLibLinear::solve_l1r_l2_svc(
 // To support weights for instances, use GETI(i) (i)
 
 void CLibLinear::solve_l1r_lr(
-	const problem *prob_col, double eps, 
+	const problem *prob_col, double eps,
 	double Cp, double Cn)
 {
 	int l = prob_col->l;
@@ -1082,7 +1115,7 @@ void CLibLinear::solve_l1r_lr(
 		SG_WARNING("\nWARNING: reaching max number of iterations\n");
 
 	// calculate objective value
-	
+
 	double v = 0;
 	int nnz = 0;
 	for(j=0; j<w_size; j++)
@@ -1110,5 +1143,27 @@ void CLibLinear::solve_l1r_lr(
 	delete [] xjpos_sum;
 }
 
+void CLibLinear::get_linear_term(float64_t** linear_term, int32_t* len)
+{
+	if (!m_linear_term_len || !m_linear_term)
+		SG_ERROR("Please assign linear term first!\n");
+
+	*linear_term=(float64_t*) malloc(sizeof(float64_t)*m_linear_term_len);
+
+	for (int32_t i=0; i<m_linear_term_len; i++)
+		(*linear_term)[i]=m_linear_term[i];
+}
+
+void CLibLinear::init_linear_term()
+{
+	if (!labels)
+		SG_ERROR("Please assign labels first!\n");
+
+	delete[] m_linear_term;
+
+	m_linear_term_len=labels->get_num_labels();
+	m_linear_term = new float64_t[m_linear_term_len];
+	CMath::fill_vector(m_linear_term, m_linear_term_len, -1.0);
+}
 
 #endif //HAVE_LAPACK
