@@ -12,31 +12,36 @@
 #include "features/Labels.h"
 #include "lib/Mathematics.h"
 #include "lib/Time.h"
+#include "base/Parameter.h"
 #include "base/Parallel.h"
 #include "classifier/LinearClassifier.h"
 #include "classifier/svm/SVMOcas.h"
-#include "classifier/svm/libocas.h"
 #include "features/DotFeatures.h"
 #include "features/Labels.h"
 
 using namespace shogun;
 
-CSVMOcas::CSVMOcas(E_SVM_TYPE type)
-: CLinearClassifier(), use_bias(true), bufsize(3000), C1(1), C2(1),
-	epsilon(1e-3), method(type)
+CSVMOcas::CSVMOcas()
+: CLinearClassifier()
 {
-	w=NULL;
-	old_w=NULL;
+	init();
+}
+
+CSVMOcas::CSVMOcas(E_SVM_TYPE type)
+: CLinearClassifier()
+{
+	init();
+	method=type;
 }
 
 CSVMOcas::CSVMOcas(
 	float64_t C, CDotFeatures* traindat, CLabels* trainlab)
-: CLinearClassifier(), use_bias(true), bufsize(3000), C1(C), C2(C),
-	epsilon(1e-3)
+: CLinearClassifier()
 {
-	w=NULL;
-	old_w=NULL;
-	method=SVM_OCAS;
+	init();
+	C1=C;
+	C2=C;
+
 	set_features(traindat);
 	set_labels(trainlab);
 }
@@ -66,8 +71,8 @@ bool CSVMOcas::train(CFeatures* data)
 	w_dim=features->get_dim_feature_space();
 	int32_t num_vec=features->get_num_vectors();
 
-	ASSERT(num_vec==num_train_labels);
-	ASSERT(num_vec>0);
+	if (num_vec!=num_train_labels || num_vec<=0)
+		SG_ERROR("num_vec=%d num_train_labels=%d\n", num_vec, num_train_labels);
 
 	delete[] w;
 	w=new float64_t[w_dim];
@@ -81,7 +86,9 @@ bool CSVMOcas::train(CFeatures* data)
 
 	tmp_a_buf=new float64_t[w_dim];
 	cp_value=new float64_t*[bufsize];
+	memset(cp_value, sizeof(float64_t*)*bufsize, 0);
 	cp_index=new uint32_t*[bufsize];
+	memset(cp_index, sizeof(float64_t*)*bufsize, 0);
 	cp_nz_dims=new uint32_t[bufsize];
 	cp_bias=new float64_t[bufsize];
 	memset(cp_bias, 0, sizeof(float64_t)*bufsize);
@@ -92,12 +99,13 @@ bool CSVMOcas::train(CFeatures* data)
 	if (method == SVM_OCAS)
 		Method = 1;
 	ocas_return_value_T result = svm_ocas_solver( get_C1(), num_vec, get_epsilon(),
-			TolAbs, QPBound, bufsize, Method, 
+			TolAbs, QPBound, get_max_train_time(), bufsize, Method, 
 			&CSVMOcas::compute_W,
 			&CSVMOcas::update_W, 
 			&CSVMOcas::add_new_cut, 
 			&CSVMOcas::compute_output,
 			&CSVMOcas::sort,
+			&CSVMOcas::print,
 			this);
 
 	SG_INFO("Ocas Converged after %d iterations\n"
@@ -109,15 +117,18 @@ bool CSVMOcas::train(CFeatures* data)
 			"w_time: %f s\n"
 			"solver_time %f s\n"
 			"ocas_time %f s\n\n", result.nIter, result.output_time, result.sort_time,
-			result.add_time, result.w_time, result.solver_time, result.ocas_time);
+			result.add_time, result.w_time, result.qp_solver_time, result.ocas_time);
 
 	delete[] tmp_a_buf;
 
 	uint32_t num_cut_planes = result.nCutPlanes;
 
+	SG_DEBUG("num_cut_planes=%d\n", num_cut_planes);
 	for (uint32_t i=0; i<num_cut_planes; i++)
 	{
+		SG_DEBUG("cp_value[%d]=%p\n", i, cp_value);
 		delete[] cp_value[i];
+		SG_DEBUG("cp_index[%d]=%p\n", i, cp_index);
 		delete[] cp_index[i];
 	}
 
@@ -173,7 +184,7 @@ float64_t CSVMOcas::update_W( float64_t t, void* ptr )
     sparse_A(:,nSel+1) = new_a;
 
   ---------------------------------------------------------------------------------*/
-void CSVMOcas::add_new_cut(
+int CSVMOcas::add_new_cut(
 	float64_t *new_col_H, uint32_t *new_cut, uint32_t cut_length,
 	uint32_t nSel, void* ptr)
 {
@@ -214,6 +225,9 @@ void CSVMOcas::add_new_cut(
 
 	/* sparsify new_a and insert it to the last column of sparse_A */
 	c_nzd[nSel] = nz_dims;
+	c_idx[nSel]=NULL;
+	c_val[nSel]=NULL;
+
 	if(nz_dims > 0)
 	{
 		c_idx[nSel]=new uint32_t[nz_dims];
@@ -243,11 +257,13 @@ void CSVMOcas::add_new_cut(
 	//CMath::display_vector(new_col_H, nSel+1, "new_col_H");
 	//CMath::display_vector((int32_t*) c_idx[nSel], (int32_t) nz_dims, "c_idx");
 	//CMath::display_vector((float64_t*) c_val[nSel], nz_dims, "c_val");
+	return 0;
 }
 
-void CSVMOcas::sort(float64_t* vals, uint32_t* idx, uint32_t size)
+int CSVMOcas::sort(float64_t* vals, float64_t* data, uint32_t size)
 {
-	CMath::qsort_index(vals, idx, size);
+	CMath::qsort_index(vals, data, size);
+	return 0;
 }
 
 /*----------------------------------------------------------------------
@@ -255,7 +271,7 @@ void CSVMOcas::sort(float64_t* vals, uint32_t* idx, uint32_t size)
 
   output = data_X'*W;
   ----------------------------------------------------------------------*/
-void CSVMOcas::compute_output(float64_t *output, void* ptr)
+int CSVMOcas::compute_output(float64_t *output, void* ptr)
 {
 	CSVMOcas* o = (CSVMOcas*) ptr;
 	CDotFeatures* f=o->features;
@@ -269,6 +285,7 @@ void CSVMOcas::compute_output(float64_t *output, void* ptr)
 		output[i]+=y[i]*o->bias;
 	//CMath::display_vector(o->w, o->w_dim, "w");
 	//CMath::display_vector(output, nData, "out");
+	return 0;
 }
 
 /*----------------------------------------------------------------------
@@ -317,3 +334,31 @@ void CSVMOcas::compute_W(
 	o->bias = bias;
 	o->old_bias = old_bias;
 }
+
+void CSVMOcas::init()
+{
+	use_bias=true;
+	bufsize=3000;
+	C1=1;
+	C2=1;
+
+	epsilon=1e-3;
+	method=SVM_OCAS;
+	w=NULL;
+	old_w=NULL;
+	tmp_a_buf=NULL;
+	lab=NULL;
+	cp_value=NULL;
+	cp_index=NULL;
+	cp_nz_dims=NULL;
+	cp_bias=NULL;
+
+    m_parameters->add(&C1, "C1",  "Cost constant 1.");
+    m_parameters->add(&C2, "C2",  "Cost constant 2.");
+    m_parameters->add(&use_bias, "use_bias",
+			"Indicates if bias is used.");
+    m_parameters->add(&epsilon, "epsilon", "Convergence precision.");
+    m_parameters->add(&bufsize, "bufsize", "Maximum number of cutting planes.");
+    m_parameters->add((machine_int_t*) &method, "method",
+			"SVMOcas solver type.");
+}
