@@ -67,7 +67,7 @@ class CCanberraMetric: public CSimpleDistance<float64_t>
 		 *
 		 * @return name Canberra-Metric
 		 */
-		virtual const char* get_name() const { return "Canberra-Metric"; }
+		virtual const char* get_name() const { return "CanberraMetric"; }
 
 	protected:
 		/// compute distance for features a and b
