@@ -10,30 +10,38 @@
  */
 
 #include "lib/common.h"
+#include "lib/io.h"
+
+#include "base/Parameter.h"
+
 #include "distance/HammingWordDistance.h"
 #include "features/Features.h"
 #include "features/StringFeatures.h"
-#include "lib/io.h"
 
 using namespace shogun;
 
-CHammingWordDistance::CHammingWordDistance(bool sign)
-: CStringDistance<uint16_t>(), use_sign(sign)
+CHammingWordDistance::CHammingWordDistance()
 {
+	init();
+}
+
+CHammingWordDistance::CHammingWordDistance(bool sign)
+: CStringDistance<uint16_t>()
+{
+	init();
+	use_sign=sign;
+
 	SG_DEBUG( "CHammingWordDistance with sign: %d created\n", (sign) ? 1 : 0);
-	dictionary_size= 1<<(sizeof(uint16_t)*8);
-	dictionary_weights = new float64_t[dictionary_size];
-	SG_DEBUG( "using dictionary of %d bytes\n", dictionary_size);
 }
 
 CHammingWordDistance::CHammingWordDistance(
 	CStringFeatures<uint16_t>* l, CStringFeatures<uint16_t>* r, bool sign)
-: CStringDistance<uint16_t>(), use_sign(sign)
+: CStringDistance<uint16_t>()
 {
+	init();
+	use_sign=sign;
+
 	SG_DEBUG( "CHammingWordDistance with sign: %d created\n", (sign) ? 1 : 0);
-	dictionary_size= 1<<(sizeof(uint16_t)*8);
-	dictionary_weights = new float64_t[dictionary_size];
-	SG_DEBUG( "using dictionary of %d bytes\n", dictionary_size);
 
 	init(l, r);
 }
@@ -41,8 +49,6 @@ CHammingWordDistance::CHammingWordDistance(
 CHammingWordDistance::~CHammingWordDistance()
 {
 	cleanup();
-
-	delete[] dictionary_weights;
 }
   
 bool CHammingWordDistance::init(CFeatures* l, CFeatures* r)
@@ -164,3 +170,10 @@ float64_t CHammingWordDistance::compute(int32_t idx_a, int32_t idx_b)
 
 	return result;
 }
+
+void CHammingWordDistance::init()
+{
+	use_sign = false;
+	m_parameters->add(&use_sign, "use_sign",
+			"If signum(counts) is used instead of counts.");
+}
