@@ -25,6 +25,9 @@ namespace shogun
 class CHammingWordDistance: public CStringDistance<uint16_t>
 {
 	public:
+		/** default constructor  */
+		CHammingWordDistance();
+
 		/** constructor
 		 *
 		 * @param use_sign if sign shall be used
@@ -61,18 +64,7 @@ class CHammingWordDistance: public CStringDistance<uint16_t>
 		 *
 		 * @return name HammingWord
 		 */
-		virtual const char* get_name() const { return "HammingWord"; }
-
-		/** get dictionary weights
-		 *
-		 * @param dsize size of the dictionary
-		 * @param dweights dictionary weights are stored in here
-		 */
-		void get_dictionary(int32_t& dsize, float64_t*& dweights)
-		{
-			dsize=dictionary_size;
-			dweights = dictionary_weights;
-		}
+		virtual const char* get_name() const { return "HammingWordDistance"; }
 
 	protected:
 		/// compute kernel function for features a and b
@@ -80,11 +72,10 @@ class CHammingWordDistance: public CStringDistance<uint16_t>
 		/// in the corresponding feature object
 		float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
-		/** size of the dictionary */
-		int32_t dictionary_size;
-		/** dictionary weights */
-		float64_t* dictionary_weights;
 		/** if sign shall be used */
 		bool use_sign;
 };
