@@ -11,21 +11,33 @@
 #include "lib/config.h"
 #include "lib/common.h"
 #include "lib/io.h"
+
+#include "base/Parameter.h"
+
 #include "distance/MinkowskiMetric.h"
 #include "features/Features.h"
 #include "features/SimpleFeatures.h"
 
 using namespace shogun;
 
-CMinkowskiMetric::CMinkowskiMetric(float64_t k_)
-: CSimpleDistance<float64_t>(), k(k_)
+CMinkowskiMetric::CMinkowskiMetric() : CSimpleDistance<float64_t>()
 {
+	init();
+}
+
+CMinkowskiMetric::CMinkowskiMetric(float64_t k_)
+: CSimpleDistance<float64_t>()
+{
+	init();
+	k=k_;
 }
 
 CMinkowskiMetric::CMinkowskiMetric(
 	CSimpleFeatures<float64_t>* l, CSimpleFeatures<float64_t>* r, float64_t k_)
-: CSimpleDistance<float64_t>(), k(k_)
+: CSimpleDistance<float64_t>()
 {
+	init();
+	k=k_;
 	init(l, r);
 }
 
@@ -36,9 +48,7 @@ CMinkowskiMetric::~CMinkowskiMetric()
 
 bool CMinkowskiMetric::init(CFeatures* l, CFeatures* r)
 {
-	bool result=CSimpleDistance<float64_t>::init(l,r);
-
-	return result;
+	return CSimpleDistance<float64_t>::init(l,r);
 }
 
 void CMinkowskiMetric::cleanup()
@@ -75,3 +85,9 @@ float64_t CMinkowskiMetric::compute(int32_t idx_a, int32_t idx_b)
 
 	return pow(result,1/k);
 }
+
+void CMinkowskiMetric::init()
+{
+	k = 2.0;
+	m_parameters->add(&k, "k", "L_k norm.");
+}
