@@ -40,6 +40,9 @@ namespace shogun
 class CMinkowskiMetric: public CSimpleDistance<float64_t>
 {
 	public:
+		/** default constructor  */
+		CMinkowskiMetric();
+
 		/** constructor
 		 *
 		 * @param k parameter k
@@ -83,6 +86,9 @@ class CMinkowskiMetric: public CSimpleDistance<float64_t>
 		/// in the corresponding feature object
 		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
 		/** parameter k */
 		float64_t k;
