@@ -41,6 +41,9 @@ class CHMM;
 class CFKFeatures: public CSimpleFeatures<float64_t>
 {
 	public:
+		/** default constructor  */
+		CFKFeatures();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -127,6 +130,9 @@ class CFKFeatures: public CSimpleFeatures<float64_t>
 		 */
 		float64_t deriv_a(float64_t a, int32_t dimension=-1) ;
 
+	private:
+		void init();
+
 	protected:
 		/** positive HMM */
 		CHMM* pos;
