@@ -25,6 +25,9 @@ namespace shogun
 class CPolyFeatures : public CDotFeatures
 {
 	public:
+		/** default constructor  */
+		CPolyFeatures(void);
+
 		/** constructor
 		 * 
 		 * @param feat real features
@@ -98,10 +101,11 @@ class CPolyFeatures : public CDotFeatures
 		/** compute dot product between vector1 and vector2,
 		 *  appointed by their indices
 		 *
-		 *  @param vec_idx1 index of first vector
-		 *   @param vec_idx2 index of second vector
+		 * @param vec_idx1 index of first vector
+		 * @param df DotFeatures (of same kind) to compute dot product with
+		 * @param vec_idx2 index of second vector
 		 */
-		virtual float64_t dot(int32_t vec_idx1, int32_t vec_idx2);
+		virtual float64_t dot(int32_t vec_idx1, CDotFeatures* df, int32_t vec_idx2);
 
 		/**
 		 *
