@@ -25,6 +25,9 @@ namespace shogun
 class CRealFileFeatures: public CSimpleFeatures<float64_t>
 {
 	public:
+		/** default constructor */
+		CRealFileFeatures(void);
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -77,26 +80,6 @@ class CRealFileFeatures: public CSimpleFeatures<float64_t>
 		 */
 		bool load_base_data();
 
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
-
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void serialize(Archive & ar, const unsigned int archive_version)
-            {
-
-                SG_DEBUG("archiving CRealFeatures\n");
-
-                ar & ::boost::serialization::base_object<CSimpleFeatures<float64_t> >(*this);
-
-                SG_DEBUG("done with CRealFeatures\n");
-
-            }
-    
-#endif //HAVE_BOOST_SERIALIZATION
-
-
-
     protected:
 		/** working file */
 		FILE* working_file;
