@@ -21,6 +21,7 @@
 #include "preproc/SimplePreProc.h"
 #include "features/DotFeatures.h"
 #include "features/StringFeatures.h"
+#include "base/Parameter.h"
 
 #include <string.h>
 
@@ -68,22 +69,18 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		 * @param size cache size
 		 */
 		CSimpleFeatures(int32_t size=0)
-		: CDotFeatures(size), num_vectors(0), num_features(0),
-			feature_matrix(NULL), feature_cache(NULL) {}
+			: CDotFeatures(size)
+		{
+			init();
+		}
 
 		/** copy constructor */
 		CSimpleFeatures(const CSimpleFeatures & orig)
-		: CDotFeatures(orig), num_vectors(orig.num_vectors),
-			num_features(orig.num_features),
-			feature_matrix(orig.feature_matrix),
-			feature_cache(orig.feature_cache)
+		: CDotFeatures(orig)
 		{
-			if (orig.feature_matrix)
-			{
-				free_feature_matrix();
-				feature_matrix=new ST(num_vectors*num_features);
-				memcpy(feature_matrix, orig.feature_matrix, sizeof(float64_t)*int64_t(num_vectors)*num_features);
-			}
+			copy_feature_matrix(orig.feature_matrix,
+					orig.num_features, orig.num_vectors);
+			initialize_cache();
 		}
 
 		/** constructor
@@ -93,9 +90,9 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		 * @param num_vec number of vectors in matrix
 		 */
 		CSimpleFeatures(ST* src, int32_t num_feat, int32_t num_vec)
-		: CDotFeatures(0), num_vectors(0), num_features(0),
-			feature_matrix(NULL), feature_cache(NULL)
+		: CDotFeatures()
 		{
+			init();
 			copy_feature_matrix(src, num_feat, num_vec);
 		}
 
@@ -104,9 +101,9 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		 * @param loader File object via which to load data
 		 */
 		CSimpleFeatures(CFile* loader)
-		: CDotFeatures(loader), num_vectors(0), num_features(0),
-			feature_matrix(NULL), feature_cache(NULL)
+		: CDotFeatures(loader)
 		{
+			init();
 			load(loader);
 		}
 
@@ -121,7 +118,6 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 
 		virtual ~CSimpleFeatures()
 		{
-			SG_DEBUG("deleting simplefeatures (0x%p)\n", this);
 			free_features();
 		}
 
@@ -132,6 +128,8 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		{
             delete[] feature_matrix;
             feature_matrix = NULL;
+			feature_matrix_num_features=num_features;
+			feature_matrix_num_vectors=num_vectors;
             num_vectors=0;
             num_features=0;
 		}
@@ -142,8 +140,7 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		void free_features()
 		{
 			free_feature_matrix();
-            delete feature_cache;
-            feature_cache = NULL;
+			SG_UNREF(feature_cache);
 		}
 
 		/** get feature vector
@@ -167,8 +164,6 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 			} 
 			else
 			{
-				SG_DEBUG( "compute feature!!!\n") ;
-
 				ST* feat=NULL;
 				dofree=false;
 
@@ -210,7 +205,6 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 					delete[] tmp_feat_after;
 
 					len=tmp_len ;
-					SG_DEBUG( "len: %d len2: %d\n", len, num_features);
 				}
 				return feat ;
 			}
@@ -374,8 +368,12 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		{
 			free_feature_matrix();
 			feature_matrix=fm;
+			feature_matrix_num_features=num_feat;
+			feature_matrix_num_vectors=num_vec;
+
 			num_features=num_feat;
 			num_vectors=num_vec;
+			initialize_cache();
 		}
 
 		/** copy feature matrix
@@ -391,10 +389,14 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		{
 			free_feature_matrix();
 			feature_matrix=new ST[((int64_t) num_feat)*num_vec];
+			feature_matrix_num_features=num_feat;
+			feature_matrix_num_vectors=num_vec;
+
 			memcpy(feature_matrix, src, (sizeof(ST)*((int64_t) num_feat)*num_vec));
 
 			num_features=num_feat;
 			num_vectors=num_vec;
+			initialize_cache();
 		}
 
 		/** obtain simple features from other dotfeatures
@@ -410,6 +412,8 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 
 			free_feature_matrix();
 			feature_matrix=new ST[((int64_t) num_feat)*num_vec];
+			feature_matrix_num_features=num_feat;
+			feature_matrix_num_vectors=num_vec;
 
 			for (int32_t i=0; i<num_vec; i++)
 			{
@@ -494,12 +498,7 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		inline void set_num_features(int32_t num)
 		{ 
 			num_features= num;
-
-			if (num_features && num_vectors)
-			{
-				delete feature_cache;
-				feature_cache= new CCache<ST>(get_cache_size(), num_features, num_vectors);
-			}
+			initialize_cache();
 		}
 
 		/** set number of vectors
@@ -509,10 +508,17 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		inline void set_num_vectors(int32_t num)
 		{
 			num_vectors= num;
+			initialize_cache();
+		}
+
+		/* Initialize cache */
+		inline void initialize_cache()
+		{
 			if (num_features && num_vectors)
 			{
-				delete feature_cache;
+				SG_UNREF(feature_cache);
 				feature_cache= new CCache<ST>(get_cache_size(), num_features, num_vectors);
+				SG_REF(feature_cache);
 			}
 		}
 
@@ -562,20 +568,26 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		 * appointed by their indices
 		 *
 		 * @param vec_idx1 index of first vector
+		 * @param df DotFeatures (of same kind) to compute dot product with
 		 * @param vec_idx2 index of second vector
 		 */
-		virtual float64_t dot(int32_t vec_idx1, int32_t vec_idx2)
+		virtual float64_t dot(int32_t vec_idx1, CDotFeatures* df, int32_t vec_idx2)
 		{
+			ASSERT(df);
+			ASSERT(df->get_feature_type() == get_feature_type());
+			ASSERT(df->get_feature_class() == get_feature_class());
+			CSimpleFeatures<ST>* sf=(CSimpleFeatures<ST>*) df;
+
 			int32_t len1, len2;
 			bool free1, free2;
 
 			ST* vec1= get_feature_vector(vec_idx1, len1, free1);
-			ST* vec2= get_feature_vector(vec_idx2, len2, free2);
+			ST* vec2= sf->get_feature_vector(vec_idx2, len2, free2);
 
 			float64_t result=CMath::dot(vec1, vec2, len1);
 
 			free_feature_vector(vec1, vec_idx1, free1);
-			free_feature_vector(vec2, vec_idx2, free2);
+			sf->free_feature_vector(vec2, vec_idx2, free2);
 
 			return result;
 		}
@@ -735,67 +747,6 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 		/** @return object name */
 		inline virtual const char* get_name() const { return "SimpleFeatures"; }
 
-
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
-
-        /// serialization needs to split up in save/load because 
-        ///  the serialization of pointers to natives (int* & friends) 
-        ///  requires a workaround 
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void save(Archive & ar, const unsigned int archive_version) const
-            {
-
-                SG_DEBUG("archiving SimpleFeatures\n");
-
-                ar & ::boost::serialization::base_object<CDotFeatures>(*this);
-
-                //TODO
-                //ar & feature_cache;
-
-                ar & num_vectors;
-                ar & num_features;
-
-                for (int i=0; i < num_vectors*num_features; ++i) 
-                {
-                    ar & feature_matrix[i];
-                }
-
-                SG_DEBUG("done SimpleFeatures\n");
-
-
-            }
-
-        template<class Archive>
-            void load(Archive & ar, const unsigned int archive_version)
-            {
-
-                SG_DEBUG("archiving SimpleFeatures\n");
-
-                ar & ::boost::serialization::base_object<CDotFeatures>(*this);
-
-                //TODO
-                //ar & feature_cache;
-
-                ar & num_vectors;
-                ar & num_features;
-
-                feature_matrix = new ST[int64_t(num_vectors)*num_features];
-                for (int i=0; i< num_vectors*num_features; ++i){
-                    ar & feature_matrix[i];
-                }
-
-
-                SG_DEBUG("done SimpleFeatures\n");
-
-            }
-
-        GLOBAL_BOOST_SERIALIZATION_SPLIT_MEMBER();
-
-#endif //HAVE_BOOST_SERIALIZATION
-
-
 	protected:
 		/** compute feature vector for sample num
 		 * if target is set the vector is written to target
@@ -814,14 +765,42 @@ template <class ST> class CSimpleFeatures: public CDotFeatures
 			return NULL;
 		}
 
+	private:
+		void init()
+		{
+			num_vectors=0;
+			num_features=0;
+
+			feature_matrix=NULL;
+			feature_matrix_num_vectors=0;
+			feature_matrix_num_features=0;
+
+			feature_cache=NULL;
+
+			set_generic<ST>();
+			m_parameters->add(&num_vectors,
+						"num_vectors", "Number of vectors.");
+			m_parameters->add(&num_features,
+						"num_features", "Number of features.");
+			m_parameters->add_matrix(&feature_matrix,
+					&feature_matrix_num_features, &feature_matrix_num_vectors,
+					"feature_matrix", "Matrix of feature vectors / 1 vector per column.");
+		}
+
+	protected:
 		/// number of vectors in cache
 		int32_t num_vectors;
 
 		/// number of features in cache
 		int32_t num_features;
 
-		/** feature matrix */
+		/** Feature matrix and its associated number of
+		 * vectors and features. Note that num_vectors / num_features
+		 * above have the same sizes if feature_matrix != NULL
+		 * */
 		ST* feature_matrix;
+		int32_t feature_matrix_num_vectors;
+		int32_t feature_matrix_num_features;
 
 		/** feature cache */
 		CCache<ST>* feature_cache;
@@ -838,6 +817,7 @@ template<> inline EFeatureType CSimpleFeatures<sg_type>::get_feature_type() \
 GET_FEATURE_TYPE(F_BOOL, bool)
 GET_FEATURE_TYPE(F_CHAR, char)
 GET_FEATURE_TYPE(F_BYTE, uint8_t)
+GET_FEATURE_TYPE(F_BYTE, int8_t)
 GET_FEATURE_TYPE(F_SHORT, int16_t)
 GET_FEATURE_TYPE(F_WORD, uint16_t)
 GET_FEATURE_TYPE(F_INT, int32_t)
@@ -849,26 +829,6 @@ GET_FEATURE_TYPE(F_DREAL, float64_t)
 GET_FEATURE_TYPE(F_LONGREAL, floatmax_t)
 #undef GET_FEATURE_TYPE
 
-#define GET_FEATURE_NAME(f_name, sg_type)									\
-template<> inline const char* CSimpleFeatures<sg_type>::get_name() const	\
-{ 																			\
-	return f_name; 															\
-}
-
-GET_FEATURE_NAME("BoolFeatures", bool)
-GET_FEATURE_NAME("CharFeatures", char)
-GET_FEATURE_NAME("ByteFeatures", uint8_t)
-GET_FEATURE_NAME("ShortFeatures", int16_t)
-GET_FEATURE_NAME("WordFeatures", uint16_t)
-GET_FEATURE_NAME("IntFeatures", int32_t)
-GET_FEATURE_NAME("UIntFeatures", uint32_t)
-GET_FEATURE_NAME("LongIntFeatures", int64_t)
-GET_FEATURE_NAME("ULongIntFeatures", uint64_t)
-GET_FEATURE_NAME("ShortRealFeatures", float32_t)
-GET_FEATURE_NAME("RealFeatures", float64_t)
-GET_FEATURE_NAME("LongRealFeatures", floatmax_t)
-#undef GET_FEATURE_NAME
-
 /** align strings and compute emperical kernel map based on alignment scores
  *
  * non functional code - needs updating
@@ -948,6 +908,25 @@ template<> inline float64_t CSimpleFeatures<char>:: dense_dot(int32_t vec_idx1,
 	return result;
 }
 
+template<> inline float64_t CSimpleFeatures<int8_t>:: dense_dot(int32_t vec_idx1, const float64_t* vec2, int32_t vec2_len)
+{
+	ASSERT(vec2_len == num_features);
+
+	int32_t vlen;
+	bool vfree;
+	int8_t* vec1= get_feature_vector(vec_idx1, vlen, vfree);
+
+	ASSERT(vlen == num_features);
+	float64_t result=0;
+
+	for (int32_t i=0 ; i<num_features; i++)
+		result+=vec1[i]*vec2[i];
+
+	free_feature_vector(vec1, vec_idx1, vfree);
+
+	return result;
+}
+
 template<> inline float64_t CSimpleFeatures<uint8_t>:: dense_dot(int32_t vec_idx1, const float64_t* vec2, int32_t vec2_len)
 {
 	ASSERT(vec2_len == num_features);
@@ -1139,16 +1118,19 @@ template<> inline float64_t CSimpleFeatures<floatmax_t>:: dense_dot(int32_t vec_
 #define LOAD(f_load, sg_type)												\
 template<> inline void CSimpleFeatures<sg_type>::load(CFile* loader)		\
 { 																			\
+	SG_SET_LOCALE_C;													\
 	ASSERT(loader);															\
 	sg_type* matrix;														\
 	int32_t num_feat;														\
 	int32_t num_vec;														\
 	loader->f_load(matrix, num_feat, num_vec);								\
 	set_feature_matrix(matrix, num_feat, num_vec);							\
+	SG_RESET_LOCALE;													\
 }
 
 LOAD(get_bool_matrix, bool)
 LOAD(get_char_matrix, char)
+LOAD(get_int8_matrix, int8_t)
 LOAD(get_byte_matrix, uint8_t)
 LOAD(get_short_matrix, int16_t)
 LOAD(get_word_matrix, uint16_t)
@@ -1164,12 +1146,15 @@ LOAD(get_longreal_matrix, floatmax_t)
 #define SAVE(f_write, sg_type)												\
 template<> inline void CSimpleFeatures<sg_type>::save(CFile* writer)		\
 { 																			\
+	SG_SET_LOCALE_C;													\
 	ASSERT(writer);															\
 	writer->f_write(feature_matrix, num_features, num_vectors);				\
+	SG_RESET_LOCALE;													\
 }
 
 SAVE(set_bool_matrix, bool)
 SAVE(set_char_matrix, char)
+SAVE(set_int8_matrix, int8_t)
 SAVE(set_byte_matrix, uint8_t)
 SAVE(set_short_matrix, int16_t)
 SAVE(set_word_matrix, uint16_t)
