@@ -22,6 +22,7 @@
 #include "lib/io.h"
 #include "lib/Cache.h"
 #include "lib/File.h"
+#include "lib/DataType.h"
 
 #include "features/Labels.h"
 #include "features/Features.h"
@@ -39,29 +40,6 @@ class CDotFeatures;
 template <class ST> class CSimpleFeatures;
 template <class ST> class CSparsePreProc;
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-/** template class TSparseEntry */
-template <class ST> struct TSparseEntry
-{
-	/** feature index */
-	int32_t feat_index;
-	/** entry */
-	ST entry;
-};
-
-/** template class TSparse */
-template <class ST> struct TSparse
-{
-	public:
-		/** vector index */
-		int32_t vec_index;
-		/** number of feature entries */
-		int32_t num_feat_entries;
-		/** features */
-		TSparseEntry<ST>* features;
-};
-#endif // DOXYGEN_SHOULD_SKIP_THIS
-
 /** @brief Template class SparseFeatures implements sparse matrices.
  *
  * Features are an array of TSparse, sorted w.r.t. vec_index (increasing) and
@@ -76,6 +54,16 @@ template <class ST> struct TSparse
  */
 template <class ST> class CSparseFeatures : public CDotFeatures
 {
+	void init(void) {
+		set_generic<ST>();
+
+		m_parameters->add_vector(&sparse_feature_matrix, &num_vectors,
+								 "sparse_feature_matrix",
+								 "Array of sparse vectors.");
+		m_parameters->add(&num_features, "num_features",
+						  "Total number of features.");
+	}
+
 	public:
 		/** constructor
 		 *
@@ -84,7 +72,7 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 		CSparseFeatures(int32_t size=0)
 		: CDotFeatures(size), num_vectors(0), num_features(0),
 			sparse_feature_matrix(NULL), feature_cache(NULL)
-		{}
+		{ init(); }
 
 		/** convenience constructor that creates sparse features from
 		 * the ones passed as argument
@@ -98,6 +86,8 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 		: CDotFeatures(0), num_vectors(0), num_features(0),
 			sparse_feature_matrix(NULL), feature_cache(NULL)
 		{
+			init();
+
 			if (!copy)
 				set_sparse_feature_matrix(src, num_feat, num_vec);
 			else
@@ -124,6 +114,8 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 		: CDotFeatures(0), num_vectors(0), num_features(0),
 			sparse_feature_matrix(NULL), feature_cache(NULL)
 		{
+			init();
+
 			set_full_feature_matrix(src, num_feat, num_vec);
 		}
 
@@ -134,6 +126,8 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 			sparse_feature_matrix(orig.sparse_feature_matrix),
 			feature_cache(orig.feature_cache)
 		{
+			init();
+
 			if (orig.sparse_feature_matrix)
 			{
 				free_sparse_feature_matrix();
@@ -156,6 +150,8 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 		: CDotFeatures(loader), num_vectors(0), num_features(0),
 			sparse_feature_matrix(NULL), feature_cache(NULL)
 		{
+			init();
+
 			load(loader);
 		}
 
@@ -658,7 +654,7 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 			num_vectors=num_vec;
 		}
 
-		/** gets a copy of a full  feature matrix
+		/** gets a copy of a full feature matrix
 		 * num_feat,num_vectors are returned by reference
 		 *
 		 * @param num_feat number of features in matrix
@@ -747,7 +743,7 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 
 			if (num_feat_entries)
 			{
-				int32_t num_total_entries=0;
+				int64_t num_total_entries=0;
 
 				// count nr of non sparse features
 				for (int32_t i=0; i< num_vec; i++)
@@ -807,7 +803,7 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 					}
 
 					SG_INFO( "sparse feature matrix has %ld entries (full matrix had %ld, sparsity %2.2f%%)\n",
-							num_total_entries, num_feat*num_vec, (100.0*num_total_entries)/(num_feat*num_vec));
+							num_total_entries, int64_t(num_feat)*num_vec, (100.0*num_total_entries)/(int64_t(num_feat)*num_vec));
 				}
 				else
 				{
@@ -968,7 +964,7 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 			return sq;
 		}
 
-		/** compute (a-b)^2 (== a^2+b^2+2ab)
+		/** compute (a-b)^2 (== a^2+b^2-2ab)
 		 * usually called by kernels'/distances' compute functions
 		 * works on two feature vectors, although it is a member of a single
 		 * feature: can either be called by lhs or rhs.
@@ -1319,19 +1315,25 @@ template <class ST> class CSparseFeatures : public CDotFeatures
 		 * appointed by their indices
 		 *
 		 * @param vec_idx1 index of first vector
+		 * @param df DotFeatures (of same kind) to compute dot product with
 		 * @param vec_idx2 index of second vector
 		 */
-		virtual float64_t dot(int32_t vec_idx1, int32_t vec_idx2)
+		virtual float64_t dot(int32_t vec_idx1, CDotFeatures* df, int32_t vec_idx2)
 		{
+			ASSERT(df);
+			ASSERT(df->get_feature_type() == get_feature_type());
+			ASSERT(df->get_feature_class() == get_feature_class());
+			CSparseFeatures<ST>* sf = (CSparseFeatures<ST>*) df;
+
 			bool afree, bfree;
 			int32_t alen, blen;
 			TSparseEntry<ST>* avec=get_sparse_feature_vector(vec_idx1, alen, afree);
-			TSparseEntry<ST>* bvec=get_sparse_feature_vector(vec_idx2, blen, bfree);
+			TSparseEntry<ST>* bvec=sf->get_sparse_feature_vector(vec_idx2, blen, bfree);
 
 			float64_t result=sparse_dot(1, avec, alen, bvec, blen);
 
 			free_sparse_feature_vector(avec, vec_idx1, afree);
-			free_sparse_feature_vector(bvec, vec_idx2, bfree);
+			sf->free_sparse_feature_vector(bvec, vec_idx2, bfree);
 
 			return result;
 		}
@@ -1501,6 +1503,7 @@ template<> inline EFeatureType CSparseFeatures<sg_type>::get_feature_type()	\
 GET_FEATURE_TYPE(bool, F_BOOL)
 GET_FEATURE_TYPE(char, F_CHAR)
 GET_FEATURE_TYPE(uint8_t, F_BYTE)
+GET_FEATURE_TYPE(int8_t, F_BYTE)
 GET_FEATURE_TYPE(int16_t, F_SHORT)
 GET_FEATURE_TYPE(uint16_t, F_WORD)
 GET_FEATURE_TYPE(int32_t, F_INT)
@@ -1515,16 +1518,19 @@ GET_FEATURE_TYPE(floatmax_t, F_LONGREAL)
 #define LOAD(fname, sg_type)											\
 template<> inline void CSparseFeatures<sg_type>::load(CFile* loader)	\
 {																		\
+	SG_SET_LOCALE_C;													\
 	ASSERT(loader);														\
 	TSparse<sg_type>* matrix=NULL;										\
 	int32_t num_feat=0;													\
 	int32_t num_vec=0;													\
-	loader->fname(matrix, num_feat, num_vec);			\
+	loader->fname(matrix, num_feat, num_vec);							\
 	set_sparse_feature_matrix(matrix, num_feat, num_vec);				\
+	SG_RESET_LOCALE;													\
 }
 LOAD(get_bool_sparsematrix, bool)
 LOAD(get_char_sparsematrix, char)
 LOAD(get_byte_sparsematrix, uint8_t)
+LOAD(get_int8_sparsematrix, int8_t)
 LOAD(get_short_sparsematrix, int16_t)
 LOAD(get_word_sparsematrix, uint16_t)
 LOAD(get_int_sparsematrix, int32_t)
@@ -1539,12 +1545,15 @@ LOAD(get_longreal_sparsematrix, floatmax_t)
 #define WRITE(fname, sg_type)											\
 template<> inline void CSparseFeatures<sg_type>::save(CFile* writer)	\
 {																		\
+	SG_SET_LOCALE_C;													\
 	ASSERT(writer);														\
 	writer->fname(sparse_feature_matrix, num_features, num_vectors);	\
+	SG_RESET_LOCALE;													\
 }
 WRITE(set_bool_sparsematrix, bool)
 WRITE(set_char_sparsematrix, char)
 WRITE(set_byte_sparsematrix, uint8_t)
+WRITE(set_int8_sparsematrix, int8_t)
 WRITE(set_short_sparsematrix, int16_t)
 WRITE(set_word_sparsematrix, uint16_t)
 WRITE(set_int_sparsematrix, int32_t)
