@@ -20,6 +20,7 @@
 #include "lib/MemoryMappedFile.h"
 #include "lib/Mathematics.h"
 #include "lib/Compressor.h"
+#include "base/Parameter.h"
 
 #include "preproc/PreProc.h"
 #include "preproc/StringPreProc.h"
@@ -44,67 +45,22 @@ class CFile;
 template <class T> class CMemoryMappedFile;
 class CMath;
 template <class ST> class CStringPreProc;
-template <class T> class T_STRING;
+template <class T> class TString;
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-/** template class T_STRING */
-template <class T> class T_STRING
+struct SSKDoubleFeature
 {
-
-
-#ifdef HAVE_BOOST_SERIALIZATION
-
-  private:
-
-
-  friend class ::boost::serialization::access;
-  template<class Archive>
-  void save(Archive & ar, const unsigned int archive_version) const
-  {
-
-    //SG_DEBUG("archiving T_STRING\n");
-
-  	ar & length;
-
-    for (int i=0; i < length; ++i) {
-      ar & string[i];
-    }
-
-    //SG_DEBUG("done archiving T_STRING\n");
-
-  }
-
-  template<class Archive>
-  void load(Archive & ar, const unsigned int archive_version)
-  {
-
-	//SG_DEBUG("archiving T_STRING\n");
-
-  	ar & length;
-
-    string = new T[length];
-
-    for (int i=0; i < length; ++i) {
-      ar & string[i];
-    }
-
-    //SG_DEBUG("done archiving T_STRING\n");
-
-  }
-
-  GLOBAL_BOOST_SERIALIZATION_SPLIT_MEMBER();
-
-
-#endif //HAVE_BOOST_SERIALIZATION
-
-    public:
-	/** string */
-	T* string;
-	/** length of string */
-	int32_t length;
+	int feature1;
+	int feature2;
+	int group;
 };
-#endif // DOXYGEN_SHOULD_SKIP_THIS
 
+struct SSKTripleFeature
+{
+	int feature1;
+	int feature2;
+	int feature3;
+	int group;
+};
 
 /** @brief Template class StringFeatures implements a list of strings.
  *
@@ -135,6 +91,8 @@ template <class ST> class CStringFeatures : public CFeatures
         max_string_length(0), order(0), symbol_mask_table(NULL),
 		preprocess_on_get(false), feature_cache(NULL)
         {
+			init();
+			alphabet=new CAlphabet();
         }
 
 		/** constructor
@@ -147,6 +105,8 @@ template <class ST> class CStringFeatures : public CFeatures
 			max_string_length(0), order(0), symbol_mask_table(NULL),
 			preprocess_on_get(false), feature_cache(NULL)
 		{
+			init();
+
 			alphabet=new CAlphabet(alpha);
 			SG_REF(alphabet);
 			num_symbols=alphabet->get_num_symbols();
@@ -160,13 +120,15 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param p_max_string_length maximum string length
 		 * @param alpha alphabet (type) to use for string features
 		 */
-		CStringFeatures(T_STRING<ST>* p_features, int32_t p_num_vectors,
+		CStringFeatures(TString<ST>* p_features, int32_t p_num_vectors,
 				int32_t p_max_string_length, EAlphabet alpha)
 		: CFeatures(0), num_vectors(0), features(NULL),
 			single_string(NULL),length_of_single_string(0),
 			max_string_length(0), order(0), symbol_mask_table(NULL),
 			preprocess_on_get(false), feature_cache(NULL)
 		{
+			init();
+
 			alphabet=new CAlphabet(alpha);
 			SG_REF(alphabet);
 			num_symbols=alphabet->get_num_symbols();
@@ -181,13 +143,15 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param p_max_string_length maximum string length
 		 * @param alpha an actual alphabet
 		 */
-		CStringFeatures(T_STRING<ST>* p_features, int32_t p_num_vectors,
+		CStringFeatures(TString<ST>* p_features, int32_t p_num_vectors,
 				int32_t p_max_string_length, CAlphabet* alpha)
 		: CFeatures(0), num_vectors(0), features(NULL),
 			single_string(NULL),length_of_single_string(0),
 			max_string_length(0), order(0), symbol_mask_table(NULL),
 			preprocess_on_get(false), feature_cache(NULL)
 		{
+			init();
+
 			alphabet=new CAlphabet(alpha);
 			SG_REF(alphabet);
 			num_symbols=alphabet->get_num_symbols();
@@ -205,6 +169,8 @@ template <class ST> class CStringFeatures : public CFeatures
 			max_string_length(0), order(0), symbol_mask_table(NULL),
 			preprocess_on_get(false), feature_cache(NULL)
 		{
+			init();
+
 			ASSERT(alpha);
 			SG_REF(alpha);
 			alphabet=alpha;
@@ -223,6 +189,8 @@ template <class ST> class CStringFeatures : public CFeatures
 			order(orig.order), preprocess_on_get(false),
 			feature_cache(NULL)
 		{
+			init();
+
 			ASSERT(orig.single_string == NULL); //not implemented
 
 			alphabet=orig.alphabet;
@@ -230,7 +198,7 @@ template <class ST> class CStringFeatures : public CFeatures
 
 			if (orig.features)
 			{
-				features=new T_STRING<ST>[orig.num_vectors];
+				features=new TString<ST>[orig.num_vectors];
 
 				for (int32_t i=0; i<num_vectors; i++)
 				{
@@ -258,6 +226,8 @@ template <class ST> class CStringFeatures : public CFeatures
 			length_of_single_string(0), max_string_length(0), order(0),
 			symbol_mask_table(NULL), preprocess_on_get(false), feature_cache(NULL)
 		{
+			init();
+
 			alphabet=new CAlphabet(alpha);
 			SG_REF(alphabet);
 			num_symbols=alphabet->get_num_symbols();
@@ -463,7 +433,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		{
 			int32_t num_feat;
 			int32_t num_vec;
-			T_STRING<ST>* s=get_transposed(num_feat, num_vec);
+			TString<ST>* s=get_transposed(num_feat, num_vec);
 
 			return new CStringFeatures<ST>(s, num_vec, num_feat, alphabet);
 		}
@@ -479,7 +449,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param num_vec number of vectors in matrix
 		 * @return transposed string features
 		 */
-		T_STRING<ST>* get_transposed(int32_t &num_feat, int32_t &num_vec)
+		TString<ST>* get_transposed(int32_t &num_feat, int32_t &num_vec)
 		{
 			num_feat=num_vectors;
 			num_vec=get_max_vector_length();
@@ -488,7 +458,7 @@ template <class ST> class CStringFeatures : public CFeatures
 			SG_DEBUG("Allocating memory for transposed string features of size %ld\n",
 					int64_t(num_feat)*num_vec);
 
-			T_STRING<ST>* sf=new T_STRING<ST>[num_vec];
+			TString<ST>* sf=new TString<ST>[num_vec];
 
 			for (int32_t i=0; i<num_vec; i++)
 			{
@@ -711,7 +681,7 @@ template <class ST> class CStringFeatures : public CFeatures
 				blocksize=required_blocksize;
 				dummy = new uint8_t[blocksize];
 				overflow = new uint8_t[blocksize];
-				features=new T_STRING<ST>[num_vectors];
+				features=new TString<ST>[num_vectors];
 
 				rewind(f);
 				sz=blocksize;
@@ -821,7 +791,7 @@ template <class ST> class CStringFeatures : public CFeatures
 			alphabet=new CAlphabet(DNA);
 			num_symbols=alphabet->get_num_symbols();
 
-			T_STRING<ST>* strings=new T_STRING<ST>[num];
+			TString<ST>* strings=new TString<ST>[num];
 			offs=0;
 
 			for (i=0;i<num; i++)
@@ -912,12 +882,12 @@ template <class ST> class CStringFeatures : public CFeatures
 			SG_UNREF(alphabet);
 			alphabet=new CAlphabet(DNA);
 
-			T_STRING<ST>* strings;
+			TString<ST>* strings;
 
 			ST* str;
 			if (bitremap_in_single_string)
 			{
-				strings=new T_STRING<ST>[1];
+				strings=new TString<ST>[1];
 				strings[0].string=new ST[num];
 				strings[0].length=num;
 				f.get_line(len, offs);
@@ -930,7 +900,7 @@ template <class ST> class CStringFeatures : public CFeatures
 				str=new ST[len];
 			}
 			else
-				strings=new T_STRING<ST>[num];
+				strings=new TString<ST>[num];
 
 			for (i=0;i<num; i++)
 			{
@@ -1002,11 +972,11 @@ template <class ST> class CStringFeatures : public CFeatures
 			struct dirent **namelist;
 			int32_t n;
 
-            CIO::set_dirname(dirname);
+            IO::set_dirname(dirname);
 
 			SG_DEBUG("dirname '%s'\n", dirname);
 
-			n = scandir(dirname, &namelist, &CIO::filter, alphasort);
+			n = scandir(dirname, &namelist, &IO::filter, alphasort);
 			if (n <= 0)
 			{
 				SG_ERROR("error calling scandir - no files found\n");
@@ -1014,18 +984,18 @@ template <class ST> class CStringFeatures : public CFeatures
 			}
 			else
 			{
-				T_STRING<ST>* strings=NULL;
+				TString<ST>* strings=NULL;
 
 				int32_t num=0;
 				int32_t max_len=-1;
 
 				//usually n==num_vec, but it might not in race conditions
 				//(file perms modified, file erased)
-				strings=new T_STRING<ST>[n];
+				strings=new TString<ST>[n];
 
 				for (int32_t i=0; i<n; i++)
 				{
-					char* fname=CIO::concat_filename(namelist[i]->d_name);
+					char* fname=IO::concat_filename(namelist[i]->d_name);
 
 					struct stat s;
 					off_t filesize=0;
@@ -1071,7 +1041,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param p_max_string_length maximum string length
 		 * @return if setting was successful
 		 */
-		bool set_features(T_STRING<ST>* p_features, int32_t p_num_vectors, int32_t p_max_string_length)
+		bool set_features(TString<ST>* p_features, int32_t p_num_vectors, int32_t p_max_string_length)
 		{
 			if (p_features)
 			{
@@ -1113,7 +1083,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		bool append_features(CStringFeatures<ST>* sf)
 		{
 			ASSERT(sf);
-			T_STRING<ST>* new_features = new T_STRING<ST>[sf->num_vectors];
+			TString<ST>* new_features = new TString<ST>[sf->num_vectors];
 
 			for (int32_t i=0; i<sf->num_vectors; i++)
 			{
@@ -1136,7 +1106,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 *
 		 * @return if setting was successful
 		 */
-		bool append_features(T_STRING<ST>* p_features, int32_t p_num_vectors, int32_t p_max_string_length)
+		bool append_features(TString<ST>* p_features, int32_t p_num_vectors, int32_t p_max_string_length)
         {
             if (!features)
                 return set_features(p_features, p_num_vectors, p_max_string_length);
@@ -1158,7 +1128,7 @@ template <class ST> class CStringFeatures : public CFeatures
 
                 int32_t old_num_vectors=num_vectors;
                 num_vectors=old_num_vectors+p_num_vectors;
-                T_STRING<ST>* new_features = new T_STRING<ST>[num_vectors];
+                TString<ST>* new_features = new TString<ST>[num_vectors];
 
                 for (int32_t i=0; i<num_vectors; i++)
                 {
@@ -1192,7 +1162,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param max_str_len maximal string length (returned)
 		 * @return string features
 		 */
-		virtual T_STRING<ST>* get_features(int32_t& num_str, int32_t& max_str_len)
+		virtual TString<ST>* get_features(int32_t& num_str, int32_t& max_str_len)
 		{
 			num_str=num_vectors;
 			max_str_len=max_string_length;
@@ -1205,13 +1175,13 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param max_str_len maximal string length (returned)
 		 * @return string features
 		 */
-		virtual T_STRING<ST>* copy_features(int32_t& num_str, int32_t& max_str_len)
+		virtual TString<ST>* copy_features(int32_t& num_str, int32_t& max_str_len)
 		{
 			ASSERT(num_vectors>0);
 
 			num_str=num_vectors;
 			max_str_len=max_string_length;
-			T_STRING<ST>* new_feat=new T_STRING<ST>[num_str];
+			TString<ST>* new_feat=new TString<ST>[num_str];
 
 			for (int32_t i=0; i<num_str; i++)
 			{
@@ -1232,7 +1202,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 * @param dst string features (returned)
 		 * @param num_str number of strings (returned)
 		 */
-		virtual void get_features(T_STRING<ST>** dst, int32_t* num_str)
+		virtual void get_features(TString<ST>** dst, int32_t* num_str)
 		{
 			int32_t num_vec;
 			int32_t max_str_len;
@@ -1287,7 +1257,7 @@ template <class ST> class CStringFeatures : public CFeatures
 			fread(&max_string_length, sizeof(int32_t), 1, file);
 			ASSERT(max_string_length>0);
 
-			features=new T_STRING<ST>[num_vectors];
+			features=new TString<ST>[num_vectors];
 
 			// vectors
 			for (int32_t i=0; i<num_vectors; i++)
@@ -1459,7 +1429,7 @@ template <class ST> class CStringFeatures : public CFeatures
 				length_of_single_string=max_string_length;
 			}
 
-			T_STRING<ST>* f=new T_STRING<ST>[num_vectors];
+			TString<ST>* f=new TString<ST>[num_vectors];
 			int32_t offs=0;
 			for (int32_t i=0; i<num_vectors; i++)
 			{
@@ -1507,7 +1477,7 @@ template <class ST> class CStringFeatures : public CFeatures
 				length_of_single_string=max_string_length;
 			}
 
-			T_STRING<ST>* f=new T_STRING<ST>[num_vectors];
+			TString<ST>* f=new TString<ST>[num_vectors];
 			for (int32_t i=0; i<num_vectors; i++)
 			{
 				int32_t p=positions->get_element(i);
@@ -1576,7 +1546,7 @@ template <class ST> class CStringFeatures : public CFeatures
 				num_vectors=sf->get_num_vectors();
 				ASSERT(num_vectors>0);
 				max_string_length=sf->get_max_vector_length()-start;
-				features=new T_STRING<ST>[num_vectors];
+				features=new TString<ST>[num_vectors];
 
 				SG_DEBUG( "%1.0llf symbols in StringFeatures<*> %d symbols in histogram\n", sf->get_num_symbols(),
 						alpha->get_num_symbols_in_histogram());
@@ -1802,7 +1772,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		 *
 		 * note that this function is only sensible for character strings
 		 */
-		static ST* get_zero_terminated_string_copy(T_STRING<ST> str)
+		static ST* get_zero_terminated_string_copy(TString<ST> str)
 		{
 			int32_t l=str.length;
 			ST* s=new ST[l+1];
@@ -1881,7 +1851,7 @@ template <class ST> class CStringFeatures : public CFeatures
 			ASSERT(rows == get_num_symbols());
 			cleanup();
 			float64_t* randoms=new float64_t[cols];
-			T_STRING<ST>* sf=new T_STRING<ST>[num_vec];
+			TString<ST>* sf=new TString<ST>[num_vec];
 
 			for (int32_t i=0; i<num_vec; i++)
 			{
@@ -1908,6 +1878,78 @@ template <class ST> class CStringFeatures : public CFeatures
 			set_features(sf, num_vec, cols);
 		}
 
+		/*
+		CStringFeatures<SSKTripleFeature>* obtain_sssk_triple_from_cha(int d1, int d2)
+		{
+			int *s;
+			int32_t nStr=get_num_vectors();
+
+			int32_t nfeat = 0;
+			for (int32_t i = 0; i < nStr; ++i)
+				nfeat += get_vector_length[i] - d1 -d2;
+			TString<SSKFeature>* F= new TString<SSKFeature>[nfeat];
+			int32_t c = 0;
+			for (int32_t i = 0; i < nStr; ++i)
+			{
+			int32_t len;
+			bool free_vec;
+			ST* S=get_feature_vector(vec_num, len, free_vec);
+			free_feature_vector(vec, vec_num, free_vec);
+				int32_t n = len - d1 - d2;
+				s = S[i];
+				for (int32_t j = 0; j < n; ++j)
+				{
+					F[c].feature1 = s[j];
+					F[c].feature2 = s[j+d1];
+					F[c].feature3 = s[j+d1+d2];
+					F[c].group = i;
+					c++;
+				}
+			}
+			ASSERT(nfeat==c);
+			return F;
+		}
+
+		CStringFeatures<SSKFeature>* obtain_sssk_double_from_char(int **S, int *len, int nStr, int d1)
+		{
+			int i, j;
+			int n, nfeat;
+			int *group;
+			int *features;
+			int *s;
+			int c;
+			SSKFeatures *F;
+
+			nfeat = 0;
+			for (i = 0; i < nStr; ++i)
+				nfeat += len[i] - d1;
+			group = (int *)malloc(nfeat*sizeof(int));
+			features = (int *)malloc(nfeat*2*sizeof(int *));
+			c = 0;
+			for (i = 0; i < nStr; ++i)
+			{
+				n = len[i] - d1;
+				s = S[i];
+				for (j = 0; j < n; ++j)
+				{
+					features[c] = s[j];
+					features[c+nfeat] = s[j+d1];
+					group[c] = i;
+					c++;
+				}
+			}
+			if (nfeat!=c)
+				printf("Something is wrong...\n");
+			F = (SSKFeatures *)malloc(sizeof(SSKFeatures));
+			(*F).features = features;
+			(*F).group = group;
+			(*F).n = nfeat;
+			return F;
+		}
+	*/
+
+
+
 		/** @return object name */
 		inline virtual const char* get_name() const { return "StringFeatures"; }
 
@@ -1936,88 +1978,34 @@ template <class ST> class CStringFeatures : public CFeatures
 			return target;
 		}
 
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
+	private:
+		void init(void)
+		{
+			set_generic<ST>();
 
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void save(Archive & ar, const unsigned int archive_version) const
-            {
+			m_parameters->add((CSGObject**) &alphabet, "alphabet");
+			m_parameters->add_vector(&features, &num_vectors, "features",
+					"This contains the array of features.");
+			m_parameters->add_vector(&single_string,
+					&length_of_single_string,
+					"single_string",
+					"Created by sliding window.");
+			m_parameters->add(&max_string_length, "max_string_length",
+					"Length of longest string.");
+			m_parameters->add(&num_symbols, "num_symbols",
+					"Number of used symbols.");
+			m_parameters->add(&original_num_symbols, "original_num_symbols",
+					"Original number of used symbols.");
+			m_parameters->add(&order, "order",
+					"Order used in higher order mapping.");
+			m_parameters->add(&preprocess_on_get, "preprocess_on_get",
+					"Preprocess on-the-fly?");
 
-				SG_DEBUG("archiving StringFeatures\n");
-
-                ar & ::boost::serialization::base_object<CFeatures>(*this);
-
-                ar & alphabet;
-
-                ar & num_vectors;
-                for (int i=0; i < num_vectors; ++i) {
-                    ar & features[i];
-                }
-
-                ar & length_of_single_string;
-                for (int i=0; i < length_of_single_string; ++i) {
-                    ar & single_string[i];
-                }
-
-                ar & max_string_length;
-                ar & num_symbols;
-                ar & original_num_symbols;
-                ar & order;
-
-                /// order used in higher order mapping
-                //TODO?! how long
-                //ST* symbol_mask_table;
-
-                SG_DEBUG("done archiving StringFeatures\n");
-
-            }
-
-        template<class Archive>
-            void load(Archive & ar, const unsigned int archive_version)
-            {
-
-				SG_DEBUG("archiving StringFeatures\n");
-
-                ar & ::boost::serialization::base_object<CFeatures>(*this);
-
-
-                ar & alphabet;
-
-                ar & num_vectors;
-
-                //T_STRING<ST>* features = new T_STRING<ST>[num_vectors];
-                features = new T_STRING<ST>[num_vectors];
-                for (int i=0; i < num_vectors; ++i) {
-                    ar & features[i];
-                }
-
-
-                ar & length_of_single_string;
-
-                //ST* single_string = new ST[length_of_single_string];
-                single_string = new ST[length_of_single_string];
-                for (int i=0; i < length_of_single_string; ++i) {
-                    ar & single_string[i];
-                }
-
-                ar & max_string_length;
-                ar & num_symbols;
-                ar & original_num_symbols;
-                ar & order;
-
-                /// order used in higher order mapping
-                //TODO?! how long -> num_of_symbols?
-                //ST* symbol_mask_table;
-
-                SG_DEBUG("done archiving StringFeatures\n");
-
-            }
-
-        GLOBAL_BOOST_SERIALIZATION_SPLIT_MEMBER();
-
-
-#endif //HAVE_BOOST_SERIALIZATION
+			/* TODO M_PARAMETERS->ADD?
+			 * /// order used in higher order mapping
+			 * ST* symbol_mask_table;
+			 */
+		}
 
 
 	protected:
@@ -2029,7 +2017,7 @@ template <class ST> class CStringFeatures : public CFeatures
 		int32_t num_vectors;
 
 		/// this contains the array of features.
-		T_STRING<ST>* features;
+		TString<ST>* features;
 
 		/// true when single string / created by sliding window
 		ST* single_string;
@@ -2281,15 +2269,18 @@ template<> inline void CStringFeatures<sg_type>::load(CFile* loader)		\
 {																			\
 	SG_INFO( "loading...\n");												\
 																			\
-	T_STRING<sg_type>* strs;												\
+	SG_SET_LOCALE_C;													\
+	TString<sg_type>* strs;												\
 	int32_t num_str;														\
 	int32_t max_len;														\
 	loader->f_load(strs, num_str, max_len);									\
 	set_features(strs, num_str, max_len);									\
+	SG_RESET_LOCALE;													\
 }
 
 LOAD(get_bool_string_list, bool)
 LOAD(get_char_string_list, char)
+LOAD(get_int8_string_list, int8_t)
 LOAD(get_byte_string_list, uint8_t)
 LOAD(get_short_string_list, int16_t)
 LOAD(get_word_string_list, uint16_t)
@@ -2305,12 +2296,15 @@ LOAD(get_longreal_string_list, floatmax_t)
 #define SAVE(f_write, sg_type)												\
 template<> inline void CStringFeatures<sg_type>::save(CFile* writer)		\
 { 																			\
+	SG_SET_LOCALE_C;													\
 	ASSERT(writer);															\
 	writer->f_write(features, num_vectors);									\
+	SG_RESET_LOCALE;													\
 }
 
 SAVE(set_bool_string_list, bool)
 SAVE(set_char_string_list, char)
+SAVE(set_int8_string_list, int8_t)
 SAVE(set_byte_string_list, uint8_t)
 SAVE(set_short_string_list, int16_t)
 SAVE(set_word_string_list, uint16_t)
