@@ -15,19 +15,30 @@
 
 using namespace shogun;
 
+CTOPFeatures::CTOPFeatures()
+{
+	init();
+}
+
 CTOPFeatures::CTOPFeatures(
 	int32_t size, CHMM* p, CHMM* n, bool neglin, bool poslin)
-: CSimpleFeatures<float64_t>(size), neglinear(neglin), poslinear(poslin)
+: CSimpleFeatures<float64_t>(size)
 {
-	memset(&pos_relevant_indizes, 0, sizeof(pos_relevant_indizes));
-	memset(&neg_relevant_indizes, 0, sizeof(neg_relevant_indizes));
+	init();
+	neglinear=neglin;
+	poslinear=poslin;
+
 	set_models(p,n);
 }
 
 CTOPFeatures::CTOPFeatures(const CTOPFeatures &orig)
-: CSimpleFeatures<float64_t>(orig), pos(orig.pos), neg(orig.neg), neglinear(orig.neglinear),
-	poslinear(orig.poslinear)
+: CSimpleFeatures<float64_t>(orig)
 {
+	init();
+	pos=orig.pos;
+	neg=orig.neg;
+	neglinear=orig.neglinear;
+	poslinear=orig.poslinear;
 }
 
 CTOPFeatures::~CTOPFeatures()
@@ -349,3 +360,21 @@ int32_t CTOPFeatures::compute_num_features()
 	}
 	return num;
 }
+
+void CTOPFeatures::init()
+{
+	pos = NULL;
+	neg = NULL;
+	neglinear = false;
+	poslinear = false;
+
+	memset(&pos_relevant_indizes, 0, sizeof(pos_relevant_indizes));
+	memset(&neg_relevant_indizes, 0, sizeof(neg_relevant_indizes));
+
+	unset_generic();
+	//TODO serialize HMMs
+	//m_parameters->add((CSGObject**) &pos, "pos", "HMM for positive class.");
+	//m_parameters->add((CSGObject**) &neg, "neg", "HMM for negative class.");
+	m_parameters->add(&neglinear, "neglinear", "If negative HMM is a LinearHMM");
+	m_parameters->add(&poslinear, "poslinear", "If positive HMM is a LinearHMM");
+}
