@@ -68,6 +68,9 @@ struct T_HMM_INDIZES
 class CTOPFeatures : public CSimpleFeatures<float64_t>
 {
 	public:
+		/** default constructor  */
+		CTOPFeatures();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -132,6 +135,9 @@ class CTOPFeatures : public CSimpleFeatures<float64_t>
 		 */
 		void compute_feature_vector(float64_t* addr, int32_t num, int32_t& len);
 
+	private:
+		void init();
+
 	protected:
 		/** positive HMM */
 		CHMM* pos;
