@@ -17,9 +17,23 @@
 
 using namespace shogun;
 
-CAUCKernel::CAUCKernel(int32_t size, CKernel* s)
-: CSimpleKernel<uint16_t>(size), subkernel(s)
+void
+CAUCKernel::init(void)
 {
+	m_parameters->add((CSGObject**) &subkernel, "subkernel",
+					  "The subkernel.");
+}
+
+CAUCKernel::CAUCKernel(void)
+: CDotKernel(0), subkernel(NULL)
+{
+	init();
+}
+
+CAUCKernel::CAUCKernel(int32_t size, CKernel* s)
+: CDotKernel(size), subkernel(s)
+{
+	init();
 	SG_REF(subkernel);
 }
 
@@ -111,7 +125,7 @@ CLabels* CAUCKernel::setup_auc_maximization(CLabels* labels)
 
 bool CAUCKernel::init(CFeatures* l, CFeatures* r)
 {
-	CSimpleKernel<uint16_t>::init(l, r);
+	CDotKernel::init(l, r);
 	init_normalizer();
 	return true;
 }
