@@ -13,7 +13,7 @@
 #define _AUCKERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
+#include "kernel/DotKernel.h"
 #include "features/SimpleFeatures.h"
 #include "features/Labels.h"
 
@@ -30,9 +30,14 @@ namespace shogun
  * are created that ensure that all positive examples get a higher score than
  * all negative examples in training.
  */
-class CAUCKernel: public CSimpleKernel<uint16_t>
+class CAUCKernel: public CDotKernel
 {
+	void init(void);
+
 	public:
+		/** default constructor  */
+		CAUCKernel(void);
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -71,6 +76,18 @@ class CAUCKernel: public CSimpleKernel<uint16_t>
 		 */
 		virtual const char* get_name() const { return "AUC" ; }
 
+		/** return feature class the kernel can deal with
+		 *
+		 * @return feature class SIMPLE
+		 */
+		inline virtual EFeatureClass get_feature_class() { return C_SIMPLE; }
+
+		/** return feature type the kernel can deal with
+		 *
+		 * @return word feature type
+		 */
+		virtual EFeatureType get_feature_type() { return F_WORD; }
+
 	protected:
 		/** compute kernel function for features a and b
 		 * idx_{a,b} denote the index of the feature vectors
