@@ -12,7 +12,7 @@
 #define _CHI2KERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
+#include "kernel/DotKernel.h"
 #include "features/Features.h"
 #include "features/SimpleFeatures.h"
 
@@ -29,9 +29,14 @@ namespace shogun
  * \f]
  *
  * */
-class CChi2Kernel: public CSimpleKernel<float64_t>
+class CChi2Kernel: public CDotKernel
 {
+	void init(void);
+
 	public:
+		/** default constructor  */
+		CChi2Kernel(void);
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -65,6 +70,18 @@ class CChi2Kernel: public CSimpleKernel<float64_t>
 		 */
 		virtual EKernelType get_kernel_type() { return K_CHI2; }
 
+		/** return feature class the kernel can deal with
+		 *
+		 * @return feature class SIMPLE
+		 */
+		inline virtual EFeatureClass get_feature_class() { return C_SIMPLE; }
+
+		/** return feature type the kernel can deal with
+		 *
+		 * @return float64_t feature type
+		 */
+		virtual EFeatureType get_feature_type() { return F_DREAL; }
+
 		/** return the kernel's name
 		 *
 		 * @return name Chi2
