@@ -43,17 +43,14 @@ struct S_THREAD_PARAM
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 CCombinedKernel::CCombinedKernel(int32_t size, bool asw)
-: CKernel(size), sv_count(0), sv_idx(NULL), sv_weight(NULL),
-	subkernel_weights_buffer(NULL), append_subkernel_weights(asw),
-	initialized(false)
+: CKernel(size), append_subkernel_weights(asw)
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
-	kernel_list=new CList<CKernel*>(true);
-	SG_REF(kernel_list);
+	init();
 
-	SG_INFO("Combined kernel created (%p)\n", this) ;
 	if (append_subkernel_weights)
 		SG_INFO( "(subkernel weights are appended)\n") ;
+
+	SG_INFO("Combined kernel created (%p)\n", this) ;
 }
 
 CCombinedKernel::~CCombinedKernel()
@@ -81,11 +78,11 @@ bool CCombinedKernel::init(CFeatures* l, CFeatures* r)
 
 	bool result=true;
 
-	CListElement<CFeatures*>* lfc = NULL;
-	CListElement<CFeatures*>* rfc = NULL;
+	CListElement* lfc = NULL;
+	CListElement* rfc = NULL;
 	lf=((CCombinedFeatures*) l)->get_first_feature_obj(lfc);
 	rf=((CCombinedFeatures*) r)->get_first_feature_obj(rfc);
-	CListElement<CKernel*>* current = NULL;
+	CListElement* current = NULL;
 	k=get_first_kernel(current);
 
 	while ( result && k )
@@ -151,7 +148,7 @@ void CCombinedKernel::remove_lhs()
 {
 	delete_optimization();
 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k=get_first_kernel(current);
 
 	while (k)
@@ -169,7 +166,7 @@ void CCombinedKernel::remove_lhs()
 
 void CCombinedKernel::remove_rhs()
 {
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k=get_first_kernel(current);
 
 	while (k)
@@ -188,7 +185,7 @@ void CCombinedKernel::remove_lhs_and_rhs()
 {
 	delete_optimization();
 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k=get_first_kernel(current);
 
 	while (k)
@@ -207,7 +204,7 @@ void CCombinedKernel::remove_lhs_and_rhs()
 
 void CCombinedKernel::cleanup()
 {
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k=get_first_kernel(current);
 
 	while (k)
@@ -232,7 +229,7 @@ void CCombinedKernel::list_kernels()
 	SG_INFO( "BEGIN COMBINED KERNEL LIST - ");
 	this->list_kernel();
 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	k=get_first_kernel(current);
 	while (k)
 	{
@@ -246,7 +243,7 @@ void CCombinedKernel::list_kernels()
 float64_t CCombinedKernel::compute(int32_t x, int32_t y)
 {
 	float64_t result=0;
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k=get_first_kernel(current);
 	while (k)
 	{
@@ -266,7 +263,7 @@ bool CCombinedKernel::init_optimization(
 
 	delete_optimization();
 
-	CListElement<CKernel*> *current=NULL;
+	CListElement* current=NULL;
 	CKernel *k=get_first_kernel(current);
 	bool have_non_optimizable=false;
 
@@ -312,7 +309,7 @@ bool CCombinedKernel::init_optimization(
 
 bool CCombinedKernel::delete_optimization() 
 { 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k = get_first_kernel(current);
 
 	while(k)
@@ -349,7 +346,7 @@ void CCombinedKernel::compute_batch(
 	//make sure we start cleanly
 	delete_optimization();
 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel * k = get_first_kernel(current) ;
 
 	while(k)
@@ -544,7 +541,7 @@ float64_t CCombinedKernel::compute_optimized(int32_t idx)
 	
 	float64_t result=0;
 
-	CListElement<CKernel*> *current=NULL;
+	CListElement* current=NULL;
 	CKernel *k=get_first_kernel(current);
 	while (k)
 	{
@@ -581,7 +578,7 @@ float64_t CCombinedKernel::compute_optimized(int32_t idx)
 
 void CCombinedKernel::add_to_normal(int32_t idx, float64_t weight)
 { 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k = get_first_kernel(current);
 
 	while(k)
@@ -595,7 +592,7 @@ void CCombinedKernel::add_to_normal(int32_t idx, float64_t weight)
 
 void CCombinedKernel::clear_normal() 
 { 
-	CListElement<CKernel*> * current = NULL ;	
+	CListElement* current = NULL ;	
 	CKernel* k = get_first_kernel(current);
 
 	while(k)
@@ -613,7 +610,7 @@ void CCombinedKernel::compute_by_subkernel(
 	if (append_subkernel_weights)
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -632,7 +629,7 @@ void CCombinedKernel::compute_by_subkernel(
 	else
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -655,7 +652,7 @@ const float64_t* CCombinedKernel::get_subkernel_weights(int32_t& num_weights)
 	if (append_subkernel_weights)
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -673,7 +670,7 @@ const float64_t* CCombinedKernel::get_subkernel_weights(int32_t& num_weights)
 	else
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -705,7 +702,7 @@ void CCombinedKernel::set_subkernel_weights(
 	if (append_subkernel_weights)
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -720,7 +717,7 @@ void CCombinedKernel::set_subkernel_weights(
 	else
 	{
 		int32_t i=0 ;
-		CListElement<CKernel*> * current = NULL ;	
+		CListElement* current = NULL ;	
 		CKernel* k = get_first_kernel(current);
 		while(k)
 		{
@@ -755,7 +752,7 @@ bool CCombinedKernel::precompute_subkernels()
 	if (!k)
 		return false;
 
-	CList<CKernel*>* new_kernel_list = new CList<CKernel*>(true);
+	CList* new_kernel_list = new CList(true);
 
 	while(k)
 	{
@@ -771,3 +768,30 @@ bool CCombinedKernel::precompute_subkernels()
 
 	return true;
 }
+
+void CCombinedKernel::init()
+{
+	sv_count=0;
+	sv_idx=NULL;
+	sv_weight=NULL;
+	subkernel_weights_buffer=NULL;
+	initialized=false;
+
+	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+	kernel_list=new CList(true);
+	SG_REF(kernel_list);
+
+
+	m_parameters->add((CSGObject**) &kernel_list, "kernel_list",
+					  "List of kernels.");
+	m_parameters->add_vector(&sv_idx, &sv_count, "sv_idx",
+							 "Support vector index.");
+	m_parameters->add_vector(&sv_weight, &sv_count, "sv_weight",
+							 "Support vector weights.");
+	m_parameters->add(&append_subkernel_weights,
+					  "append_subkernel_weights",
+					  "If subkernel weights are appended.");
+	m_parameters->add(&initialized, "initialized",
+					  "Whether kernel is ready to be used.");
+}
+
