@@ -9,32 +9,36 @@
  */
 
 #include "lib/common.h"
+#include "lib/io.h"
+
+#include "base/Parameter.h"
+
 #include "kernel/CommWordStringKernel.h"
 #include "kernel/SqrtDiagKernelNormalizer.h"
 #include "features/StringFeatures.h"
-#include "lib/io.h"
 
 using namespace shogun;
 
-CCommWordStringKernel::CCommWordStringKernel(int32_t size, bool s)
-: CStringKernel<uint16_t>(size), dictionary_size(0), dictionary_weights(NULL),
-	use_sign(s), use_dict_diagonal_optimization(false), dict_diagonal_optimization(NULL)
+CCommWordStringKernel::CCommWordStringKernel()
+: CStringKernel<uint16_t>()
 {
-	properties |= KP_LINADD;
-	init_dictionary(1<<(sizeof(uint16_t)*8));
-	set_normalizer(new CSqrtDiagKernelNormalizer(use_dict_diagonal_optimization));
+	init();
+}
+
+CCommWordStringKernel::CCommWordStringKernel(int32_t size, bool s)
+: CStringKernel<uint16_t>(size)
+{
+	init();
+	use_sign=s;
 }
 
 CCommWordStringKernel::CCommWordStringKernel(
-	CStringFeatures<uint16_t>* l, CStringFeatures<uint16_t>* r, bool s,
-	int32_t size)
-: CStringKernel<uint16_t>(size), dictionary_size(0), dictionary_weights(NULL),
-	use_sign(s), use_dict_diagonal_optimization(false), dict_diagonal_optimization(NULL)
+	CStringFeatures<uint16_t>* l, CStringFeatures<uint16_t>* r,
+	bool s, int32_t size) : CStringKernel<uint16_t>(size)
 {
-	properties |= KP_LINADD;
+	init();
+	use_sign=s;
 
-	init_dictionary(1<<(sizeof(uint16_t)*8));
-	set_normalizer(new CSqrtDiagKernelNormalizer(use_dict_diagonal_optimization));
 	init(l,r);
 }
 
@@ -595,3 +599,24 @@ char* CCommWordStringKernel::compute_consensus(
 	SG_UNREF(alpha);
 	return result;
 }
+
+void CCommWordStringKernel::init()
+{
+	dictionary_size=0;
+	dictionary_weights=NULL;
+
+	use_sign=false;
+	use_dict_diagonal_optimization=false;
+	dict_diagonal_optimization=NULL;
+
+	properties |= KP_LINADD;
+	init_dictionary(1<<(sizeof(uint16_t)*8));
+	set_normalizer(new CSqrtDiagKernelNormalizer(use_dict_diagonal_optimization));
+
+	m_parameters->add_vector(&dictionary_weights, &dictionary_size, "dictionary_weights",
+			"Dictionary for applying kernel.");
+	m_parameters->add(&use_sign, "use_sign",
+			"If signum(counts) is used instead of counts.");
+	m_parameters->add(&use_dict_diagonal_optimization, "use_dict_diagonal_optimization",
+			"If K(x,x) is computed potentially more efficiently.");
+}
