@@ -54,6 +54,9 @@ class CCommWordStringKernel : public CStringKernel<uint16_t>
 	friend class CDiceKernelNormalizer;
 
 	public:
+		/** default constructor  */
+		CCommWordStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -231,6 +234,9 @@ class CCommWordStringKernel : public CStringKernel<uint16_t>
 		 */
 		virtual float64_t compute_diag(int32_t idx_a);
 
+	private:
+		void init();
+
 	protected:
 		/** size of dictionary (number of possible strings) */
 		int32_t dictionary_size;
