@@ -27,6 +27,9 @@ namespace shogun
 class CConstKernel: public CKernel
 {
 	public:
+		/** default constructor  */
+		CConstKernel();
+
 		/** constructor
 		 *
 		 * @param c constant c
@@ -93,6 +96,9 @@ class CConstKernel: public CKernel
 			return const_value;
 		}
 
+	private:
+		void init();
+
 	protected:
 		/** const value */
 		float64_t const_value;
