@@ -26,6 +26,9 @@ namespace shogun
 class CDiagKernel: public CKernel
 {
 	public:
+		/** default constructor  */
+		CDiagKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -43,6 +46,14 @@ class CDiagKernel: public CKernel
 
 		virtual ~CDiagKernel();
 
+		/** initialize kernel
+		 *
+		 * @param l features of left-hand side
+		 * @param r features of right-hand side
+		 * @return if initializing was successful
+		 */
+		virtual bool init(CFeatures* l, CFeatures* r);
+
 		/** return feature type the kernel can deal with
 		 *
 		 * @return feature type ANY
@@ -71,7 +82,7 @@ class CDiagKernel: public CKernel
 		 *
 		 * @return name Custom
 		 */
-		virtual const char* get_name() const { return "Diagonal"; }
+		virtual const char* get_name() const { return "DiagKernel"; }
 
 	protected:
 		/** compute kernel function for features a and b
@@ -89,6 +100,8 @@ class CDiagKernel: public CKernel
 			else
 				return 0;
 		}
+	private:
+		void init();
 
 	protected:
 		/** diagonal */
