@@ -17,6 +17,12 @@
 
 using namespace shogun;
 
+CDistanceKernel::CDistanceKernel(void)
+: CKernel(0), distance(NULL), width(0.0)
+{
+	SG_UNSTABLE("CDistanceKernel::CDistanceKernel(void)", "\n");
+}
+
 CDistanceKernel::CDistanceKernel(int32_t size, float64_t w, CDistance* d)
 : CKernel(size), distance(d), width(w)
 {
