@@ -17,17 +17,30 @@
 
 using namespace shogun;
 
+void
+CFixedDegreeStringKernel::init(void)
+{
+	m_parameters->add(&degree, "degree", "The degree.");
+	set_normalizer(new CSqrtDiagKernelNormalizer());
+}
+
+CFixedDegreeStringKernel::CFixedDegreeStringKernel(void)
+: CStringKernel<char>(0), degree(0)
+{
+	init();
+}
+
 CFixedDegreeStringKernel::CFixedDegreeStringKernel(int32_t size, int32_t d)
 : CStringKernel<char>(size), degree(d)
 {
-	set_normalizer(new CSqrtDiagKernelNormalizer());
+	init();
 }
 
 CFixedDegreeStringKernel::CFixedDegreeStringKernel(
 	CStringFeatures<char>* l, CStringFeatures<char>* r, int32_t d)
 : CStringKernel<char>(10), degree(d)
 {
-	set_normalizer(new CSqrtDiagKernelNormalizer());
+	init();
 	init(l, r);
 }
 
