@@ -30,7 +30,12 @@ namespace shogun
  */
 class CFixedDegreeStringKernel: public CStringKernel<char>
 {
+	void init(void);
+
 	public:
+		/** default constructor  */
+		CFixedDegreeStringKernel(void);
+
 		/** constructor
 		 *
 		 * @param size cache size
