@@ -4,21 +4,23 @@
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * Written (W) 1999-2009 Soeren Sonnenburg
+ * Written (W) 1999-2010 Soeren Sonnenburg
  * Copyright (C) 1999-2009 Fraunhofer Institute FIRST and Max-Planck-Society
+ * Copyright (C) 2010 Berlin Institute of Technology
  */
 
 #ifndef _GAUSSIANKERNEL_H___
 #define _GAUSSIANKERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
-#include "features/SimpleFeatures.h"
+#include "kernel/DotKernel.h"
+#include "features/DotFeatures.h"
 
 namespace shogun
 {
+	class CDotFeatures;
 /** @brief The well known Gaussian kernel (swiss army knife for SVMs)
- * on dense real valued features.
+ * computed on CDotFeatures.
  *
  * It is computed as
  *
@@ -28,7 +30,7 @@ namespace shogun
  *
  * where \f$\tau\f$ is the kernel width.
  */
-class CGaussianKernel: public CSimpleKernel<float64_t>
+class CGaussianKernel: public CDotKernel
 {
 	public:
 		/** default constructor
@@ -50,7 +52,7 @@ class CGaussianKernel: public CSimpleKernel<float64_t>
 		 * @param width width
 		 * @param size cache size
 		 */
-		CGaussianKernel(CSimpleFeatures<float64_t>* l, CSimpleFeatures<float64_t>* r,
+		CGaussianKernel(CDotFeatures* l, CDotFeatures* r,
 			float64_t width, int32_t size=10);
 
 		virtual ~CGaussianKernel();
@@ -63,6 +65,9 @@ class CGaussianKernel: public CSimpleKernel<float64_t>
 		 */
 		virtual bool init(CFeatures* l, CFeatures* r);
 
+		/** clean up kernel */
+		virtual void cleanup();
+
 		/** return what type of kernel we are
 		 *
 		 * @return kernel type GAUSSIAN
@@ -75,6 +80,14 @@ class CGaussianKernel: public CSimpleKernel<float64_t>
 		 */
 		inline virtual const char* get_name() const { return "GaussianKernel"; }
 
+		/** return the kernel's width
+		 *
+		 * @return kernel width
+		 */
+		inline virtual float64_t get_width(void) const {
+			return width;
+		}
+
 	protected:
 		/** compute kernel function for features a and b
 		 * idx_{a,b} denote the index of the feature vectors
@@ -86,29 +99,42 @@ class CGaussianKernel: public CSimpleKernel<float64_t>
 		 */
 		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
 
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
+		/** Can (optionally) be overridden to post-initialize some
+		 *  member variables which are not PARAMETER::ADD'ed.  Make
+		 *  sure that at first the overridden method
+		 *  BASE_CLASS::LOAD_SERIALIZABLE_POST is called.
+		 *
+		 *  @exception ShogunException Will be thrown if an error
+		 *                             occurres.
+		 */
+		virtual void load_serializable_post(void) throw (ShogunException);
 
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void serialize(Archive & ar, const unsigned int archive_version)
-            {
+	private:
+		/** helper function to compute quadratic terms in
+		 * (a-b)^2 (== a^2+b^2-2ab)
+		 *
+		 * @param buf buffer to store squared terms (will be allocated)
+		 * @param df dot feature object based on which k(i,i) is computed
+		 * */
+		void precompute_squared();
 
-                SG_DEBUG("archiving GaussianKernel\n");
-
-                ar & ::boost::serialization::base_object<CSimpleKernel<float64_t> >(*this);
-
-                ar & width;
-
-                SG_DEBUG("done with GaussianKernel\n");
-
-            }
-#endif //HAVE_BOOST_SERIALIZATION
+		/** helper function to compute quadratic terms in
+		 * (a-b)^2 (== a^2+b^2-2ab)
+		 *
+		 * @param buf buffer to store squared terms (will be allocated)
+		 * @param df dot feature object based on which k(i,i) is computed
+		 * */
+		void precompute_squared_helper(float64_t* &buf, CDotFeatures* df);
 
+		void init();
 
 	protected:
 		/** width */
 		float64_t width;
+		/** squared left-hand side */
+		float64_t* sq_lhs;
+		/** squared right-hand side */
+		float64_t* sq_rhs;
 };
 }
 #endif /* _GAUSSIANKERNEL_H__ */
