@@ -13,6 +13,7 @@
 
 #include "lib/common.h"
 #include "kernel/GaussianKernel.h"
+#include "features/SimpleFeatures.h"
 
 namespace shogun
 {
@@ -36,6 +37,9 @@ namespace shogun
 class CGaussianShiftKernel: public CGaussianKernel
 {
 	public:
+		/** default constructor  */
+		CGaussianShiftKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -86,6 +90,9 @@ class CGaussianShiftKernel: public CGaussianKernel
 		 */
 		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
 		/** maximum shift */
 		int32_t max_shift;
