@@ -26,6 +26,9 @@ namespace shogun
 class CHistogramWordStringKernel: public CStringKernel<uint16_t>
 {
 	public:
+		/** default constructor  */
+		CHistogramWordStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -90,6 +93,9 @@ class CHistogramWordStringKernel: public CStringKernel<uint16_t>
 			return position*num_symbols+symbol+1;
 		}
 
+	private:
+		void init();
+
 	protected:
 		/** plugin estimate */
 		CPluginEstimate* estimate;
