@@ -20,6 +20,9 @@
 #include "features/Features.h"
 #include "kernel/KernelNormalizer.h"
 
+#include <vector>
+#include <set>
+#include <string>
 
 namespace shogun
 {
@@ -48,10 +51,8 @@ enum EKernelType
 {
 	K_UNKNOWN = 0,
 	K_LINEAR = 10,
-	K_SPARSELINEAR = 11,
 	K_POLY = 20,
 	K_GAUSSIAN = 30,
-	K_SPARSEGAUSSIAN = 31,
 	K_GAUSSIANSHIFT = 32,
 	K_GAUSSIANMATCH = 33,
 	K_HISTOGRAM = 40,
@@ -81,7 +82,9 @@ enum EKernelType
 	K_OLIGO = 250,
 	K_MATCHWORD = 260,
 	K_TPPK = 270,
-	K_REGULATORYMODULES = 280
+	K_REGULATORYMODULES = 280,
+	K_SPARSESPATIALSAMPLE = 290,
+	K_HISTOGRAMINTERSECTION = 300
 };
 
 enum EKernelProperty
@@ -157,6 +160,7 @@ class CKernel : public CSGObject
 	friend class CMultitaskKernelMaskPairNormalizer;
 	friend class CTanimotoKernelNormalizer;
 	friend class CDiceKernelNormalizer;
+	friend class CZeroMeanCenterKernelNormalizer;
 
 	public:
 
@@ -208,6 +212,47 @@ class CKernel : public CSGObject
 		 */
 		void get_kernel_matrix(float64_t** dst, int32_t* m, int32_t* n);
 
+
+		/**
+		 * get column j
+		 *
+		 * @return the jth column of the kernel matrix
+		 */
+		virtual std::vector<float64_t> get_kernel_col(int32_t j)
+        {
+
+            std::vector<float64_t> col = std::vector<float64_t>(num_rhs);
+
+            for (int32_t i=0; i!=num_rhs; i++)
+            {
+                col[i] = kernel(i,j);
+            }
+
+        	return col;
+
+        }
+
+
+		/**
+		 * get row i
+		 *
+		 * @return the ith row of the kernel matrix
+		 */
+		virtual std::vector<float64_t> get_kernel_row(int32_t i)
+        {
+
+            std::vector<float64_t> row = std::vector<float64_t>(num_lhs);
+
+            for (int32_t j=0; j!=num_lhs; j++)
+            {
+                row[j] = kernel(i,j);
+            }
+
+        	return row;
+
+        }
+
+
 		/** get kernel matrix real
 		 *
 		 * @param m dimension m of matrix
@@ -401,9 +446,9 @@ class CKernel : public CSGObject
 		 *
 		 * @return true if features are the same
 		 */
-		inline bool lhs_equals_rhs()
+		inline bool get_lhs_equals_rhs()
 		{
-			return lhs==rhs;
+			return lhs_equals_rhs;
 		}
 
 		/** remove lhs and rhs from kernel */
@@ -692,53 +737,45 @@ class CKernel : public CSGObject
 			return NULL;
 		}
 
+		/** Can (optionally) be overridden to post-initialize some member
+		 *  variables which are not PARAMETER::ADD'ed.  Make sure that at
+		 *  first the overridden method BASE_CLASS::LOAD_SERIALIZABLE_POST
+		 *  is called.
+		 *
+		 *  @exception ShogunException Will be thrown if an error
+		 *                             occurres.
+		 */
+		virtual void load_serializable_post() throw (ShogunException);
+
+		/** Can (optionally) be overridden to pre-initialize some member
+		 *  variables which are not PARAMETER::ADD'ed.  Make sure that at
+		 *  first the overridden method BASE_CLASS::SAVE_SERIALIZABLE_PRE
+		 *  is called.
+		 *
+		 *  @exception ShogunException Will be thrown if an error
+		 *                             occurres.
+		 */
+		virtual void save_serializable_pre() throw (ShogunException);
+
+		/** Can (optionally) be overridden to post-initialize some member
+		 *  variables which are not PARAMETER::ADD'ed.  Make sure that at
+		 *  first the overridden method BASE_CLASS::SAVE_SERIALIZABLE_POST
+		 *  is called.
+		 *
+		 *  @exception ShogunException Will be thrown if an error
+		 *                             occurres.
+		 */
+		virtual void save_serializable_post() throw (ShogunException);
+
+	private:
+		/** Do basic initialisations like default settings
+		 * and registering parameters */
+		void init();
+
+
 
 		//@}
 
-
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
-
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void serialize(Archive & ar, const unsigned int archive_version)
-            {
-
-                SG_DEBUG("archiving CKernel\n");
-
-                ar & ::boost::serialization::base_object<CSGObject>(*this);
-
-                ar & cache_size;
-
-
-
-                //TODO
-                //KERNELCACHE_ELEM* kernel_matrix;
-
-                //TODO
-                //SHORTREAL * precomputed_matrix ;
-                //ar & precompute_subkernel_matrix ;
-                //ar & precompute_matrix ;
-
-                ar & rhs;
-                ar & lhs;
-
-                ar & combined_kernel_weight;
-
-                ar & optimization_initialized;
-
-                ar & opt_type;
-
-                ar & properties;
-
-                SG_DEBUG("done with CKernel\n");
-
-            }
-
-#endif //HAVE_BOOST_SERIALIZATION
-
-
-
 	protected:
 		/// cache_size in MB
 		int32_t cache_size;
@@ -754,6 +791,9 @@ class CKernel : public CSGObject
 		/// feature vectors to occur on right hand side
 		CFeatures* rhs;
 
+		/// lhs
+		bool lhs_equals_rhs;
+
 		/// number of feature vectors on left hand side
 		int32_t num_lhs;
 		/// number of feature vectors on right hand side
