@@ -4,20 +4,23 @@
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * Written (W) 1999-2009 Soeren Sonnenburg
+ * Written (W) 1999-2010 Soeren Sonnenburg
  * Copyright (C) 1999-2009 Fraunhofer Institute FIRST and Max-Planck-Society
+ * Copyright (C) 2010 Berlin Institute of Technology
  */
 
 #ifndef _LINEARKERNEL_H___
 #define _LINEARKERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
-#include "features/SimpleFeatures.h"
+#include "kernel/DotKernel.h"
+#include "features/DotFeatures.h"
 
 namespace shogun
 {
-/** @brief Computes the standard linear kernel on dense real valued features.
+	class CDotFeatures;
+
+/** @brief Computes the standard linear kernel on CDotFeatures.
  *
  * Formally, it computes
  *
@@ -25,7 +28,7 @@ namespace shogun
  * k({\bf x},{\bf x'})= {\bf x}\cdot {\bf x'}
  * \f]
  */
-class CLinearKernel: public CSimpleKernel<float64_t>
+class CLinearKernel: public CDotKernel
 {
 	public:
 		/** constructor
@@ -37,7 +40,7 @@ class CLinearKernel: public CSimpleKernel<float64_t>
 		 * @param l features of left-hand side
 		 * @param r features of right-hand side
 		 */
-		CLinearKernel(CSimpleFeatures<float64_t>* l, CSimpleFeatures<float64_t>* r);
+		CLinearKernel(CDotFeatures* l, CDotFeatures* r);
 
 		virtual ~CLinearKernel();
 
@@ -107,7 +110,7 @@ class CLinearKernel: public CSimpleKernel<float64_t>
 		{
 			if (lhs && normal)
 			{
-				len = ((CSimpleFeatures<float64_t>*) lhs)->get_num_features();
+				len = ((CDotFeatures*) lhs)->get_dim_feature_space();
 				return normal;
 			}
 			else
@@ -125,7 +128,7 @@ class CLinearKernel: public CSimpleKernel<float64_t>
 		inline void get_w(float64_t** dst_w, int32_t* dst_dims)
 		{
 			ASSERT(lhs && normal);
-			int32_t len = ((CSimpleFeatures<float64_t>*) lhs)->get_num_features();
+			int32_t len = ((CDotFeatures*) lhs)->get_dim_feature_space();
 			ASSERT(dst_w && dst_dims);
 			*dst_dims=len;
 			*dst_w=(float64_t*) malloc(sizeof(float64_t)*(*dst_dims));
@@ -140,22 +143,11 @@ class CLinearKernel: public CSimpleKernel<float64_t>
 		 */
 		inline void set_w(float64_t* src_w, int32_t src_w_dim)
 		{
-			ASSERT(lhs && src_w_dim==((CSimpleFeatures<float64_t>*) lhs)->get_num_features());
+			ASSERT(lhs && src_w_dim==((CDotFeatures*) lhs)->get_dim_feature_space());
 			clear_normal();
 			memcpy(normal, src_w, sizeof(float64_t) * src_w_dim);
 		}
 
-	protected:
-		/** compute kernel function for features a and b
-		 * idx_{a,b} denote the index of the feature vectors
-		 * in the corresponding feature object
-		 *
-		 * @param idx_a index a
-		 * @param idx_b index b
-		 * @return computed kernel function at indices a,b
-		 */
-		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
-
 	protected:
 		/** normal vector (used in case of optimized kernel) */
 		float64_t* normal;
