@@ -16,18 +16,36 @@
 
 using namespace shogun;
 
+CLocalityImprovedStringKernel::CLocalityImprovedStringKernel()
+: CStringKernel<char>(0)
+{
+	init();
+}
+
 CLocalityImprovedStringKernel::CLocalityImprovedStringKernel(
 	int32_t size, int32_t l, int32_t id, int32_t od)
-: CStringKernel<char>(size), length(l), inner_degree(id), outer_degree(od)
+: CStringKernel<char>(size)
 {
+	init();
+
+	length=l;
+	inner_degree=id;
+	outer_degree=od;
+
 	SG_INFO( "LIK with parms: l=%d, id=%d, od=%d created!\n", l, id, od);
 }
 
 CLocalityImprovedStringKernel::CLocalityImprovedStringKernel(
 	CStringFeatures<char>* l, CStringFeatures<char>* r, int32_t len,
 	int32_t id, int32_t od)
-: CStringKernel<char>(10), length(len), inner_degree(id), outer_degree(od)
+: CStringKernel<char>(10)
 {
+	init();
+
+	length=len;
+	inner_degree=id;
+	outer_degree=od;
+
 	SG_INFO( "LIK with parms: l=%d, id=%d, od=%d created!\n", len, id, od);
 
 	init(l, r);
@@ -79,3 +97,14 @@ float64_t CLocalityImprovedStringKernel::compute(int32_t idx_a, int32_t idx_b)
 	((CStringFeatures<char>*) rhs)->free_feature_vector(bvec, idx_b, free_bvec);
 	return pow(outer_sum, outer_degree + 1);
 }
+
+void CLocalityImprovedStringKernel::init()
+{
+	length = 0;
+	inner_degree = 0;
+	outer_degree = 0;
+
+	m_parameters->add(&length, "length", "Window Length.");
+	m_parameters->add(&inner_degree, "inner_degree", "Inner degree.");
+	m_parameters->add(&outer_degree, "outer_degree", "Outer degree.");
+}
