@@ -30,6 +30,9 @@ namespace shogun
 class CLocalityImprovedStringKernel: public CStringKernel<char>
 {
 	public:
+		/** default constructor  */
+		CLocalityImprovedStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -85,6 +88,9 @@ class CLocalityImprovedStringKernel: public CStringKernel<char>
 		 */
 		float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
 		/** length */
 		int32_t length;
