@@ -37,6 +37,9 @@ namespace shogun
 class CMatchWordStringKernel: public CStringKernel<uint16_t>
 {
 	public:
+		/** default constructor  */
+		CMatchWordStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -85,6 +88,9 @@ class CMatchWordStringKernel: public CStringKernel<uint16_t>
 		 */
 		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
 		/** degree */
 		int32_t degree;
