@@ -41,6 +41,9 @@ namespace shogun
 class COligoStringKernel : public CStringKernel<char>
 {
 	public:
+		/** default constructor  */
+		COligoStringKernel(void);
+
 		/** Constructor
 		 * @param cache_size cache size for kernel
 		 * @param k k-mer length
@@ -69,7 +72,7 @@ class COligoStringKernel : public CStringKernel<char>
 		 *
 		 * @return name Oligo
 		 */
-		virtual const char* get_name() const { return "Oligo"; }
+		virtual const char* get_name() const { return "OligoStringKernel"; }
 
 
 		virtual float64_t compute(int32_t x, int32_t y);
@@ -148,13 +151,17 @@ class COligoStringKernel : public CStringKernel<char>
 			return (a.second < b.second);
 		}
 
+		void init();
+
 	protected:
-		/** member variable k */
+		/** k-mer length */
 		int32_t k;
 		/** width of kernel */
 		float64_t width;
 		/** cache for exp (see getExpFunctionCache above) */
 		float64_t* gauss_table;
+		/** length of gauss table */
+		int32_t gauss_table_len;
 };
 }
 #endif // _OLIGOSTRINGKERNEL_H_
