@@ -4,21 +4,23 @@
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * Written (W) 1999-2009 Soeren Sonnenburg
+ * Written (W) 1999-2010 Soeren Sonnenburg
  * Copyright (C) 1999-2009 Fraunhofer Institute FIRST and Max-Planck-Society
+ * Copyright (C) 2010 Berlin Institute of Technology
  */
 
 #ifndef _POLYKERNEL_H___
 #define _POLYKERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
-#include "features/SimpleFeatures.h"
+#include "kernel/DotKernel.h"
+#include "features/DotFeatures.h"
 
 namespace shogun
 {
-/** @brief Computes the standard polynomial kernel on dense real valued
- * features.
+	class CDotFeatures;
+
+/** @brief Computes the standard polynomial kernel on CDotFeatures
  *
  * Formally, it computes
  *
@@ -31,9 +33,14 @@ namespace shogun
  *     k'({\bf x}, {\bf x'})=\frac{k({\bf x}, {\bf x'})}{\sqrt{k({\bf x}, {\bf x})k({\bf x'}, {\bf x'})}}
  * \f]
  */
-class CPolyKernel: public CSimpleKernel<float64_t>
+class CPolyKernel: public CDotKernel
 {
+	void init(void);
+
 	public:
+		/** default constructor  */
+		CPolyKernel(void);
+
 		/** constructor
 		 *
 		 * @param l features of left-hand side
@@ -42,7 +49,7 @@ class CPolyKernel: public CSimpleKernel<float64_t>
 		 * @param inhom is inhomogeneous
 		 * @param size cache size
 		 */
-		CPolyKernel(CSimpleFeatures<float64_t>* l, CSimpleFeatures<float64_t>* r,
+		CPolyKernel(CDotFeatures* l, CDotFeatures* r,
 			int32_t d, bool inhom, int32_t size=10);
 
 		/** constructor
@@ -76,7 +83,7 @@ class CPolyKernel: public CSimpleKernel<float64_t>
 		 *
 		 * @return name Poly
 		 */
-		virtual const char* get_name() const { return "Poly"; };
+		virtual const char* get_name() const { return "PolyKernel"; };
 
 	protected:
 		/** compute kernel function for features a and b
