@@ -17,17 +17,30 @@
 
 using namespace shogun;
 
-CPolyMatchWordStringKernel::CPolyMatchWordStringKernel(int32_t size, int32_t d, bool i)
-: CStringKernel<uint16_t>(size),degree(d),inhomogene(i)
+CPolyMatchWordStringKernel::CPolyMatchWordStringKernel(void)
+: CStringKernel<uint16_t>()
 {
-	set_normalizer(new CSqrtDiagKernelNormalizer());
+	init();
+}
+
+CPolyMatchWordStringKernel::CPolyMatchWordStringKernel(int32_t size, int32_t d, bool i)
+: CStringKernel<uint16_t>(size)
+{
+	init();
+
+	degree=d;
+	inhomogene=i;
 }
 
 CPolyMatchWordStringKernel::CPolyMatchWordStringKernel(
 	CStringFeatures<uint16_t>* l, CStringFeatures<uint16_t>* r, int32_t d, bool i)
-: CStringKernel<uint16_t>(10),degree(d),inhomogene(i)
+: CStringKernel<uint16_t>()
 {
-	set_normalizer(new CSqrtDiagKernelNormalizer());
+	init();
+
+	degree=d;
+	inhomogene=i;
+
 	init(l, r);
 }
 
@@ -74,3 +87,13 @@ float64_t CPolyMatchWordStringKernel::compute(int32_t idx_a, int32_t idx_b)
 	((CStringFeatures<uint16_t>*) rhs)->free_feature_vector(bvec, idx_b, free_bvec);
 	return result;
 }
+
+void CPolyMatchWordStringKernel::init()
+{
+	degree=0;
+	inhomogene=false;
+	set_normalizer(new CSqrtDiagKernelNormalizer());
+
+	m_parameters->add(&degree, "degree", "Degree of poly-kernel.");
+	m_parameters->add(&inhomogene, "inhomogene", "True for inhomogene poly-kernel.");
+}
