@@ -38,6 +38,9 @@ namespace shogun
 class CPolyMatchWordStringKernel: public CStringKernel<uint16_t>
 {
 	public:
+		/** default constructor  */
+		CPolyMatchWordStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -91,6 +94,9 @@ class CPolyMatchWordStringKernel: public CStringKernel<uint16_t>
 		 */
 		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
 
+	private:
+		void init();
+
 	protected:
 		/** degree */
 		int32_t degree;
