@@ -29,6 +29,9 @@ namespace shogun
 class CSalzbergWordStringKernel: public CStringKernel<uint16_t>
 {
 	public:
+		/** default constructor  */
+		CSalzbergWordStringKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -114,6 +117,8 @@ class CSalzbergWordStringKernel: public CStringKernel<uint16_t>
 		{
 			return position*num_symbols+symbol;
 		}
+	private:
+		void init();
 
 	protected:
 		/** the plugin estimate */
