@@ -4,16 +4,17 @@
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * Written (W) 1999-2009 Soeren Sonnenburg
+ * Written (W) 1999-2010 Soeren Sonnenburg
  * Copyright (C) 1999-2009 Fraunhofer Institute FIRST and Max-Planck-Society
+ * Copyright (C) 2010 Berlin Institute of Technology
  */
 
 #ifndef _SIGMOIDKERNEL_H___
 #define _SIGMOIDKERNEL_H___
 
 #include "lib/common.h"
-#include "kernel/SimpleKernel.h"
-#include "features/SimpleFeatures.h"
+#include "kernel/DotKernel.h"
+#include "features/DotFeatures.h"
 
 namespace shogun
 {
@@ -25,9 +26,12 @@ namespace shogun
  * k({\bf x},{\bf x'})=\mbox{tanh}(\gamma {\bf x}\cdot{\bf x'}+c)
  * \f]
  */
-class CSigmoidKernel: public CSimpleKernel<float64_t>
+class CSigmoidKernel: public CDotKernel
 {
 	public:
+		/** default constructor  */
+		CSigmoidKernel();
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -44,7 +48,7 @@ class CSigmoidKernel: public CSimpleKernel<float64_t>
 		 * @param gamma gamma
 		 * @param coef0 coefficient 0
 		 */
-		CSigmoidKernel(CSimpleFeatures<float64_t>* l, CSimpleFeatures<float64_t>* r, int32_t size,
+		CSigmoidKernel(CDotFeatures* l, CDotFeatures* r, int32_t size,
 			float64_t gamma, float64_t coef0);
 
 		virtual ~CSigmoidKernel();
@@ -81,7 +85,13 @@ class CSigmoidKernel: public CSimpleKernel<float64_t>
 		 * @param idx_b index b
 		 * @return computed kernel function at indices a,b
 		 */
-		virtual float64_t compute(int32_t idx_a, int32_t idx_b);
+		inline virtual float64_t compute(int32_t idx_a, int32_t idx_b)
+		{
+			return tanh(gamma*CDotKernel::compute(idx_a,idx_b)+coef0);
+		}
+
+	private:
+		void init();
 
 	protected:
 		/** gamma */
