@@ -16,19 +16,34 @@
 
 using namespace shogun;
 
+CSimpleLocalityImprovedStringKernel::CSimpleLocalityImprovedStringKernel()
+: CStringKernel<char>()
+{
+	init();
+}
+
 CSimpleLocalityImprovedStringKernel::CSimpleLocalityImprovedStringKernel(
 	int32_t size, int32_t l, int32_t id, int32_t od)
-: CStringKernel<char>(size), length(l), inner_degree(id), outer_degree(od),
-	pyramid_weights(NULL)
+: CStringKernel<char>(size)
 {
+	init();
+
+	length=l;
+	inner_degree=id;
+	outer_degree=od;
 }
 
 CSimpleLocalityImprovedStringKernel::CSimpleLocalityImprovedStringKernel(
 	CStringFeatures<char>* l, CStringFeatures<char>* r,
 	int32_t len, int32_t id, int32_t od)
-: CStringKernel<char>(10), length(len), inner_degree(id), outer_degree(od),
-	pyramid_weights(NULL)
+: CStringKernel<char>()
 {
+	init();
+
+	length=len;
+	inner_degree=id;
+	outer_degree=od;
+
 	init(l, r);
 }
 
@@ -43,14 +58,19 @@ bool CSimpleLocalityImprovedStringKernel::init(CFeatures* l, CFeatures* r)
 
 	if (!result)
 		return false;
-	int32_t num_features = ((CStringFeatures<char>*) l)->get_max_vector_length();
+	const int32_t num_features = ((CStringFeatures<char>*) l)->get_max_vector_length();
+	const int32_t PYRAL = 2 * length - 1; // total window length
+	const int32_t pyra_len  = num_features-PYRAL+1;
+	const int32_t pyra_len2 = (int32_t) pyra_len/2;
+
 	delete[] pyramid_weights;
-	pyramid_weights = new float64_t[num_features];
+
+	pyramid_weights = new float64_t[pyra_len];
+	num_pyramid_weights=pyra_len;
 
 	SG_INFO("initializing pyramid weights: size=%ld length=%i\n",
 		num_features, length);
 
-	const int32_t PYRAL = 2 * length - 1; // total window length
 	float64_t PYRAL_pot;
 	int32_t DEGREE1_1  = (inner_degree & 0x1)==0;
 	int32_t DEGREE1_1n = (inner_degree & ~0x1)!=0;
@@ -74,8 +94,6 @@ bool CSimpleLocalityImprovedStringKernel::init(CFeatures* l, CFeatures* r)
 	}
 	}
 
-	int32_t pyra_len  = num_features-PYRAL+1;
-	int32_t pyra_len2 = (int32_t) pyra_len/2;
 	{
 	int32_t j;
 	for (j = 0; j < pyra_len; j++)
@@ -91,6 +109,7 @@ void CSimpleLocalityImprovedStringKernel::cleanup()
 {
 	delete[] pyramid_weights;
 	pyramid_weights = NULL;
+	num_pyramid_weights = 0;
 
 	CKernel::cleanup();
 }
@@ -197,9 +216,25 @@ float64_t CSimpleLocalityImprovedStringKernel::compute(
 	float64_t dpt;
 
 	dpt = dot_pyr(avec, bvec, alen, length, inner_degree, outer_degree, pyramid_weights);
-	dpt = dpt / pow((float64_t)alen, (float64_t)outer_degree);
+	dpt = dpt / pow((float64_t) alen, (float64_t) outer_degree);
 
 	((CStringFeatures<char>*) lhs)->free_feature_vector(avec, idx_a, free_avec);
 	((CStringFeatures<char>*) rhs)->free_feature_vector(bvec, idx_b, free_bvec);
 	return (float64_t) dpt;
 }
+
+void CSimpleLocalityImprovedStringKernel::init()
+{
+	length = 3;
+	inner_degree = 3;
+	outer_degree = 1;
+	pyramid_weights=NULL;
+	num_pyramid_weights=0;
+
+	m_parameters->add(&length, "length", "Window Length.");
+	m_parameters->add(&inner_degree, "inner_degree", "Inner degree.");
+	m_parameters->add(&outer_degree, "outer_degree", "Outer degree.");
+
+	m_parameters->add_vector(&pyramid_weights, &num_pyramid_weights,
+			"pyramid_weights", "Pyramid weights.");
+}
