@@ -28,7 +28,7 @@ template <class ST> class CStringKernel : public CKernel
 		 *
 		 * @param cachesize cache size
 		 */
-		CStringKernel(int32_t cachesize) : CKernel(cachesize) {}
+		CStringKernel(int32_t cachesize=0) : CKernel(cachesize) {}
 
 		/** constructor
 		 *
@@ -74,21 +74,22 @@ template <class ST> class CStringKernel : public CKernel
 		 */
 		virtual EFeatureType get_feature_type();
 
-#ifdef HAVE_BOOST_SERIALIZATION
-    private:
-
-        friend class ::boost::serialization::access;
-        template<class Archive>
-            void serialize(Archive & ar, const unsigned int archive_version)
-            {
-
-                SG_DEBUG("archiving CStringKernel\n");
-                ar & ::boost::serialization::base_object<CKernel>(*this);
-
-                SG_DEBUG("done CStringKernel\n");
-            }
-#endif //HAVE_BOOST_SERIALIZATION
+		/** Returns the name of the SGSerializable instance.  It MUST BE
+		 *  the CLASS NAME without the prefixed `C'.
+		 *
+		 *  @return name of the SGSerializable
+		 */
+		virtual const char* get_name(void) const {
+			return "StringKernel"; }
 
+		/** return what type of kernel we are, e.g.
+		 * Linear,Polynomial, Gaussian,...
+		 *
+		 * abstract base method
+		 *
+		 * @return kernel type
+		 */
+		virtual EKernelType get_kernel_type()=0;
 };
 
 template<> inline EFeatureType CStringKernel<float64_t>::get_feature_type() { return F_DREAL; }
