@@ -30,8 +30,9 @@ class CTanimotoKernelNormalizer : public CKernelNormalizer
 		 * @param use_opt_diag - some kernels support faster diagonal compuation
 		 * via compute_diag(idx), this flag enables this
 		 */
-		CTanimotoKernelNormalizer(bool use_opt_diag=false) : diag_lhs(NULL),
-			diag_rhs(NULL), use_optimized_diagonal_computation(use_opt_diag)
+		CTanimotoKernelNormalizer(bool use_opt_diag=false)
+			: CKernelNormalizer(), diag_lhs(NULL), diag_rhs(NULL),
+			use_optimized_diagonal_computation(use_opt_diag)
 		{
 		}
 
@@ -101,6 +102,14 @@ class CTanimotoKernelNormalizer : public CKernelNormalizer
 			return 0;
 		}
 
+		/** Returns the name of the SGSerializable instance.  It MUST BE
+		 *  the CLASS NAME without the prefixed `C'.
+		 *
+		 * @return name of the SGSerializable
+		 */
+		virtual const char* get_name(void) const {
+			return "TanimotoKernelNormalizer"; }
+
     public:
 		/**
 		 * alloc and compute the vector containing the square root of the
