@@ -50,64 +50,67 @@ template <class Trie> struct S_THREAD_PARAM
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 CWeightedDegreePositionStringKernel::CWeightedDegreePositionStringKernel(
-	int32_t size, int32_t d, int32_t mm, int32_t mkls)
-: CStringKernel<char>(size), weights(NULL), position_weights(NULL),
-	position_weights_lhs(NULL), position_weights_rhs(NULL),
-	weights_buffer(NULL), mkl_stepsize(mkls), degree(d), length(0),
-	max_mismatch(mm), seq_length(0), shift(NULL), shift_len(0),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(E_EXTERNAL), tries(d), poim_tries(d),
-	tree_initialized(false), use_poim_tries(false), m_poim_distrib(NULL),
-	m_poim(NULL), m_poim_num_sym(0), m_poim_num_feat(0), m_poim_result_len(0),
-	alphabet(NULL)
+	void)
+: CStringKernel<char>()
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+	init();
+}
+
+CWeightedDegreePositionStringKernel::CWeightedDegreePositionStringKernel(
+	int32_t size, int32_t d, int32_t mm, int32_t mkls)
+: CStringKernel<char>(size)
+{
+	init();
+
+	mkl_stepsize=mkls;
+	degree=d;
+	max_mismatch=mm;
+
+	tries=CTrie<DNATrie>(d);
+	poim_tries=CTrie<POIMTrie>(d);
+
 	set_wd_weights();
 	ASSERT(weights);
-
-	set_normalizer(new CSqrtDiagKernelNormalizer());
 }
 
 CWeightedDegreePositionStringKernel::CWeightedDegreePositionStringKernel(
 	int32_t size, float64_t* w, int32_t d, int32_t mm, int32_t* s, int32_t sl,
 	int32_t mkls)
-: CStringKernel<char>(size), weights(NULL), position_weights(NULL),
-	position_weights_lhs(NULL), position_weights_rhs(NULL),
-	weights_buffer(NULL), mkl_stepsize(mkls), degree(d), length(0),
-	max_mismatch(mm), seq_length(0), shift(NULL), shift_len(0),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(E_EXTERNAL), tries(d), poim_tries(d),
-	tree_initialized(false), use_poim_tries(false), m_poim_distrib(NULL),
-	m_poim(NULL), m_poim_num_sym(0), m_poim_num_feat(0), m_poim_result_len(0),
-	alphabet(NULL)
+: CStringKernel<char>(size)
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+	init();
+
+	mkl_stepsize=mkls;
+	degree=d;
+	max_mismatch=mm;
+
+	tries=CTrie<DNATrie>(d);
+	poim_tries=CTrie<POIMTrie>(d);
 
 	weights=new float64_t[d*(1+max_mismatch)];
+	weights_degree=degree;
+	weights_length=(1+max_mismatch);
+
 	for (int32_t i=0; i<d*(1+max_mismatch); i++)
 		weights[i]=w[i];
 
 	set_shifts(s, sl);
-
-	set_normalizer(new CSqrtDiagKernelNormalizer());
 }
 
 CWeightedDegreePositionStringKernel::CWeightedDegreePositionStringKernel(
 	CStringFeatures<char>* l, CStringFeatures<char>* r, int32_t d)
-: CStringKernel<char>(10), weights(NULL), position_weights(NULL),
-	position_weights_lhs(NULL), position_weights_rhs(NULL),
-	weights_buffer(NULL), mkl_stepsize(1), degree(d), length(0),
-	max_mismatch(0), seq_length(0), shift(NULL), shift_len(0),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(E_EXTERNAL), tries(d), poim_tries(d),
-	tree_initialized(false), use_poim_tries(false), m_poim_distrib(NULL),
-	m_poim(NULL), m_poim_num_sym(0), m_poim_num_feat(0), m_poim_result_len(0),
-	alphabet(NULL)
+: CStringKernel<char>()
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+	init();
+
+	mkl_stepsize=1;
+	degree=d;
+
+	tries=CTrie<DNATrie>(d);
+	poim_tries=CTrie<POIMTrie>(d);
+
 	set_wd_weights();
 	ASSERT(weights);
-	set_normalizer(new CSqrtDiagKernelNormalizer());
 
 	init(l, r);
 }
@@ -122,7 +125,9 @@ CWeightedDegreePositionStringKernel::~CWeightedDegreePositionStringKernel()
 	shift=NULL;
 
 	delete[] weights;
-	weights=NULL ;
+	weights=NULL;
+	weights_degree=0;
+	weights_length=0;
 
 	delete[] block_weights;
 	block_weights=NULL;
@@ -452,6 +457,7 @@ float64_t CWeightedDegreePositionStringKernel::compute_without_mismatch(
 		result += max_shift_vec[i]/(2*(i+1)) ;
 
 	delete[] max_shift_vec;
+
 	return result ;
 }
 
@@ -523,7 +529,6 @@ float64_t CWeightedDegreePositionStringKernel::compute_without_mismatch_position
 	char* avec, float64_t* pos_weights_lhs, int32_t alen, char* bvec,
 	float64_t* pos_weights_rhs, int32_t blen)
 {
-
 	float64_t* max_shift_vec = new float64_t[max_shift];
 	float64_t sum0=0 ;
 	for (int32_t i=0; i<max_shift; i++)
@@ -618,14 +623,7 @@ float64_t CWeightedDegreePositionStringKernel::compute(
 		ASSERT(max_mismatch==0);
 		float64_t* position_weights_rhs_ = position_weights_rhs ;
 		if (lhs==rhs)
-		{
-			//fprintf(stdout, ".") ;
 			position_weights_rhs_ = position_weights_lhs ;
-		}
-		else
-		{
-			//fprintf(stdout, "*") ;
-		}
 		
 		result = compute_without_mismatch_position_weights(avec, &position_weights_lhs[idx_a*alen], alen, bvec, &position_weights_rhs_[idx_b*blen], blen) ;
 	}
@@ -683,13 +681,10 @@ void CWeightedDegreePositionStringKernel::add_example_to_tree(
 		{
 			float64_t alpha_pw = normalizer->normalize_lhs((s==0) ? (alpha) : (alpha/(2.0*s)), idx);
 			TRIES(add_to_trie(i, s, vec, alpha_pw, weights, (length!=0))) ;
-			//fprintf(stderr, "tree=%i, s=%i, example=%i, alpha_pw=%1.2f\n", i, s, idx, alpha_pw) ;
-
 			if ((s==0) || (i+s>=len))
 				continue;
 
 			TRIES(add_to_trie(i+s, -s, vec, alpha_pw, weights, (length!=0))) ;
-			//fprintf(stderr, "tree=%i, s=%i, example=%i, alpha_pw=%1.2f\n", i+s, -s, idx, alpha_pw) ;
 		}
 	}
 
@@ -733,7 +728,6 @@ void CWeightedDegreePositionStringKernel::add_example_to_single_tree(
 	{
 		float64_t alpha_pw = normalizer->normalize_lhs((s==0) ? (alpha) : (alpha/(2.0*s)), idx);
 		tries.add_to_trie(tree_num, s, vec, alpha_pw, weights, (length!=0)) ;
-		//fprintf(stderr, "tree=%i, s=%i, example=%i, alpha_pw=%1.2f\n", tree_num, s, idx, alpha_pw) ;
 	} 
 
 	if (opt_type==FASTBUTMEMHUNGRY)
@@ -745,7 +739,6 @@ void CWeightedDegreePositionStringKernel::add_example_to_single_tree(
 			{
 				float64_t alpha_pw = normalizer->normalize_lhs((s==0) ? (alpha) : (alpha/(2.0*s)), idx);
 				tries.add_to_trie(tree_num, -s, vec, alpha_pw, weights, (length!=0)) ; 
-				//fprintf(stderr, "tree=%i, s=%i, example=%i, alpha_pw=%1.2f\n", tree_num, -s, idx, alpha_pw) ;
 			}
 		}
 	}
@@ -856,8 +849,7 @@ bool CWeightedDegreePositionStringKernel::set_shifts(
 		for (int32_t i=0; i<shift_len; i++)
 		{
 			shift[i] = shift_[i] ;
-			if (shift[i]>max_shift)
-				max_shift = shift[i] ;
+			max_shift = CMath::max(shift[i], max_shift);
 		}
 
 		ASSERT(max_shift>=0 && max_shift<=shift_len);
@@ -872,6 +864,9 @@ bool CWeightedDegreePositionStringKernel::set_wd_weights()
 
 	delete[] weights;
 	weights=new float64_t[degree];
+	weights_degree=degree;
+	weights_length=1;
+
 	if (weights)
 	{
 		int32_t i;
@@ -907,24 +902,27 @@ bool CWeightedDegreePositionStringKernel::set_wd_weights()
 bool CWeightedDegreePositionStringKernel::set_weights(
 	float64_t* ws, int32_t d, int32_t len)
 {
-	SG_DEBUG("degree = %i  d=%i\n", degree, d);
+	if (d!=degree || len<0)
+		SG_ERROR("WD: Dimension mismatch (should be (seq_length | 1) x degree) got (%d x %d)\n", len, degree);
+
 	degree=d;
 	length=len;
 
 	if (len <= 0)
 		len=1;
 
-	delete[] weights;
-	weights=new float64_t[d*len];
+	weights_degree=degree;
+	weights_length=len+max_mismatch;
 
-	if (weights)
-	{
-		for (int32_t i=0; i<degree*len; i++)
-			weights[i]=ws[i];
-		return true;
-	}
-	else
-		return false;
+	SG_DEBUG("Creating weights of size %dx%d\n", weights_degree, weights_length);
+	int32_t num_weights=weights_degree*weights_length;
+	delete[] weights;
+	weights=new float64_t[num_weights];
+
+	for (int32_t i=0; i<degree*len; i++)
+		weights[i]=ws[i];
+
+	return true;
 }
 
 bool CWeightedDegreePositionStringKernel::set_position_weights(
@@ -940,6 +938,7 @@ bool CWeightedDegreePositionStringKernel::set_position_weights(
 	}
 	delete[] position_weights;
 	position_weights=new float64_t[len];
+	position_weights_len=len;
 	tries.set_position_weights(position_weights);
 
 	if (position_weights)
@@ -954,8 +953,6 @@ bool CWeightedDegreePositionStringKernel::set_position_weights(
 
 bool CWeightedDegreePositionStringKernel::set_position_weights_lhs(float64_t* pws, int32_t len, int32_t num)
 {
-	fprintf(stderr, "set_position_weights_lhs %i %i %i\n", len, num, seq_length);
-
 	if (position_weights_rhs==position_weights_lhs)
 		position_weights_rhs=NULL;
 	else
@@ -971,37 +968,20 @@ bool CWeightedDegreePositionStringKernel::set_position_weights_lhs(float64_t* pw
 		SG_ERROR("seq_length = %i, position_weights_length=%i\n", seq_length, len);
 		return false;
 	}
-	if (0)
-	{
-		
-	if (!lhs)
-	{
-		SG_ERROR("lhs=NULL\n");
-		return false ;
-	}
-	if (lhs->get_num_vectors()!=num)
-	{
-		SG_ERROR("lhs->get_num_vectors()=%i, num=%i\n", lhs->get_num_vectors(), num);
-		return false;
-	}
-	}
 	
 	delete[] position_weights_lhs;
 	position_weights_lhs=new float64_t[len*num];
-	if (position_weights_lhs)
-	{
-		for (int32_t i=0; i<len*num; i++)
-			position_weights_lhs[i]=pws[i];
-		return true;
-	}
-	else
-		return false;
+	position_weights_lhs_len=len*num;
+
+	for (int32_t i=0; i<len*num; i++)
+		position_weights_lhs[i]=pws[i];
+
+	return true;
 }
 
 bool CWeightedDegreePositionStringKernel::set_position_weights_rhs(
 	float64_t* pws, int32_t len, int32_t num)
 {
-	fprintf(stderr, "set_position_weights_rhs %i %i %i\n", len, num, seq_length);
 	if (len==0)
 	{
 		if (position_weights_rhs==position_weights_lhs)
@@ -1017,39 +997,15 @@ bool CWeightedDegreePositionStringKernel::set_position_weights_rhs(
 		SG_ERROR("seq_length = %i, position_weights_length=%i\n", seq_length, len);
 		return false;
 	}
-	if (0)
-	{
-		
-	if (!rhs)
-	{
-		if (!lhs)
-		{
-			SG_ERROR("rhs=NULL and lhs=NULL\n");
-			return false;
-		}
-		if (lhs->get_num_vectors()!=num)
-		{
-			SG_ERROR("lhs->get_num_vectors()=%i, num=%i\n", lhs->get_num_vectors(), num);
-			return false;
-		}
-	} else
-		if (rhs->get_num_vectors()!=num)
-		{
-			SG_ERROR("rhs->get_num_vectors()=%i, num=%i\n", rhs->get_num_vectors(), num);
-			return false;
-		}
-	}
 	
 	delete[] position_weights_rhs;
 	position_weights_rhs=new float64_t[len*num];
-	if (position_weights_rhs)
-	{
-		for (int32_t i=0; i<len*num; i++)
-			position_weights_rhs[i]=pws[i];
-		return true;
-	}
-	else
-		return false;
+	position_weights_rhs_len=len*num;
+
+	for (int32_t i=0; i<len*num; i++)
+		position_weights_rhs[i]=pws[i];
+
+	return true;
 }
 
 bool CWeightedDegreePositionStringKernel::init_block_weights_from_wd()
@@ -1196,25 +1152,6 @@ bool CWeightedDegreePositionStringKernel::init_block_weights_log()
 	return (block_weights!=NULL);
 }
 
-bool CWeightedDegreePositionStringKernel::init_block_weights_external()
-{
-	if (block_weights_external && (seq_length == num_block_weights_external) )
-	{
-		delete[] block_weights;
-		block_weights=new float64_t[seq_length];
-
-		if (block_weights)
-		{
-			for (int32_t i=0; i<seq_length; i++)
-				block_weights[i]=block_weights_external[i];
-		}
-	}
-	else {
-      SG_ERROR( "sequence longer then weights (seqlen:%d, wlen:%d)\n", seq_length, block_weights_external);
-   }
-	return (block_weights!=NULL);
-}
-
 bool CWeightedDegreePositionStringKernel::init_block_weights()
 {
 	switch (type)
@@ -1235,11 +1172,8 @@ bool CWeightedDegreePositionStringKernel::init_block_weights()
 			return init_block_weights_exp();
 		case E_BLOCK_LOG:
 			return init_block_weights_log();
-		case E_BLOCK_EXTERNAL:
-			return init_block_weights_external();
-		default:
-			return false;
 	};
+	return false;
 }
 
 
@@ -1589,10 +1523,10 @@ char* CWeightedDegreePositionStringKernel::compute_consensus(
 
 	//backtracking and scoring table
 	int32_t num_tables=CMath::max(1,num_feat-degree+1);
-	CDynamicArray<ConsensusEntry>** table=new CDynamicArray<ConsensusEntry>*[num_tables];
+	DynArray<ConsensusEntry>** table=new DynArray<ConsensusEntry>*[num_tables];
 
 	for (int32_t i=0; i<num_tables; i++)
-		table[i]=new CDynamicArray<ConsensusEntry>(num_suppvec/10);
+		table[i]=new DynArray<ConsensusEntry>(num_suppvec/10);
 
 	//compute consensus via dynamic programming
 	for (int32_t i=0; i<num_tables; i++)
@@ -1954,3 +1888,85 @@ void CWeightedDegreePositionStringKernel::cleanup_POIM2()
 	m_poim_result_len=0 ;
 }
 
+void CWeightedDegreePositionStringKernel::load_serializable_post(void) throw (ShogunException)
+{
+	CKernel::load_serializable_post();
+
+	tries=CTrie<DNATrie>(degree);
+	poim_tries=CTrie<POIMTrie>(degree);
+
+	if (weights)
+		init_block_weights();
+}
+
+void CWeightedDegreePositionStringKernel::init()
+{
+	weights=NULL;
+	position_weights=NULL;
+	position_weights_len=0;
+
+	position_weights_lhs=NULL;
+	position_weights_lhs_len=0;
+	position_weights_rhs=NULL;
+	position_weights_rhs_len=0;
+
+	weights_buffer=NULL;
+	mkl_stepsize=1;
+	degree=1;
+	length=0;
+
+	max_shift=0;
+	max_mismatch=0;
+	seq_length=0;
+	shift=NULL;
+	shift_len=0;
+
+	block_weights=NULL;
+	block_computation=true;
+	type=E_EXTERNAL;
+	which_degree=-1;
+	tries=CTrie<DNATrie>(1);
+	poim_tries=CTrie<POIMTrie>(1);
+
+	tree_initialized=false;
+	use_poim_tries=false;
+	m_poim_distrib=NULL;
+
+	m_poim=NULL;
+	m_poim_num_sym=0;
+	m_poim_num_feat=0;
+	m_poim_result_len=0;
+
+	alphabet=NULL;
+
+	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+
+	set_normalizer(new CSqrtDiagKernelNormalizer());
+
+	m_parameters->add_matrix(&weights, &weights_degree, &weights_length,
+			"weights", "WD Kernel weights.");
+	m_parameters->add_vector(&position_weights, &position_weights_len,
+			"position_weights",
+			"Weights per position.");
+	m_parameters->add_vector(&position_weights_lhs, &position_weights_lhs_len,
+			"position_weights_lhs",
+			"Weights per position left hand side.");
+	m_parameters->add_vector(&position_weights_rhs, &position_weights_rhs_len,
+			"position_weights_rhs",
+			"Weights per position right hand side.");
+	m_parameters->add_vector(&shift, &shift_len,
+			"shift",
+			"Shift Vector.");
+	m_parameters->add(&mkl_stepsize, "mkl_stepsize", "MKL step size.");
+	m_parameters->add(&degree, "degree", "Order of WD kernel.");
+	m_parameters->add(&max_mismatch, "max_mismatch",
+			"Number of allowed mismatches.");
+	m_parameters->add(&block_computation, "block_computation",
+			"If block computation shall be used.");
+	m_parameters->add((machine_int_t*) &type, "type",
+			"WeightedDegree kernel type.");
+	m_parameters->add(&which_degree, "which_degree",
+			"Unqueal -1 if just a single degree is selected.");
+	m_parameters->add((CSGObject**) &alphabet, "alphabet",
+			"Alphabet of Features.");
+}
