@@ -48,6 +48,9 @@ class CSVM;
 class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 {
 	public:
+		/** default constructor  */
+		CWeightedDegreePositionStringKernel(void);
+
 		/** constructor
 		 *
 		 * @param size cache size
@@ -467,12 +470,6 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 		 */
 		bool init_block_weights_log();
 
-		/** initialize block weights external
-		 *
-		 * @return if initialization was successful
-		 */
-		bool init_block_weights_external();
-
 		/** delete position weights
 		 *
 		 * @return if deleting was successful
@@ -690,15 +687,42 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 		/** remove lhs from kernel */
 		virtual void remove_lhs();
 
+		/** Can (optionally) be overridden to post-initialize some
+		 *  member variables which are not PARAMETER::ADD'ed.  Make
+		 *  sure that at first the overridden method
+		 *  BASE_CLASS::LOAD_SERIALIZABLE_POST is called.
+		 *
+		 *  @exception ShogunException Will be thrown if an error
+		 *                             occurres.
+		 */
+		virtual void load_serializable_post(void) throw (ShogunException);
+
+	private:
+		/** Do basic initialisations like default settings
+		 * and registering parameters */
+		void init();
+
 	protected:
 		/** weights */
 		float64_t* weights;
+		/** degree */
+		int32_t weights_degree;
+		/** length */
+		int32_t weights_length;
+
 		/** position weights */
 		float64_t* position_weights;
+		/** position weights len */
+		int32_t position_weights_len;
+
 		/** position weights left-hand side */
 		float64_t* position_weights_lhs;
+		/** position weights len */
+		int32_t position_weights_lhs_len;
 		/** position weights right-hand side */
 		float64_t* position_weights_rhs;
+		/** position weights len */
+		int32_t position_weights_rhs_len;
 		/** position mask */
 		bool* position_mask;
 
@@ -727,11 +751,6 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 		/** if block computation is used */
 		bool block_computation;
 
-		/** number of external block weights */
-		int32_t num_block_weights_external;
-		/** external block weights */
-		float64_t* block_weights_external;
-
 		/** (internal) block weights */
 		float64_t* block_weights;
 		/** WeightedDegree kernel type */
