@@ -13,6 +13,7 @@
 #include "lib/io.h"
 #include "lib/Signal.h"
 #include "lib/Trie.h"
+#include "base/Parameter.h"
 #include "base/Parallel.h"
 
 #include "kernel/WeightedDegreeStringKernel.h"
@@ -24,13 +25,6 @@
 #include <pthread.h>
 #endif
 
-
-#ifdef HAVE_BOOST_SERIALIZATION
-#include <boost/serialization/export.hpp>
-BOOST_CLASS_EXPORT(shogun::CWeightedDegreeStringKernel);
-#endif //HAVE_BOOST_SERIALIZATION
-
-
 using namespace shogun;
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -51,56 +45,50 @@ struct S_THREAD_PARAM
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
+CWeightedDegreeStringKernel::CWeightedDegreeStringKernel ()
+: CStringKernel<char>()
+{
+	init();
+}
+
 
 CWeightedDegreeStringKernel::CWeightedDegreeStringKernel (
-	int32_t degree_, EWDKernType type_)
-: CStringKernel<char>(10),weights(NULL),position_weights(NULL),
-	weights_buffer(NULL), mkl_stepsize(1),degree(degree_), length(0),
-	max_mismatch(0), seq_length(0), block_computation(true),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(type_), which_degree(-1), tries(NULL),
-	tree_initialized(false), alphabet(NULL)
+	int32_t d, EWDKernType t)
+: CStringKernel<char>()
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
-	lhs=NULL;
-	rhs=NULL;
+	init();
+
+	degree=d;
+	type=t;
 
 	if (type!=E_EXTERNAL)
 		set_wd_weights_by_type(type);
-
-	set_normalizer(new CFirstElementKernelNormalizer());
 }
 
 CWeightedDegreeStringKernel::CWeightedDegreeStringKernel (
-	float64_t *weights_, int32_t degree_)
-: CStringKernel<char>(10), weights(NULL), position_weights(NULL),
-	weights_buffer(NULL), mkl_stepsize(1), degree(degree_), length(0),
-	max_mismatch(0), seq_length(0), block_computation(true),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(E_EXTERNAL), which_degree(-1), tries(NULL),
-	tree_initialized(false), alphabet(NULL)
+	float64_t *w, int32_t d)
+: CStringKernel<char>(10)
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
-	lhs=NULL;
-	rhs=NULL;
+	init();
+
+	type=E_EXTERNAL;
+	degree=d;
 
 	weights=new float64_t[degree*(1+max_mismatch)];
+	weights_degree=degree;
+	weights_length=(1+max_mismatch);
+
 	for (int32_t i=0; i<degree*(1+max_mismatch); i++)
-		weights[i]=weights_[i];
-	set_normalizer(new CFirstElementKernelNormalizer());
+		weights[i]=w[i];
 }
 
 CWeightedDegreeStringKernel::CWeightedDegreeStringKernel(
-	CStringFeatures<char>* l, CStringFeatures<char>* r, int32_t degree_)
-: CStringKernel<char>(10), weights(NULL), position_weights(NULL),
-	weights_buffer(NULL), mkl_stepsize(1), degree(degree_), length(0),
-	max_mismatch(0), seq_length(0), block_computation(true),
-	num_block_weights_external(0), block_weights_external(NULL),
-	block_weights(NULL), type(E_WD), which_degree(-1), tries(NULL),
-	tree_initialized(false), alphabet(NULL)
+	CStringFeatures<char>* l, CStringFeatures<char>* r, int32_t d)
+: CStringKernel<char>(10)
 {
-	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
-
+	init();
+	degree=d;
+	type=E_WD;
 	set_wd_weights_by_type(type);
 	set_normalizer(new CFirstElementKernelNormalizer());
 	init(l, r);
@@ -112,6 +100,8 @@ CWeightedDegreeStringKernel::~CWeightedDegreeStringKernel()
 
 	delete[] weights;
 	weights=NULL;
+	weights_degree=0;
+	weights_length=0;
 
 	delete[] block_weights;
 	block_weights=NULL;
@@ -586,6 +576,9 @@ bool CWeightedDegreeStringKernel::set_wd_weights_by_type(EWDKernType p_type)
 
 	delete[] weights;
 	weights=new float64_t[degree];
+	weights_degree=degree;
+	weights_length=1;
+
 	if (weights)
 	{
 		int32_t i;
@@ -635,25 +628,25 @@ bool CWeightedDegreeStringKernel::set_weights(
 	if (d!=degree || len<0)
 		SG_ERROR("WD: Dimension mismatch (should be (seq_length | 1) x degree) got (%d x %d)\n", len, degree);
 
+	degree=d;
 	length=len;
 
-	if (length==0)
-		length=1;
+	if (len <= 0)
+		len=1;
 
-	int32_t num_weights=degree*(length+max_mismatch);
+	weights_degree=degree;
+	weights_length=len+max_mismatch;
+
+
+	SG_DEBUG("Creating weights of size %dx%d\n", weights_degree, weights_length);
+	int32_t num_weights=weights_degree*weights_length;
 	delete[] weights;
 	weights=new float64_t[num_weights];
 
-	if (weights)
-	{
-		for (int32_t i=0; i<num_weights; i++) {
-			if (ws[i]) // len(ws) might be != num_weights?
-				weights[i]=ws[i];
-		}
-		return true;
-	}
-	else
-		return false;
+	for (int32_t i=0; i<degree*len; i++)
+		weights[i]=ws[i];
+
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::set_position_weights(
@@ -672,6 +665,7 @@ bool CWeightedDegreeStringKernel::set_position_weights(
 
 	delete[] position_weights;
 	position_weights=new float64_t[len];
+	position_weights_len=len;
 	ASSERT(tries);
 	tries->set_position_weights(position_weights);
 
@@ -690,19 +684,16 @@ bool CWeightedDegreeStringKernel::init_block_weights_from_wd()
 	delete[] block_weights;
 	block_weights=new float64_t[CMath::max(seq_length,degree)];
 
-	if (block_weights)
-	{
-		int32_t k;
-		float64_t d=degree; // use float to evade rounding errors below
+	int32_t k;
+	float64_t d=degree; // use float to evade rounding errors below
 
-		for (k=0; k<degree; k++)
-			block_weights[k]=
-				(-CMath::pow(k, 3)+(3*d-3)*CMath::pow(k, 2)+(9*d-2)*k+6*d)/(3*d*(d+1));
-		for (k=degree; k<seq_length; k++)
-			block_weights[k]=(-d+3*k+4)/3;
-	}
+	for (k=0; k<degree; k++)
+		block_weights[k]=
+			(-CMath::pow(k, 3)+(3*d-3)*CMath::pow(k, 2)+(9*d-2)*k+6*d)/(3*d*(d+1));
+	for (k=degree; k<seq_length; k++)
+		block_weights[k]=(-d+3*k+4)/3;
 
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_from_wd_external()
@@ -711,26 +702,22 @@ bool CWeightedDegreeStringKernel::init_block_weights_from_wd_external()
 	delete[] block_weights;
 	block_weights=new float64_t[CMath::max(seq_length,degree)];
 
-	if (block_weights)
+	int32_t i=0;
+	block_weights[0]=weights[0];
+	for (i=1; i<CMath::max(seq_length,degree); i++)
+		block_weights[i]=0;
+
+	for (i=1; i<CMath::max(seq_length,degree); i++)
 	{
-		int32_t i=0;
-		block_weights[0]=weights[0];
-		for (i=1; i<CMath::max(seq_length,degree); i++)
-			block_weights[i]=0;
+		block_weights[i]=block_weights[i-1];
 
-		for (i=1; i<CMath::max(seq_length,degree); i++)
-		{
-			block_weights[i]=block_weights[i-1];
+		float64_t contrib=0;
+		for (int32_t j=0; j<CMath::min(degree,i+1); j++)
+			contrib+=weights[j];
 
-			float64_t contrib=0;
-			for (int32_t j=0; j<CMath::min(degree,i+1); j++)
-				contrib+=weights[j];
-
-			block_weights[i]+=contrib;
-		}
+		block_weights[i]+=contrib;
 	}
-
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_const()
@@ -738,13 +725,9 @@ bool CWeightedDegreeStringKernel::init_block_weights_const()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<seq_length+1 ; i++)
-			block_weights[i-1]=1.0/seq_length;
-	}
-
-	return (block_weights!=NULL);
+	for (int32_t i=1; i<seq_length+1 ; i++)
+		block_weights[i-1]=1.0/seq_length;
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_linear()
@@ -752,13 +735,10 @@ bool CWeightedDegreeStringKernel::init_block_weights_linear()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<seq_length+1 ; i++)
-			block_weights[i-1]=degree*i;
-	}
+	for (int32_t i=1; i<seq_length+1 ; i++)
+		block_weights[i-1]=degree*i;
 
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_sqpoly()
@@ -766,16 +746,13 @@ bool CWeightedDegreeStringKernel::init_block_weights_sqpoly()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<degree+1 ; i++)
-			block_weights[i-1]=((float64_t) i)*i;
+	for (int32_t i=1; i<degree+1 ; i++)
+		block_weights[i-1]=((float64_t) i)*i;
 
-		for (int32_t i=degree+1; i<seq_length+1 ; i++)
-			block_weights[i-1]=i;
-	}
+	for (int32_t i=degree+1; i<seq_length+1 ; i++)
+		block_weights[i-1]=i;
 
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_cubicpoly()
@@ -783,16 +760,12 @@ bool CWeightedDegreeStringKernel::init_block_weights_cubicpoly()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<degree+1 ; i++)
-			block_weights[i-1]=((float64_t) i)*i*i;
+	for (int32_t i=1; i<degree+1 ; i++)
+		block_weights[i-1]=((float64_t) i)*i*i;
 
-		for (int32_t i=degree+1; i<seq_length+1 ; i++)
-			block_weights[i-1]=i;
-	}
-
-	return (block_weights!=NULL);
+	for (int32_t i=degree+1; i<seq_length+1 ; i++)
+		block_weights[i-1]=i;
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_exp()
@@ -800,16 +773,13 @@ bool CWeightedDegreeStringKernel::init_block_weights_exp()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<degree+1 ; i++)
-			block_weights[i-1]=exp(((float64_t) i/10.0));
+	for (int32_t i=1; i<degree+1 ; i++)
+		block_weights[i-1]=exp(((float64_t) i/10.0));
 
-		for (int32_t i=degree+1; i<seq_length+1 ; i++)
-			block_weights[i-1]=i;
-	}
+	for (int32_t i=degree+1; i<seq_length+1 ; i++)
+		block_weights[i-1]=i;
 
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights_log()
@@ -817,35 +787,13 @@ bool CWeightedDegreeStringKernel::init_block_weights_log()
 	delete[] block_weights;
 	block_weights=new float64_t[seq_length];
 
-	if (block_weights)
-	{
-		for (int32_t i=1; i<degree+1 ; i++)
-			block_weights[i-1]=CMath::pow(CMath::log((float64_t) i),2);
+	for (int32_t i=1; i<degree+1 ; i++)
+		block_weights[i-1]=CMath::pow(CMath::log((float64_t) i),2);
 
-		for (int32_t i=degree+1; i<seq_length+1 ; i++)
-			block_weights[i-1]=i-degree+1+CMath::pow(CMath::log(degree+1.0),2);
-	}
+	for (int32_t i=degree+1; i<seq_length+1 ; i++)
+		block_weights[i-1]=i-degree+1+CMath::pow(CMath::log(degree+1.0),2);
 
-	return (block_weights!=NULL);
-}
-
-bool CWeightedDegreeStringKernel::init_block_weights_external()
-{
-	if (block_weights_external && (seq_length == num_block_weights_external) )
-	{
-		delete[] block_weights;
-		block_weights=new float64_t[seq_length];
-
-		if (block_weights)
-		{
-			for (int32_t i=0; i<seq_length; i++)
-				block_weights[i]=block_weights_external[i];
-		}
-	}
-	else {
-      SG_ERROR( "sequence longer then weights (seqlen:%d, wlen:%d)\n", seq_length, block_weights_external);
-   }
-	return (block_weights!=NULL);
+	return true;
 }
 
 bool CWeightedDegreeStringKernel::init_block_weights()
@@ -868,11 +816,8 @@ bool CWeightedDegreeStringKernel::init_block_weights()
 			return init_block_weights_exp();
 		case E_BLOCK_LOG:
 			return init_block_weights_log();
-		case E_BLOCK_EXTERNAL:
-			return init_block_weights_external();
-		default:
-			return false;
 	};
+	return false;
 }
 
 
@@ -1018,9 +963,8 @@ void CWeightedDegreeStringKernel::compute_batch(
 
 bool CWeightedDegreeStringKernel::set_max_mismatch(int32_t max)
 {
-	if (type==E_EXTERNAL && max!=0) {
+	if (type==E_EXTERNAL && max!=0)
 		return false;
-	}
 
 	max_mismatch=max;
 
@@ -1029,3 +973,55 @@ bool CWeightedDegreeStringKernel::set_max_mismatch(int32_t max)
 	else
 		return true;
 }
+
+void CWeightedDegreeStringKernel::init()
+{
+	weights=NULL;
+	weights_degree=0;
+	weights_length=0;
+
+	position_weights=NULL;
+	position_weights_len=0;
+
+	weights_buffer=NULL;
+	mkl_stepsize=1;
+	degree=1;
+	length=0;
+
+	max_mismatch=0;
+	seq_length=0;
+
+	block_weights=NULL;
+	block_computation=true;
+	type=E_WD;
+	which_degree=-1;
+	tries=NULL;
+
+	tree_initialized=false;
+	alphabet=NULL;
+
+	lhs=NULL;
+	rhs=NULL;
+
+	properties |= KP_LINADD | KP_KERNCOMBINATION | KP_BATCHEVALUATION;
+
+	set_normalizer(new CFirstElementKernelNormalizer());
+
+	m_parameters->add_matrix(&weights, &weights_degree, &weights_length,
+			"weights", "WD Kernel weights.");
+	m_parameters->add_vector(&position_weights, &position_weights_len,
+			"position_weights",
+			"Weights per position.");
+	m_parameters->add(&mkl_stepsize, "mkl_stepsize", "MKL step size.");
+	m_parameters->add(&degree, "degree", "Order of WD kernel.");
+	m_parameters->add(&max_mismatch, "max_mismatch",
+			"Number of allowed mismatches.");
+	m_parameters->add(&block_computation, "block_computation",
+			"If block computation shall be used.");
+	m_parameters->add((machine_int_t*) &type, "type",
+			"WeightedDegree kernel type.");
+	m_parameters->add(&which_degree, "which_degree",
+			"Unqueal -1 if just a single degree is selected.");
+	m_parameters->add((CSGObject**) &alphabet, "alphabet",
+			"Alphabet of Features.");
+}
