@@ -18,11 +18,6 @@
 #include "kernel/MultitaskKernelMklNormalizer.h"
 #include "features/StringFeatures.h"
 
-
-
-
-
-
 namespace shogun
 {
 
@@ -37,7 +32,6 @@ enum EWDKernType
 	E_BLOCK_CUBICPOLY=5,
 	E_BLOCK_EXP=6,
 	E_BLOCK_LOG=7,
-	E_BLOCK_EXTERNAL=8
 };
 
 
@@ -59,6 +53,12 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 {
 	public:
 
+		/** default constructor
+		 *
+		 */
+		CWeightedDegreeStringKernel();
+
+
 		/** constructor
 		 *
 		 * @param degree degree
@@ -136,7 +136,9 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 		 *
 		 * @return name WeightedDegree
 		 */
-		virtual const char* get_name() const { return "WeightedDegree"; }
+		virtual const char* get_name() const {
+			return "WeightedDegreeStringKernel";
+		}
 
 		/** initialize optimization
 		 *
@@ -471,11 +473,11 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 
 		/** set position weights
 		 *
-		 * @param position_weights new position weights
+		 * @param pws new position weights
 		 * @param len number of position weights
 		 * @return if setting was successful
 		 */
-		bool set_position_weights(float64_t* position_weights, int32_t len=0);
+		bool set_position_weights(float64_t* pws, int32_t len=0);
 
 		/** initialize block weights
 		 *
@@ -531,12 +533,6 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 		 */
 		bool init_block_weights_log();
 
-		/** initialize block weights external
-		 *
-		 * @return if initialization was successful
-		 */
-		bool init_block_weights_external();
-
 		/** delete position weights
 		 *
 		 * @return if deleting was successful
@@ -727,167 +723,26 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 		/** remove lhs from kernel */
 		virtual void remove_lhs();
 
-
-#ifdef HAVE_BOOST_SERIALIZATION
-
-
-
-
-    private:
-
-        // serialization needs to split up in save/load because
-        // the serialization of pointers to natives (int* & friends)
-        // requires a workaround
-        friend class ::boost::serialization::access;
-
-        //  friend std::ostream & operator<<(std::ostream &os, const CWeightedDegreeStringKernel &gp);
-        //template<class Archive>
-        //friend void ::boost::serialization::save_construct_data(Archive & ar, const CWeightedDegreeStringKernel* t, const unsigned int file_version);
-        template<class Archive>
-            void save(Archive & ar, const unsigned int archive_version) const
-            {
-
-                SG_DEBUG("archiving CWeightedDegreeStringKernel\n");
-
-                ar & ::boost::serialization::base_object<CStringKernel<char> >(*this);
-
-
-                ///degree*length weights
-                ///length must match seq_length if != 0
-                ar & mkl_stepsize ;
-                //ar & degree;
-                ar & length;
-                ar & max_mismatch ;
-
-                //for (int32_t i=0; i<degree*(1+max_mismatch); i++)
-                //    ar & weights[i];
-
-                //TODO how long?
-                //float64_t* position_weights ;
-                //float64_t* weights_buffer ;
-
-                ar & seq_length ;
-
-                ar & initialized ;
-                ar & block_computation;
-                //ar & use_normalization ;
-
-                //ar & normalization_const;
-
-                ar & num_block_weights_external;
-                for (int32_t i=0; i < num_block_weights_external; ++i)
-                {
-                    ar & block_weights_external[i];
-                }
-
-                //TODO how long
-                //float64_t* block_weights;
-                //ar & type;
-                ar & which_degree;
-
-                //TODO implement
-                //CTrie<DNATrie> tries ;
-                //ar & tree_initialized ;
-
-
-                //CWeightedDegreeStringKernel* tmp = const_cast<CWeightedDegreeStringKernel*>(this);
-                //tmp->create_empty_tries();
-                //create_empty_tries();
-
-                SG_DEBUG("done with CWeightedDegreeStringKernel\n");
-
-            }
-
-        template<class Archive>
-            void load(Archive & ar, const unsigned int archive_version)
-            {
-                SG_DEBUG("archiving CWeightedDegreeStringKernel\n");
-
-                ar & ::boost::serialization::base_object<CStringKernel<char> >(*this);
-
-
-                ///degree*length weights
-                ///length must match seq_length if != 0
-                ar & mkl_stepsize ;
-                ar & degree;
-                ar & length;
-                ar & max_mismatch ;
-
-                //weights=new float64_t[degree*(1+max_mismatch)];
-                //for (int32_t i=0; i<degree*(1+max_mismatch); i++)
-                //    ar & weights[i];
-
-
-                //TODO how long?
-                //float64_t* position_weights ;
-                //float64_t* weights_buffer ;
-
-                ar & seq_length ;
-
-                ar & initialized ;
-                ar & block_computation;
-                //ar & use_normalization ;
-
-                //ar & normalization_const;
-
-                ar & num_block_weights_external;
-                //float64_t* block_weights_external;
-                block_weights_external = new float64_t[num_block_weights_external];
-                for (int32_t i=0; i < num_block_weights_external; ++i)
-                {
-                    ar & block_weights_external[i];
-                }
-
-                //TODO how long
-                //float64_t* block_weights;
-                //ar & type;
-                ar & which_degree;
-
-                //TODO implement
-                //CTrie<DNATrie> tries ;
-                //ar & tree_initialized ;
-
-                SG_DEBUG("done with CWeightedDegreeStringKernel\n");
-
-            }
-
-        GLOBAL_BOOST_SERIALIZATION_SPLIT_MEMBER();
-
-
-    public:
-
-        virtual std::string toString() const
-        {
-            std::ostringstream s;
-
-            ::boost::archive::text_oarchive oa(s);
-
-            oa << *this;
-
-            return s.str();
-        }
-
-        virtual void fromString(std::string str)
-        {
-
-            std::istringstream is(str);
-
-            ::boost::archive::text_iarchive ia(is);
-
-            ia >> *this;
-
-        }
-
-#endif //HAVE_BOOST_SERIALIZATION
-
+	private:
+		/** Do basic initialisations like default settings
+		 * and registering parameters */
+		void init();
 
 	protected:
 		/** degree*length weights
 		 *length must match seq_length if != 0
 		 */
 		float64_t* weights;
+		/** degree */
+		int32_t weights_degree;
+		/** length */
+		int32_t weights_length;
+
+
 		/** position weights */
 		float64_t* position_weights;
+		/** position weights */
+		int32_t position_weights_len;
 		/** weights buffer */
 		float64_t* weights_buffer;
 		/** MKL step size */
@@ -908,11 +763,6 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 		/** if block computation is used */
 		bool block_computation;
 
-		/** number of external block weights */
-		int32_t num_block_weights_external;
-		/** external block weights */
-		float64_t* block_weights_external;
-
 		/** (internal) block weights */
 		float64_t* block_weights;
 		/** WeightedDegree kernel type */
@@ -932,106 +782,4 @@ class CWeightedDegreeStringKernel: public CStringKernel<char>
 
 }
 
-
-
-#ifdef HAVE_BOOST_SERIALIZATION
-#include <boost/serialization/export.hpp>
-
-#endif //HAVE_BOOST_SERIALIZATION
-
-
-#ifdef HAVE_BOOST_SERIALIZATION
-
-namespace boost
-{
-	namespace serialization
-	{
-		template<class Archive>
-			//inline void save_construct_data(Archive & ar, const shogun::CWeightedDegreeStringKernel* const t, const unsigned int file_version)
-			inline void save_construct_data(Archive & ar, shogun::CWeightedDegreeStringKernel* t, const unsigned int file_version)
-			{
-
-				std::cout << "saving WDK from non-defaultconstruct data works" << std::endl;
-
-				//CWeightedDegreeStringKernel(INT size, EWDKernType type, INT degree, INT max_mismatch, bool use_normalization=true, bool block_computation=false, INT mkl_stepsize=1, INT which_deg=-1);
-
-				//ar << t->cache_size;
-
-				ar << t->type;
-
-				ar << t->degree;
-
-				//ar << t->max_mismatch;
-				/*
-
-				ar.register_type(static_cast<shogun::CStringFeatures<char> *>(NULL));
-
-
-				const shogun::CStringFeatures<char>* const lhs = dynamic_cast<shogun::CStringFeatures<char>* >(const_cast<shogun::CWeightedDegreeStringKernel*>(t)->get_lhs());
-
-				const shogun::CStringFeatures<char>* const rhs = dynamic_cast<shogun::CStringFeatures<char>* >(const_cast<shogun::CWeightedDegreeStringKernel*>(t)->get_rhs());
-
-				//CStringFeatures<char>* lhs = (CStringFeatures<char>*) (const_cast<CWeightedDegreeStringKernel*>(t)->get_lhs());
-				//CStringFeatures<char>* rhs = (CStringFeatures<char>*) (const_cast<CWeightedDegreeStringKernel*>(t)->get_rhs());
-
-				//    const CFeatures* const lhs = t->get_lhs();
-				//    const CFeatures* const rhs = t->get_rhs();
-
-				ar << lhs;
-				ar << rhs;
-
-				//ar << dynamic_cast<CStringFeatures<char>*>(rhs);
-				//ar << t->get_lhs();
-				//ar << t->get_rhs();
-				*/
-				std::cout << "done saving WDK from non-defaultconstruct data" << std::endl;
-
-			}
-
-		template<class Archive>
-			inline void load_construct_data(Archive & ar, shogun::CWeightedDegreeStringKernel * t, const unsigned int file_version)
-			{
-
-				std::cout << "loading WDK from non-defaultconstruct data" << std::endl;
-
-
-
-				shogun::EWDKernType type;
-				int32_t degree;
-
-				ar >> type;
-				ar >> degree;
-				/*
-				int32_t size;
-				int32_t max_mismatch;
-
-				ar >> size;
-				ar >> type;
-				ar >> degree;
-				ar >> max_mismatch;
-
-				//      ::new(t)CWeightedDegreeStringKernel(size, type, degree, max_mismatch);
-
-				shogun::CStringFeatures<char>* lhs;
-				shogun::CStringFeatures<char>* rhs;
-
-
-				ar >> lhs;
-				ar >> rhs;
-
-				::new(t)shogun::CWeightedDegreeStringKernel(lhs, rhs, degree);
-				*/
-
-				::new(t)shogun::CWeightedDegreeStringKernel(degree, type);
-				//t->set_max_mismatch(max_mismatch);
-
-				std::cout << "done loading WDK from non-defaultconstruct data" << std::endl;
-			}
-	} // serialization
-} // namespace boost
-#endif //HAVE_BOOST_SERIALIZATION
-
-//BOOST_CLASS_EXPORT_KEY2(shogun::CWeightedDegreeStringKernel, "CWeightedDegreeStringKernel");
-
-
 #endif /* _WEIGHTEDDEGREESTRINGKERNEL_H__ */
