@@ -12,9 +12,15 @@
 #include "lib/File.h"
 #include "lib/AsciiFile.h"
 #include "lib/Mathematics.h"
+#include <ctype.h>
 
 using namespace shogun;
 
+CAsciiFile::CAsciiFile(void)
+{
+	SG_UNSTABLE("CAsciiFile::CAsciiFile(void)", "\n");
+}
+
 CAsciiFile::CAsciiFile(FILE* f, const char* name) : CFile(f, name)
 {
 }
@@ -84,7 +90,7 @@ void CAsciiFile::fname(sg_type*& matrix, int32_t& num_feat, int32_t& num_vec)	\
 	num_vec=0;																	\
 	char* ptr_item=NULL;														\
 	char* ptr_data=data;														\
-	CDynamicArray<char*>* items=new CDynamicArray<char*>();						\
+	DynArray<char*>* items=new DynArray<char*>();						\
 																				\
 	while (*ptr_data)															\
 	{																			\
@@ -135,6 +141,7 @@ void CAsciiFile::fname(sg_type*& matrix, int32_t& num_feat, int32_t& num_vec)	\
 }
 
 GET_MATRIX(get_byte_matrix, atoi, uint8_t)
+GET_MATRIX(get_int8_matrix, atoi, int8_t)
 GET_MATRIX(get_char_matrix, atoi, char)
 GET_MATRIX(get_int_matrix, atoi, int32_t)
 GET_MATRIX(get_uint_matrix, atoi, uint32_t)
@@ -340,6 +347,7 @@ void CAsciiFile::fname(TSparse<sg_type>*& matrix, int32_t& num_feat, int32_t& nu
 
 GET_SPARSEMATRIX(get_bool_sparsematrix, atoi, bool)
 GET_SPARSEMATRIX(get_byte_sparsematrix, atoi, uint8_t)
+GET_SPARSEMATRIX(get_int8_sparsematrix, atoi, int8_t)
 GET_SPARSEMATRIX(get_char_sparsematrix, atoi, char)
 GET_SPARSEMATRIX(get_int_sparsematrix, atoi, int32_t)
 GET_SPARSEMATRIX(get_uint_sparsematrix, atoi, uint32_t)
@@ -353,7 +361,7 @@ GET_SPARSEMATRIX(get_word_sparsematrix, atoi, uint16_t)
 #undef GET_SPARSEMATRIX
 
 
-void CAsciiFile::get_byte_string_list(T_STRING<uint8_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_byte_string_list(TString<uint8_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	size_t blocksize=1024*1024;
 	size_t required_blocksize=0;
@@ -398,7 +406,7 @@ void CAsciiFile::get_byte_string_list(T_STRING<uint8_t>*& strings, int32_t& num_
 		blocksize=required_blocksize;
 		dummy=new uint8_t[blocksize];
 		overflow=new uint8_t[blocksize];
-		strings=new T_STRING<uint8_t>[num_str];
+		strings=new TString<uint8_t>[num_str];
 
 		rewind(file);
 		sz=blocksize;
@@ -448,7 +456,102 @@ void CAsciiFile::get_byte_string_list(T_STRING<uint8_t>*& strings, int32_t& num_
 	delete[] overflow;
 }
 
-void CAsciiFile::get_char_string_list(T_STRING<char>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_int8_string_list(TString<int8_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+{
+	size_t blocksize=1024*1024;
+	size_t required_blocksize=0;
+	int8_t* dummy=new int8_t[blocksize];
+	int8_t* overflow=NULL;
+	int32_t overflow_len=0;
+
+	if (file)
+	{
+		num_str=0;
+		max_string_len=0;
+
+		SG_INFO("counting line numbers in file %s\n", filename);
+		size_t sz=blocksize;
+		size_t block_offs=0;
+		size_t old_block_offs=0;
+		fseek(file, 0, SEEK_END);
+		size_t fsize=ftell(file);
+		rewind(file);
+
+		while (sz == blocksize)
+		{
+			sz=fread(dummy, sizeof(int8_t), blocksize, file);
+			bool contains_cr=false;
+			for (size_t i=0; i<sz; i++)
+			{
+				block_offs++;
+				if (dummy[i]=='\n' || (i==sz-1 && sz<blocksize))
+				{
+					num_str++;
+					contains_cr=true;
+					required_blocksize=CMath::max(required_blocksize, block_offs-old_block_offs);
+					old_block_offs=block_offs;
+				}
+			}
+			SG_PROGRESS(block_offs, 0, fsize, 1, "COUNTING:\t");
+		}
+
+		SG_INFO("found %d strings\n", num_str);
+		SG_DEBUG("block_size=%d\n", required_blocksize);
+		delete[] dummy;
+		blocksize=required_blocksize;
+		dummy=new int8_t[blocksize];
+		overflow=new int8_t[blocksize];
+		strings=new TString<int8_t>[num_str];
+
+		rewind(file);
+		sz=blocksize;
+		int32_t lines=0;
+		size_t old_sz=0;
+		while (sz == blocksize)
+		{
+			sz=fread(dummy, sizeof(int8_t), blocksize, file);
+
+			old_sz=0;
+			for (size_t i=0; i<sz; i++)
+			{
+				if (dummy[i]=='\n' || (i==sz-1 && sz<blocksize))
+				{
+					int32_t len=i-old_sz;
+					max_string_len=CMath::max(max_string_len, len+overflow_len);
+
+					strings[lines].length=len+overflow_len;
+					strings[lines].string=new int8_t[len+overflow_len];
+
+					for (int32_t j=0; j<overflow_len; j++)
+						strings[lines].string[j]=overflow[j];
+					for (int32_t j=0; j<len; j++)
+						strings[lines].string[j+overflow_len]=dummy[old_sz+j];
+
+					// clear overflow
+					overflow_len=0;
+
+					//CMath::display_vector(strings[lines].string, len);
+					old_sz=i+1;
+					lines++;
+					SG_PROGRESS(lines, 0, num_str, 1, "LOADING:\t");
+				}
+			}
+
+			for (size_t i=old_sz; i<sz; i++)
+				overflow[i-old_sz]=dummy[i];
+
+			overflow_len=sz-old_sz;
+		}
+		SG_INFO("file successfully read\n");
+		SG_INFO("max_string_length=%d\n", max_string_len);
+		SG_INFO("num_strings=%d\n", num_str);
+	}
+
+	delete[] dummy;
+	delete[] overflow;
+}
+
+void CAsciiFile::get_char_string_list(TString<char>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	size_t blocksize=1024*1024;
 	size_t required_blocksize=0;
@@ -493,7 +596,7 @@ void CAsciiFile::get_char_string_list(T_STRING<char>*& strings, int32_t& num_str
 		blocksize=required_blocksize;
 		dummy=new char[blocksize];
 		overflow=new char[blocksize];
-		strings=new T_STRING<char>[num_str];
+		strings=new TString<char>[num_str];
 
 		rewind(file);
 		sz=blocksize;
@@ -543,63 +646,63 @@ void CAsciiFile::get_char_string_list(T_STRING<char>*& strings, int32_t& num_str
 	delete[] overflow;
 }
 
-void CAsciiFile::get_int_string_list(T_STRING<int32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_int_string_list(TString<int32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_uint_string_list(T_STRING<uint32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_uint_string_list(TString<uint32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_short_string_list(T_STRING<int16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_short_string_list(TString<int16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_word_string_list(T_STRING<uint16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_word_string_list(TString<uint16_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_long_string_list(T_STRING<int64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_long_string_list(TString<int64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_ulong_string_list(T_STRING<uint64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_ulong_string_list(TString<uint64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_shortreal_string_list(T_STRING<float32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_shortreal_string_list(TString<float32_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_real_string_list(T_STRING<float64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_real_string_list(TString<float64_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
 	max_string_len=0;
 }
 
-void CAsciiFile::get_longreal_string_list(T_STRING<floatmax_t>*& strings, int32_t& num_str, int32_t& max_string_len)
+void CAsciiFile::get_longreal_string_list(TString<floatmax_t>*& strings, int32_t& num_str, int32_t& max_string_len)
 {
 	strings=NULL;
 	num_str=0;
@@ -643,6 +746,7 @@ void CAsciiFile::fname(const sg_type* matrix, int32_t num_feat, int32_t num_vec)
 }
 SET_MATRIX(set_char_matrix, char, char, "%c")
 SET_MATRIX(set_byte_matrix, uint8_t, uint8_t, "%u")
+SET_MATRIX(set_int8_matrix, int8_t, int8_t, "%d")
 SET_MATRIX(set_int_matrix, int32_t, int32_t, "%i")
 SET_MATRIX(set_uint_matrix, uint32_t, uint32_t, "%u")
 SET_MATRIX(set_long_matrix, int64_t, long long int, "%lli")
@@ -683,6 +787,7 @@ void CAsciiFile::fname(const TSparse<sg_type>* matrix, int32_t num_feat, int32_t
 SET_SPARSEMATRIX(set_bool_sparsematrix, bool, uint8_t, "%u")
 SET_SPARSEMATRIX(set_char_sparsematrix, char, char, "%c")
 SET_SPARSEMATRIX(set_byte_sparsematrix, uint8_t, uint8_t, "%u")
+SET_SPARSEMATRIX(set_int8_sparsematrix, int8_t, int8_t, "%d")
 SET_SPARSEMATRIX(set_int_sparsematrix, int32_t, int32_t, "%i")
 SET_SPARSEMATRIX(set_uint_sparsematrix, uint32_t, uint32_t, "%u")
 SET_SPARSEMATRIX(set_long_sparsematrix, int64_t, long long int, "%lli")
@@ -694,7 +799,7 @@ SET_SPARSEMATRIX(set_real_sparsematrix, float64_t, float64_t, "%f")
 SET_SPARSEMATRIX(set_longreal_sparsematrix, floatmax_t, floatmax_t, "%Lf")
 #undef SET_SPARSEMATRIX
 
-void CAsciiFile::set_byte_string_list(const T_STRING<uint8_t>* strings, int32_t num_str)
+void CAsciiFile::set_byte_string_list(const TString<uint8_t>* strings, int32_t num_str)
 {
 	if (!(file && strings))
 		SG_ERROR("File or strings invalid.\n");
@@ -707,7 +812,20 @@ void CAsciiFile::set_byte_string_list(const T_STRING<uint8_t>* strings, int32_t
 	}
 }
 
-void CAsciiFile::set_char_string_list(const T_STRING<char>* strings, int32_t num_str)
+void CAsciiFile::set_int8_string_list(const TString<int8_t>* strings, int32_t num_str)
+{
+	if (!(file && strings))
+		SG_ERROR("File or strings invalid.\n");
+
+	for (int32_t i=0; i<num_str; i++)
+	{
+		int32_t len = strings[i].length;
+		fwrite(strings[i].string, sizeof(int8_t), len, file);
+		fprintf(file, "\n");
+	}
+}
+
+void CAsciiFile::set_char_string_list(const TString<char>* strings, int32_t num_str)
 {
 	if (!(file && strings))
 		SG_ERROR("File or strings invalid.\n");
@@ -720,44 +838,44 @@ void CAsciiFile::set_char_string_list(const T_STRING<char>* strings, int32_t num
 	}
 }
 
-void CAsciiFile::set_int_string_list(const T_STRING<int32_t>* strings, int32_t num_str)
+void CAsciiFile::set_int_string_list(const TString<int32_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_uint_string_list(const T_STRING<uint32_t>* strings, int32_t num_str)
+void CAsciiFile::set_uint_string_list(const TString<uint32_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_short_string_list(const T_STRING<int16_t>* strings, int32_t num_str)
+void CAsciiFile::set_short_string_list(const TString<int16_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_word_string_list(const T_STRING<uint16_t>* strings, int32_t num_str)
+void CAsciiFile::set_word_string_list(const TString<uint16_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_long_string_list(const T_STRING<int64_t>* strings, int32_t num_str)
+void CAsciiFile::set_long_string_list(const TString<int64_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_ulong_string_list(const T_STRING<uint64_t>* strings, int32_t num_str)
+void CAsciiFile::set_ulong_string_list(const TString<uint64_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_shortreal_string_list(const T_STRING<float32_t>* strings, int32_t num_str)
+void CAsciiFile::set_shortreal_string_list(const TString<float32_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_real_string_list(const T_STRING<float64_t>* strings, int32_t num_str)
+void CAsciiFile::set_real_string_list(const TString<float64_t>* strings, int32_t num_str)
 {
 }
 
-void CAsciiFile::set_longreal_string_list(const T_STRING<floatmax_t>* strings, int32_t num_str)
+void CAsciiFile::set_longreal_string_list(const TString<floatmax_t>* strings, int32_t num_str)
 {
 }
 
 template <class T> void CAsciiFile::append_item(
-	CDynamicArray<T>* items, char* ptr_data, char* ptr_item)
+	DynArray<T>* items, char* ptr_data, char* ptr_item)
 {
 	size_t len=(ptr_data-ptr_item)/sizeof(char);
 	char* item=new char[len+1];
