@@ -14,36 +14,60 @@
 
 #include "lib/common.h"
 #include "base/SGObject.h"
+#include "base/Parameter.h"
 
 namespace shogun
 {
 /** @brief Class ListElement, defines how an element of the the list looks like */
-template <class T> class CListElement
+class CListElement :public CSGObject
 {
 	public:
-		/** next element in list */
-		CListElement* next;
-		/** previous element in list */
-		CListElement* prev;
-		/** data of this element */
-		T data;
+		/** default constructor */
+		CListElement()
+			: next(NULL), prev(NULL), data(NULL)
+		{
+			init();
+		}
 
-	public:
 		/** constructor
 		 *
 		 * @param p_data data of this element
 		 * @param p_prev previous element
 		 * @param p_next next element
 		 */
-		CListElement(T p_data, CListElement* p_prev = NULL, CListElement* p_next = NULL)
+		CListElement(CSGObject* p_data,
+				CListElement* p_prev = NULL,
+				CListElement* p_next = NULL)
 		{
+			init();
+
 			this->data = p_data;
 			this->next = p_next;
 			this->prev = p_prev;
-		};
+		}
 
 		/// destructor
 		virtual ~CListElement() { data = NULL; }
+
+		/** @return object name */
+		inline virtual const char* get_name(void) const { return "ListElement"; }
+
+	private:
+		void init()
+		{
+			m_parameters->add(&data, "data", "Data of this element.");
+			m_parameters->add((CSGObject**) &next, "next",
+					"Next element in list.");
+		}
+
+	public:
+		/** next element in list */
+		CListElement* next;
+		/** previous element in list */
+		CListElement* prev;
+		/** data of this element */
+		CSGObject* data;
+
 };
 
 /** @brief Class List implements a doubly connected list for low-level-objects.
@@ -51,7 +75,7 @@ template <class T> class CListElement
  * For higher level objects pointers should be used. The list supports calling
  * delete() of an object that is to be removed from the list.
  */
-template <class T> class CList : public CSGObject
+class CList : public CSGObject
 {
 	public:
 		/** constructor
@@ -60,6 +84,13 @@ template <class T> class CList : public CSGObject
 		 */
 		CList(bool p_delete_data=false) : CSGObject()
 		{
+			m_parameters->add(&delete_data, "delete_data",
+							  "Delete data on destruction?");
+			m_parameters->add(&num_elements, "num_elements",
+							  "Number of elements.");
+			m_parameters->add((CSGObject**) &first, "first",
+							  "First element in list.");
+
 			first  = NULL;
 			current = NULL;
 			last   = NULL;
@@ -74,7 +105,7 @@ template <class T> class CList : public CSGObject
 
 			while (get_num_elements())
 			{
-				T d=delete_element();
+				CSGObject* d=delete_element();
 
 				if (delete_data)
 				{
@@ -94,7 +125,7 @@ template <class T> class CList : public CSGObject
 		 *
 		 * @return first element in list or NULL if list is empty
 		 */
-		inline T get_first_element()
+		inline CSGObject* get_first_element()
 		{
 			if (first != NULL)
 			{
@@ -111,7 +142,7 @@ template <class T> class CList : public CSGObject
 		 *
 		 * @return last element in list or NULL if list is empty
 		 */
-		inline T get_last_element()
+		inline CSGObject* get_last_element()
 		{
 			if (last != NULL)
 			{
@@ -128,7 +159,7 @@ template <class T> class CList : public CSGObject
 		 *
 		 * @return next element in list or NULL if list is empty
 		 */
-		inline T get_next_element()
+		inline CSGObject* get_next_element()
 		{
 			if ((current != NULL) && (current->next != NULL))
 			{
@@ -145,7 +176,7 @@ template <class T> class CList : public CSGObject
 		 *
 		 * @return previous element in list or NULL if list is empty
 		 */
-		inline T get_previous_element()
+		inline CSGObject* get_previous_element()
 		{
 			if ((current != NULL) && (current->prev != NULL))
 			{
@@ -162,7 +193,7 @@ template <class T> class CList : public CSGObject
 		 *
 		 * @return current element in list or NULL if not available
 		 */
-		inline T get_current_element()
+		inline CSGObject* get_current_element()
 		{
 			if (current != NULL)
 			{
@@ -183,7 +214,7 @@ template <class T> class CList : public CSGObject
 		 * @param p_current current list element
 		 * @return first element in list or NULL if list is empty
 		 */
-		inline T get_first_element(CListElement<T> *&p_current)
+		inline CSGObject* get_first_element(CListElement*& p_current)
 		{
 			if (first != NULL)
 			{
@@ -201,7 +232,7 @@ template <class T> class CList : public CSGObject
 		 * @param p_current current list element
 		 * @return last element in list or NULL if list is empty
 		 */
-		inline T get_last_element(CListElement<T> *&p_current)
+		inline CSGObject* get_last_element(CListElement*& p_current)
 		{
 			if (last != NULL)
 			{
@@ -219,7 +250,7 @@ template <class T> class CList : public CSGObject
 		 * @param p_current current list element
 		 * @return next element in list or NULL if list is empty
 		 */
-		inline T get_next_element(CListElement<T> *& p_current)
+		inline CSGObject* get_next_element(CListElement*& p_current)
 		{
 			if ((p_current != NULL) && (p_current->next != NULL))
 			{
@@ -237,7 +268,7 @@ template <class T> class CList : public CSGObject
 		 * @param p_current current list element
 		 * @return previous element in list or NULL if list is empty
 		 */
-		inline T get_previous_element(CListElement<T> *& p_current)
+		inline CSGObject* get_previous_element(CListElement*& p_current)
 		{
 			if ((p_current != NULL) && (p_current->prev != NULL))
 			{
@@ -255,7 +286,7 @@ template <class T> class CList : public CSGObject
 		 * @param p_current current list element
 		 * @return current element in list or NULL if not available
 		 */
-		inline T get_current_element(CListElement<T> *& p_current)
+		inline CSGObject* get_current_element(CListElement*& p_current)
 		{
 			if (p_current != NULL)
 			{
@@ -273,11 +304,11 @@ template <class T> class CList : public CSGObject
 		 * @param data data element to append
 		 * @return if appending was successful
 		 */
-		inline bool append_element(T data)
+		inline bool append_element(CSGObject* data)
 		{
 			if (current != NULL)    // none available, case is shattered in insert_element()
 			{
-				T e=get_next_element();
+				CSGObject* e=get_next_element();
 				if (e)
 				{
 					if (delete_data)
@@ -288,9 +319,9 @@ template <class T> class CList : public CSGObject
 				else
 				{
 					// case with no successor but nonempty
-					CListElement<T>* element;
+					CListElement* element;
 
-					if ((element = new CListElement<T>(data, current)) != NULL)
+					if ((element = new CListElement(data, current)) != NULL)
 					{
 						current->next = element;
 						current       = element;
@@ -316,9 +347,9 @@ template <class T> class CList : public CSGObject
 		 * @param data data element to append
 		 * @return if appending was successful
 		 */
-		inline bool append_element_at_listend(T data)
+		inline bool append_element_at_listend(CSGObject* data)
 		{
-			T p = get_last_element();
+			CSGObject* p = get_last_element();
 			if (delete_data)
 				SG_UNREF(p);
 
@@ -330,16 +361,16 @@ template <class T> class CList : public CSGObject
 		 * @param data data element to insert
 		 * @return if inserting was successful
 		 */
-		inline bool insert_element(T data)
+		inline bool insert_element(CSGObject* data)
 		{
-			CListElement<T>* element;
+			CListElement* element;
 
 			if (delete_data)
 				SG_REF(data);
 
 			if (current == NULL)
 			{
-				if ((element = new CListElement<T> (data)) != NULL)
+				if ((element = new CListElement(data)) != NULL)
 				{
 					current = element;
 					first  = element;
@@ -354,7 +385,7 @@ template <class T> class CList : public CSGObject
 			}
 			else
 			{
-				if ((element = new CListElement<T>(data, current->prev, current)) != NULL)
+				if ((element = new CListElement(data, current->prev, current)) != NULL)
 				{
 					if (current->prev != NULL)
 						current->prev->next = element;
@@ -377,18 +408,21 @@ template <class T> class CList : public CSGObject
 		 * the new current element is the successor of the former
 		 * current element
 		 *
-		 * @return the elements data - if available - is returned else NULL
+		 * @return the elements data - if available - otherwise NULL
 		 */
-		inline T delete_element(void)
+		inline CSGObject* delete_element(void)
 		{
-			T data = get_current_element();
+			CSGObject* data = get_current_element();
+
+			if (num_elements>0)
+				num_elements--;
 
 			if (data)
 			{
 				if (delete_data)
 					SG_UNREF(data);
 
-				CListElement<T> *element = current;
+				CListElement *element = current;
 
 				if (element->prev)
 					element->prev->next = element->next;
@@ -409,26 +443,38 @@ template <class T> class CList : public CSGObject
 
 				delete element;
 
-				num_elements--;
-
 				return data;
 			} 
 
 			return NULL;
 		}
 
+		virtual void load_serializable_post() throw (ShogunException)
+		{
+			CSGObject::load_serializable_post();
+
+			current = first;
+			CListElement* prev = NULL;
+			for (CListElement* cur=first; cur!=NULL; cur=cur->next)
+			{
+				cur->prev = prev;
+				prev = cur;
+			}
+			last = prev;
+		}
+
 		/** @return object name */
-		inline virtual const char* get_name() const { return "List"; }
+		inline virtual const char* get_name(void) const { return "List"; }
 
 	private:
 		/** if data is to be deleted on object destruction */
 		bool delete_data;
 		/** first element in list */
-		CListElement<T>* first;
+		CListElement* first;
 		/** current element in list */
-		CListElement<T>* current;
+		CListElement* current;
 		/** last element in list */
-		CListElement<T>* last;
+		CListElement* last;
 		/** number of elements */
 		int32_t num_elements;
 };
