@@ -665,6 +665,17 @@ class CMath : public CSGObject
 			return r;
 		}
 
+		/// compute dot product between v1 and v2 (for 8bit (un)signed ints)
+		static inline float64_t dot(
+			const int8_t* v1, const int8_t* v2, int32_t n)
+		{
+			float64_t r=0;
+			for (int32_t i=0; i<n; i++)
+				r+=((float64_t) v1[i])*v2[i];
+
+			return r;
+		}
+
 		/// compute dot product between v1 and v2
 		static inline float64_t dot(
 			const float64_t* v1, const char* v2, int32_t n)
@@ -912,6 +923,9 @@ class CMath : public CSGObject
 		template <class T>
 			static void qsort(T* output, int32_t size)
 			{
+				if (size==1)
+					return;
+
 				if (size==2)
 				{
 					if (output[0] > output [1])
@@ -1381,6 +1395,9 @@ void* CMath::parallel_qsort_index(void* p)
 	template <class T1,class T2>
 void CMath::qsort_index(T1* output, T2* index, uint32_t size)
 {
+	if (size==1)
+		return;
+
 	if (size==2)
 	{
 		if (output[0] > output [1])
