@@ -15,7 +15,7 @@
 #include <string.h>
 #include "lib/common.h"
 #include "lib/io.h"
-#include "lib/DynamicArray.h"
+#include "base/DynArray.h"
 #include "lib/Mathematics.h"
 #include "base/SGObject.h"
 
@@ -152,9 +152,13 @@ template <class Trie> class CTrie;
  * may save a lot of memory on higher degree tries.
  *
  */
-template <class Trie> class CTrie : public CSGObject
+#define IGNORE_IN_CLASSLIST
+IGNORE_IN_CLASSLIST template <class Trie> class CTrie : public CSGObject
 {
 	public:
+		/** default constructor  */
+		CTrie();
+
 		/** constructor
 		 *
 		 * @param d degree
@@ -393,7 +397,7 @@ template <class Trie> class CTrie : public CSGObject
 		 */
 		void fill_backtracking_table_recursion(
 			Trie* tree, int32_t depth, uint64_t seq, float64_t value,
-			CDynamicArray<ConsensusEntry>* table, float64_t* weights);
+			DynArray<ConsensusEntry>* table, float64_t* weights);
 
 		/** fill backtracking table
 		 *
@@ -404,8 +408,8 @@ template <class Trie> class CTrie : public CSGObject
 		 * @param weights weights
 		 */
 		void fill_backtracking_table(
-			int32_t pos, CDynamicArray<ConsensusEntry>* prev,
-			CDynamicArray<ConsensusEntry>* cur, bool cumulative,
+			int32_t pos, DynArray<ConsensusEntry>* prev,
+			DynArray<ConsensusEntry>* cur, bool cumulative,
 			float64_t* weights);
 
 		/** POIMs extract W
@@ -655,6 +659,22 @@ template <class Trie> class CTrie : public CSGObject
 		/** nofsKmers */
 		int32_t* nofsKmers;
 };
+	template <class Trie>
+	CTrie<Trie>::CTrie()
+	: CSGObject(), degree(0), position_weights(NULL),
+		use_compact_terminal_nodes(false),
+		weights_in_tree(true)
+	{
+
+		TreeMemPtrMax=0;
+		TreeMemPtr=0;
+		TreeMem=NULL;
+
+		length=0;
+		trees=NULL;
+
+		NUM_SYMS=4;
+	}
 
 	template <class Trie>
 	CTrie<Trie>::CTrie(int32_t d, bool p_use_compact_terminal_nodes)
@@ -1993,7 +2013,7 @@ void CTrie<Trie>::compute_by_tree_helper(
 	template <class Trie>
 void CTrie<Trie>::fill_backtracking_table_recursion(
 	Trie* tree, int32_t depth, uint64_t seq, float64_t value,
-	CDynamicArray<ConsensusEntry>* table, float64_t* weights)
+	DynArray<ConsensusEntry>* table, float64_t* weights)
 {
 	float64_t w=1.0;
 
@@ -2066,8 +2086,8 @@ float64_t CTrie<Trie>::get_cumulative_score(
 
 	template <class Trie>
 void CTrie<Trie>::fill_backtracking_table(
-	int32_t pos, CDynamicArray<ConsensusEntry>* prev,
-	CDynamicArray<ConsensusEntry>* cur, bool cumulative, float64_t* weights)
+	int32_t pos, DynArray<ConsensusEntry>* prev,
+	DynArray<ConsensusEntry>* cur, bool cumulative, float64_t* weights)
 {
 	ASSERT(pos>=0 && pos<length);
 	ASSERT(!use_compact_terminal_nodes);
