@@ -34,6 +34,15 @@
 
 #include <stdint.h>
 
+/* No feature test:
+ * ISO C99: 7.8 Format conversion of integer types	<inttypes.h>
+ *
+ * If not supported make sure that your development environment is
+ * supporting ISO C99!
+ */
+#define __STDC_FORMAT_MACROS 1
+#include <inttypes.h>
+
 /**
  * Implementations tend to follow IEEE754
  * @see http://ieeexplore.ieee.org/xpl/freeabs_all.jsp?arnumber=4610935
@@ -44,21 +53,10 @@ typedef long double floatmax_t;
 
 //@}
 
-#ifdef HAVE_BOOST_SERIALIZATION
+#define STRING_LEN                 256
+#define STRING_LEN_STR             "256"
+typedef char                       string_t[STRING_LEN];
 
-#define GLOBAL_BOOST_SERIALIZATION_SPLIT_MEMBER()                  \
-template<class Archive>                                            \
-void serialize(Archive &ar, const unsigned int file_version)       \
-{                                                                  \
-    ::boost::serialization::split_member(ar, *this, file_version); \
-}
-/**/
-
-#define GLOBAL_BOOST_CLASS_EXPORT_KEY(T)                           \
-    BOOST_CLASS_EXPORT_KEY2(T, BOOST_PP_STRINGIZE(T))              \
-/**/
-
-
-#endif //HAVE_BOOST_SERIALIZATION
+typedef int                        machine_int_t;
 
 #endif //__COMMON_H__
