@@ -43,12 +43,16 @@ void CLogPlusOne::cleanup()
 /// initialize preprocessor from file
 bool CLogPlusOne::load(FILE* f)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
 /// save preprocessor init-data to file
 bool CLogPlusOne::save(FILE* f)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
