@@ -41,12 +41,16 @@ void CNormDerivativeLem3::cleanup()
 /// initialize preprocessor from file
 bool CNormDerivativeLem3::load(FILE* f)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
 /// save preprocessor init-data to file
 bool CNormDerivativeLem3::save(FILE* f)
 {
+	SG_SET_LOCALE_C;
+	SG_RESET_LOCALE;
 	return false;
 }
 
@@ -61,7 +65,7 @@ float64_t* CNormDerivativeLem3::apply_to_feature_matrix(CFeatures* f)
 /// apply preproc on single feature vector
 /// result in feature matrix
 float64_t* CNormDerivativeLem3::apply_to_feature_vector(
-	float64_t* f, int32_t len)
+	float64_t* f, int32_t& len)
 {
 	return NULL;
 }
