@@ -36,7 +36,8 @@ namespace shogun
  * covariance matrix is of size num_feat*num_feat. Note that vectors don't have
  * to have zero mean as it is substracted.
  */
-class CPCACut : public CSimplePreProc<float64_t>
+#define IGNORE_IN_CLASSLIST
+IGNORE_IN_CLASSLIST class CPCACut : public CSimplePreProc<float64_t>
 {
 	public:
 		/** constructor
