@@ -41,6 +41,7 @@ namespace shogun
 	class CIntronList;
 	class CPlifMatrix;
 	class CSegmentLoss;
+	template <class T> class CArray;
 
 //#define DYNPROG_TIMING
 
@@ -51,6 +52,21 @@ typedef uint8_t T_STATES ;
 #endif
 typedef T_STATES* P_STATES ;
 
+/** @brief segment loss */
+struct segment_loss_struct
+{
+    /** maximum lookback */
+    int32_t maxlookback;
+    /** sequence length */
+    int32_t seqlen;
+    /** segments changed */
+    int32_t *segments_changed;
+    /** numb segment ID */
+    float64_t *num_segment_id;
+    /** length of segmend ID */
+    int32_t *length_segment_id ;
+};
+
 /** @brief Dynamic Programming Class.
  *
  * Structure and Function collection.
@@ -65,26 +81,6 @@ public:
 	 */
 	CDynProg(int32_t p_num_svms=8);
 	virtual ~CDynProg();
-
-	/** best path no b
-	 *
-	 * @param max_iter max iter
-	 * @param best_iter best iter
-	 * @param my_path my path
-	 *
-	 * @return best path no b
-	 */
-	float64_t best_path_no_b(int32_t max_iter, int32_t & best_iter, int32_t *my_path);
-
-	/** best path no b transition
-	 *
-	 * @param max_iter max iter
-	 * @param max_best_iter max best iter
-	 * @param nbest nbest
-	 * @param prob_nbest prob_nbest
-	 * @param my_paths my paths
-	 */
-	void best_path_no_b_trans(int32_t max_iter, int32_t & max_best_iter, int16_t nbest, float64_t *prob_nbest, int32_t *my_paths);
 	
 	// model related functions
 	/** set number of states
@@ -511,9 +507,10 @@ public:
 	{
 		m_long_transitions = use_long_transitions;
 		m_long_transition_threshold = threshold;
-		m_long_transition_max = max_len;
+		SG_DEBUG("ignoring max_len\n") ;
+		//m_long_transition_max = max_len;
 	}
-		
+
 protected:
 
 	/* helper functions */
@@ -793,7 +790,7 @@ protected:
 	 *  Note: is ignored in the current implementation
 	 *        => arbitrarily long transitions can be decoded
 	 */
-	int32_t m_long_transition_max ;
+	//int32_t m_long_transition_max ;
 
 	/**default values defining the k-mer degrees
 	 * used for content type prediction
