@@ -143,7 +143,7 @@ void CPlifMatrix::set_plif_penalties(float64_t* penalties, int32_t num_plifs, in
 	delete[] pen;
 }
 
-void CPlifMatrix::set_plif_names(T_STRING<char>* names, int32_t num_values, int32_t maxlen)
+void CPlifMatrix::set_plif_names(TString<char>* names, int32_t num_values, int32_t maxlen)
 {
 	if (num_values!=m_num_plifs)
 		SG_ERROR("names size mismatch (num_values=%d vs.num_plifs=%d)\n", num_values, m_num_plifs);
@@ -157,7 +157,7 @@ void CPlifMatrix::set_plif_names(T_STRING<char>* names, int32_t num_values, int3
 	}
 }
 
-void CPlifMatrix::set_plif_transform_type(T_STRING<char>* transform_type, int32_t num_values, int32_t maxlen)
+void CPlifMatrix::set_plif_transform_type(TString<char>* transform_type, int32_t num_values, int32_t maxlen)
 {
 	if (num_values!=m_num_plifs)
 		SG_ERROR("transform_type size mismatch (num_values=%d vs.num_plifs=%d)\n", num_values, m_num_plifs);
