@@ -127,11 +127,24 @@ bool CGUIClassifier::new_classifier(char* name, int32_t d, int32_t from_d)
 		classifier= new CLibSVMMultiClass(LIBSVM_NU_SVC);
 		SG_INFO("created SVMlibsvm object for multiclass\n") ;
 	}
-	else if (strcmp(name,"SCATTERSVM")==0)
+
+	else if (strcmp(name,"SCATTERSVM_NO_BIAS_LIBSVM")==0)
 	{
 		SG_UNREF(classifier);
-		classifier= new CScatterSVM();
-		SG_INFO("created ScatterSVM object\n") ;
+		classifier= new CScatterSVM(NO_BIAS_LIBSVM);
+		SG_INFO("created ScatterSVM NO BIAS LIBSVM object\n") ;
+	}
+	else if (strcmp(name,"SCATTERSVM_TESTRULE1")==0)
+	{
+		SG_UNREF(classifier);
+		classifier= new CScatterSVM(TEST_RULE1);
+		SG_INFO("created ScatterSVM TESTRULE1 object\n") ;
+	}
+	else if (strcmp(name,"SCATTERSVM_TESTRULE2")==0)
+	{
+		SG_UNREF(classifier);
+		classifier= new CScatterSVM(TEST_RULE2);
+		SG_INFO("created ScatterSVM TESTRULE2 object\n") ;
 	}
 	else if (strcmp(name,"LIBSVM_NU")==0)
 	{
@@ -223,6 +236,11 @@ bool CGUIClassifier::new_classifier(char* name, int32_t d, int32_t from_d)
 			st=L2R_L2LOSS_SVC;
 			SG_INFO("created LibLinear l2 regularized l2 loss SVM primal object\n") ;
 		}
+		else if (strcmp(name,"LIBLINEAR_L1R_L2LOSS_SVC")==0)
+		{
+			st=L1R_L2LOSS_SVC;
+			SG_INFO("created LibLinear l1 regularized l2 loss SVM primal object\n") ;
+		}
 		else if (strcmp(name,"LIBLINEAR_L2R_L1LOSS_SVC_DUAL")==0)
 		{
 			st=L2R_L1LOSS_SVC_DUAL;
@@ -854,7 +872,7 @@ bool CGUIClassifier::load(char* filename, char* type)
 bool CGUIClassifier::save(char* param)
 {
 	bool result=false;
-	param=CIO::skip_spaces(param);
+	param=IO::skip_spaces(param);
 
 	if (classifier)
 	{
@@ -1106,6 +1124,7 @@ CLabels* CGUIClassifier::classify()
 	switch (classifier->get_classifier_type())
 	{
 		case CT_LIGHT:
+		case CT_LIGHTONECLASS:
 		case CT_LIBSVM:
 		case CT_SCATTERSVM:
 		case CT_MPD:
@@ -1202,6 +1221,7 @@ bool CGUIClassifier::get_trained_classifier(
 		case CT_GNPPSVM:
 		case CT_LIBSVMMULTICLASS:
 		case CT_LIGHT:
+		case CT_LIGHTONECLASS:
 		case CT_LIBSVM:
 		case CT_MPD:
 		case CT_GPBT:
@@ -1570,11 +1590,17 @@ bool CGUIClassifier::set_constraint_generator(char* name)
 		constraint_generator= new CLibSVMMultiClass(LIBSVM_NU_SVC);
 		SG_INFO("created SVMlibsvm object for multiclass\n") ;
 	}
-	else if (strcmp(name,"SCATTERSVM")==0)
+	else if (strcmp(name,"SCATTERSVM_RULE1")==0)
 	{
 		SG_UNREF(constraint_generator);
-		constraint_generator= new CScatterSVM();
-		SG_INFO("created ScatterSVM object\n") ;
+		constraint_generator= new CScatterSVM(TEST_RULE1);
+		SG_INFO("created ScatterSVM RULE1 object\n") ;
+	}
+	else if (strcmp(name,"SCATTERSVM_RULE2")==0)
+	{
+		SG_UNREF(constraint_generator);
+		constraint_generator= new CScatterSVM(TEST_RULE2);
+		SG_INFO("created ScatterSVM RULE2 object\n") ;
 	}
 	else if (strcmp(name,"LIBSVM_NU")==0)
 	{
