@@ -20,9 +20,7 @@
 #include <shogun/kernel/CombinedKernel.h>
 #include <shogun/kernel/Chi2Kernel.h>
 #include <shogun/kernel/LinearKernel.h>
-#include <shogun/kernel/LinearByteKernel.h>
 #include <shogun/kernel/LinearStringKernel.h>
-#include <shogun/kernel/LinearWordKernel.h>
 #include <shogun/kernel/WeightedDegreeStringKernel.h>
 #include <shogun/kernel/WeightedDegreeRBFKernel.h>
 #include <shogun/kernel/SpectrumMismatchRBFKernel.h>
@@ -45,9 +43,6 @@
 #include <shogun/kernel/GaussianKernel.h>
 #include <shogun/kernel/GaussianShiftKernel.h>
 #include <shogun/kernel/SigmoidKernel.h>
-#include <shogun/kernel/SparseLinearKernel.h>
-#include <shogun/kernel/SparsePolyKernel.h>
-#include <shogun/kernel/SparseGaussianKernel.h>
 #include <shogun/kernel/DiagKernel.h>
 #include <shogun/kernel/OligoStringKernel.h>
 #include <shogun/kernel/DistanceKernel.h>
@@ -60,6 +55,7 @@
 #include <shogun/kernel/VarianceKernelNormalizer.h>
 #include <shogun/kernel/ScatterKernelNormalizer.h>
 #include <shogun/classifier/svm/SVM.h>
+#include <shogun/kernel/ZeroMeanCenterKernelNormalizer.h>
 
 #include <string.h>
 
@@ -149,7 +145,7 @@ CKernel* CGUIKernel::create_gaussianshift(
 
 CKernel* CGUIKernel::create_sparsegaussian(int32_t size, float64_t width)
 {
-	CKernel* kern=new CSparseGaussianKernel(size, width);
+	CKernel* kern=new CGaussianKernel(size, width);
 	if (!kern)
 		SG_ERROR("Couldn't create GaussianKernel with size %d, width %f.\n", size, width);
 	else
@@ -184,10 +180,10 @@ CKernel* CGUIKernel::create_sigmoid(
 CKernel* CGUIKernel::create_sparsepoly(
 	int32_t size, int32_t degree, bool inhomogene, bool normalize)
 {
-	CKernel* kern=new CSparsePolyKernel(size, degree, inhomogene);
+	CKernel* kern=new CPolyKernel(size, degree, inhomogene);
 	if (!normalize)
 		kern->set_normalizer(new CIdentityKernelNormalizer());
-	SG_DEBUG("created SparsePolyKernel with size %d, degree %d, inhomogene %d normalize %d.\n", kern, size, degree, inhomogene, normalize);
+	SG_DEBUG("created PolyKernel with size %d, degree %d, inhomogene %d normalize %d.\n", kern, size, degree, inhomogene, normalize);
 
 	return kern;
 }
@@ -386,10 +382,10 @@ CKernel* CGUIKernel::create_weighteddegreerbf(int32_t size, int32_t degree, int3
 	return kern;
 }
 
-CKernel* CGUIKernel::create_spectrummismatchrbf(int32_t size, float64_t* AA_matrix, int32_t max_mismatch, int32_t degree, float64_t width)
+CKernel* CGUIKernel::create_spectrummismatchrbf(int32_t size, float64_t* AA_matrix, int32_t nr, int32_t nc, int32_t max_mismatch, int32_t degree, float64_t width)
 {
 
-	CKernel* kern = new CSpectrumMismatchRBFKernel(size, AA_matrix, degree, max_mismatch, width);
+  CKernel* kern = new CSpectrumMismatchRBFKernel(size, AA_matrix, nr, nc, degree, max_mismatch, width);
 	if (!kern)
 		SG_ERROR("Couldn't create SpectrumMismatchRBFKernel with size %d, width %f, degree %d, max_mismatch %d.\n", size, width, degree, max_mismatch);
 	else
@@ -545,7 +541,7 @@ CKernel* CGUIKernel::create_histogramword(int32_t size)
 CKernel* CGUIKernel::create_linearbyte(int32_t size, float64_t scale)
 {
 	size=0;
-	CKernel* kern=new CLinearByteKernel();
+	CKernel* kern=new CLinearKernel();
 	kern->set_normalizer(new CAvgDiagKernelNormalizer(scale));
 	SG_DEBUG("created LinearByteKernel (%p) with size %d and scale %f.\n", kern, size, scale);
 
@@ -555,7 +551,7 @@ CKernel* CGUIKernel::create_linearbyte(int32_t size, float64_t scale)
 CKernel* CGUIKernel::create_linearword(int32_t size, float64_t scale)
 {
 	size=0;
-	CKernel* kern=new CLinearWordKernel();
+	CKernel* kern=new CLinearKernel();
 	kern->set_normalizer(new CAvgDiagKernelNormalizer(scale));
 	SG_DEBUG("created LinearWordKernel (%p) with size %d and scale %f.\n", kern, size, scale);
 
@@ -588,10 +584,10 @@ CKernel* CGUIKernel::create_linear(int32_t size, float64_t scale)
 CKernel* CGUIKernel::create_sparselinear(int32_t size, float64_t scale)
 {
 	size=0;
-	CKernel* kern=new CSparseLinearKernel();
+	CKernel* kern=new CLinearKernel();
 	kern->set_normalizer(new CAvgDiagKernelNormalizer(scale));
 
-	SG_DEBUG("created SparseLinearKernel (%p) with size %d and scale %f.\n", kern, size, scale);
+	SG_DEBUG("created LinearKernel (%p) with size %d and scale %f.\n", kern, size, scale);
 
 	return kern;
 }
@@ -675,13 +671,18 @@ bool CGUIKernel::set_normalization(char* normalization, float64_t c, float64_t r
 		SG_INFO("Variance Normalization selected\n");
 		return k->set_normalizer(new CVarianceKernelNormalizer());
 	}
-	else if (strncmp(normalization,"SCATTER", 7)==0)
+   	else if (strncmp(normalization,"SCATTER", 7)==0)
 	{
 		SG_INFO("Scatter Normalization selected\n");
 		CLabels* train_labels=ui->ui_labels->get_train_labels();
 		ASSERT(train_labels);
 		return k->set_normalizer(new CScatterKernelNormalizer(c,r, train_labels));
 	}
+	else if (strncmp(normalization,"ZEROMEANCENTER", 13)==0)
+	{
+		SG_INFO("Zero Mean Center Normalization selected\n");
+		return k->set_normalizer(new CZeroMeanCenterKernelNormalizer());
+	}
 	else
 		SG_ERROR("Wrong kernel normalizer name.\n");
 
