@@ -17,6 +17,8 @@
 #include <shogun/classifier/PluginEstimate.h>
 #include <shogun/features/Labels.h>
 
+namespace shogun
+{
 class CSGInterface;
 
 class CGUIPluginEstimate : public CSGObject
@@ -38,7 +40,7 @@ class CGUIPluginEstimate : public CSGObject
 
 		inline CPluginEstimate* get_estimator() { return estimator; }
 
-		CLabels* classify(CLabels* output=NULL);
+		CLabels* classify();
 		float64_t classify_example(int32_t idx);
 
 		/** @return object name */
@@ -51,4 +53,5 @@ class CGUIPluginEstimate : public CSGObject
 		float64_t pos_pseudo;
 		float64_t neg_pseudo;
 };
+}
 #endif
