@@ -572,6 +572,8 @@ class CSGInterface : public CSGObject
 		virtual bool cmd_run_octave();
 		/** execute code under r from python,... */
 		virtual bool cmd_run_r();
+		/** call pr_loqo solver */
+		virtual bool cmd_pr_loqo();
 
 		/** get functions - to pass data from the target interface to shogun */
 
@@ -638,19 +640,19 @@ class CSGInterface : public CSGObject
 		virtual void get_word_sparsematrix(TSparse<uint16_t>*& matrix, int32_t& num_feat, int32_t& num_vec)=0; */
 
 		virtual void get_byte_string_list(
-			T_STRING<uint8_t>*& strings, int32_t& num_str,
+			TString<uint8_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len)=0;
 		virtual void get_char_string_list(
-			T_STRING<char>*& strings, int32_t& num_str,
+			TString<char>*& strings, int32_t& num_str,
 			int32_t& max_string_len)=0;
 		virtual void get_int_string_list(
-			T_STRING<int32_t>*& strings, int32_t& num_str,
+			TString<int32_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len)=0;
 		virtual void get_short_string_list(
-			T_STRING<int16_t>*& strings, int32_t& num_str,
+			TString<int16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len)=0;
 		virtual void get_word_string_list(
-			T_STRING<uint16_t>*& strings, int32_t& num_str,
+			TString<uint16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len)=0;
 
 		virtual void get_attribute_struct(
@@ -704,15 +706,15 @@ class CSGInterface : public CSGObject
 
 
 		virtual void set_byte_string_list(
-			const T_STRING<uint8_t>* strings, int32_t num_str)=0;
+			const TString<uint8_t>* strings, int32_t num_str)=0;
 		virtual void set_char_string_list(
-			const T_STRING<char>* strings, int32_t num_str)=0;
+			const TString<char>* strings, int32_t num_str)=0;
 		virtual void set_int_string_list(
-			const T_STRING<int32_t>* strings, int32_t num_str)=0;
+			const TString<int32_t>* strings, int32_t num_str)=0;
 		virtual void set_short_string_list(
-			const T_STRING<int16_t>* strings, int32_t num_str)=0;
+			const TString<int16_t>* strings, int32_t num_str)=0;
 		virtual void set_word_string_list(
-			const T_STRING<uint16_t>* strings, int32_t num_str)=0;
+			const TString<uint16_t>* strings, int32_t num_str)=0;
 
 		virtual void set_attribute_struct(
 			const CDynamicArray<T_ATTRIBUTE>* attrs)=0;
