@@ -91,19 +91,19 @@ class CMatlabInterface : public CSGInterface
 		virtual void get_word_sparsematrix(TSparse<uint16_t>*& matrix, int32_t& num_feat, int32_t& num_vec);*/
 
 		virtual void get_byte_string_list(
-			T_STRING<uint8_t>*& strings, int32_t& num_str,
+			TString<uint8_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_char_string_list(
-			T_STRING<char>*& strings, int32_t& num_str,
+			TString<char>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_int_string_list(
-			T_STRING<int32_t>*& strings, int32_t& num_str,
+			TString<int32_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_short_string_list(
-			T_STRING<int16_t>*& strings, int32_t& num_str,
+			TString<int16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 		virtual void get_word_string_list(
-			T_STRING<uint16_t>*& strings, int32_t& num_str,
+			TString<uint16_t>*& strings, int32_t& num_str,
 			int32_t& max_string_len);
 
 		virtual void get_attribute_struct(
@@ -151,15 +151,15 @@ class CMatlabInterface : public CSGInterface
 		virtual void set_word_sparsematrix(const TSparse<uint16_t>* matrix, int32_t num_feat, int32_t num_vec);*/
 
 		virtual void set_byte_string_list(
-			const T_STRING<uint8_t>* strings, int32_t num_str);
+			const TString<uint8_t>* strings, int32_t num_str);
 		virtual void set_char_string_list(
-			const T_STRING<char>* strings, int32_t num_str);
+			const TString<char>* strings, int32_t num_str);
 		virtual void set_int_string_list(
-			const T_STRING<int32_t>* strings, int32_t num_str);
+			const TString<int32_t>* strings, int32_t num_str);
 		virtual void set_short_string_list(
-			const T_STRING<int16_t>* strings, int32_t num_str);
+			const TString<int16_t>* strings, int32_t num_str);
 		virtual void set_word_string_list(
-			const T_STRING<uint16_t>* strings, int32_t num_str);
+			const TString<uint16_t>* strings, int32_t num_str);
 
 		virtual void set_attribute_struct(
 			const CDynamicArray<T_ATTRIBUTE>* attrs);
