@@ -5,7 +5,7 @@
 
 #include <shogun/lib/ShogunException.h>
 #include <shogun/lib/io.h>
-#include <shogun/ui/SGInterface.h>
+#include "ui/SGInterface.h"
 #include <shogun/base/init.h>
 
 #ifdef HAVE_OCTAVE
@@ -345,7 +345,7 @@ GET_SPARSEMATRIX(get_word_sparsematrix, "uint16", uint16_t, unsigned short, "Wor
 
 
 #define GET_STRINGLIST(function_name, py_type, sg_type, if_type, is_char_str, error_string)	\
-void CPythonInterface::function_name(T_STRING<sg_type>*& strings, int32_t& num_str, int32_t& max_string_len)	\
+void CPythonInterface::function_name(TString<sg_type>*& strings, int32_t& num_str, int32_t& max_string_len)	\
 { 																			\
 	max_string_len=0;														\
 	const PyObject* py_str= get_arg_increment();							\
@@ -360,7 +360,7 @@ void CPythonInterface::function_name(T_STRING<sg_type>*& strings, int32_t& num_s
 		num_str=PyList_Size((PyObject*) py_str);							\
 		ASSERT(num_str>=1);													\
 																			\
-		strings=new T_STRING<sg_type>[num_str];								\
+		strings=new TString<sg_type>[num_str];								\
 		ASSERT(strings);													\
 																			\
 		for (int32_t i=0; i<num_str; i++)										\
@@ -397,7 +397,7 @@ void CPythonInterface::function_name(T_STRING<sg_type>*& strings, int32_t& num_s
 		if_type* data=(if_type*) py_array_str->data;						\
 		num_str=py_array_str->dimensions[0]; 								\
 		int32_t len=py_array_str->dimensions[1]; 								\
-		strings=new T_STRING<sg_type>[num_str]; 							\
+		strings=new TString<sg_type>[num_str]; 							\
 																			\
 		for (int32_t i=0; i<num_str; i++) 										\
 		{ 																	\
@@ -576,7 +576,7 @@ SET_SPARSEMATRIX(set_word_sparsematrix, mxUINT16_CLASS, uint16_t, unsigned short
 
 
 #define SET_STRINGLIST(function_name, py_type, sg_type, if_type, is_char_str, error_string)	\
-void CPythonInterface::function_name(const T_STRING<sg_type>* strings, int32_t num_str)	\
+void CPythonInterface::function_name(const TString<sg_type>* strings, int32_t num_str)	\
 {																				\
 	if (!is_char_str)															\
 		SG_ERROR("Only character strings supported.\n");						\
